@@ -75,12 +75,10 @@ nc_cluster_abundance_init (NcClusterAbundance *cad)
   cad->N        = &_N;
   cad->intp_d2N = &_intp_d2N;
 
-  cad->completeness = NULL;
-  cad->purity = NULL;
-  cad->sd_lnM = NULL;
-  cad->norma = 0.0;
-  cad->log_norma = 0.0;
-  cad->completeness_factor = 1.0; //0.874737945; (work with Camila and Alex)
+  cad->purity       = NULL;
+  cad->sd_lnM       = NULL;
+  cad->norma        = 0.0;
+  cad->log_norma    = 0.0;
 
 #define D2NDZDLNM_Z(cad) ((cad)->d2NdzdlnM->yv)
 #define D2NDZDLNM_LNM(cad) ((cad)->d2NdzdlnM->xv)
@@ -119,7 +117,7 @@ _nc_cluster_abundance_dispose (GObject *object)
 {
   NcClusterAbundance *cad = NC_CLUSTER_ABUNDANCE (object);
   
-  nc_mass_function_clear (&cad->mfp);
+  nc_halo_mass_function_clear (&cad->mfp);
   nc_halo_bias_func_clear (&cad->mbiasf);
 
   ncm_spline_clear (&cad->inv_z);
@@ -188,22 +186,22 @@ nc_cluster_abundance_class_init (NcClusterAbundanceClass *klass)
 {
   GObjectClass* object_class = G_OBJECT_CLASS (klass);
 
-  object_class->dispose = _nc_cluster_abundance_dispose;
-  object_class->finalize = _nc_cluster_abundance_finalize;
-  object_class->set_property = _nc_cluster_abundance_set_property;
-  object_class->get_property = _nc_cluster_abundance_get_property;
+  object_class->set_property = &_nc_cluster_abundance_set_property;
+  object_class->get_property = &_nc_cluster_abundance_get_property;
+  object_class->dispose      = &_nc_cluster_abundance_dispose;
+  object_class->finalize     = &_nc_cluster_abundance_finalize;
 
   /**
-   * NcClusterAbundance:mass-function:
+   * NcClusterAbundance:halo-mass-function:
    *
    * FIXME
    */
   g_object_class_install_property (object_class,
                                    PROP_MASS_FUNCTION,
-                                   g_param_spec_object ("mass-function",
+                                   g_param_spec_object ("halo-mass-function",
                                                         NULL,
                                                         "Mass Function",
-                                                        NC_TYPE_MASS_FUNCTION,
+                                                        NC_TYPE_HALO_MASS_FUNCTION,
                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
   /**
    * NcClusterAbundance:mean-bias:
@@ -222,7 +220,7 @@ nc_cluster_abundance_class_init (NcClusterAbundanceClass *klass)
 
 /**
  * nc_cluster_abundance_new:
- * @mfp: a #NcMassFunction
+ * @mfp: a #NcHaloMassFunction
  * @mbiasf: (allow-none): a #NcHaloBiasFunc
  *
  * This function allocates memory for a new #NcClusterAbundance object and sets its properties to the values from
@@ -231,31 +229,31 @@ nc_cluster_abundance_class_init (NcClusterAbundanceClass *klass)
  * Returns: A new #NcClusterAbundance.
  */
 NcClusterAbundance *
-nc_cluster_abundance_new (NcMassFunction *mfp, NcHaloBiasFunc *mbiasf)
+nc_cluster_abundance_new (NcHaloMassFunction *mfp, NcHaloBiasFunc *mbiasf)
 {
   NcClusterAbundance *cad = g_object_new (NC_TYPE_CLUSTER_ABUNDANCE,
-                                          "mass-function",    mfp,
-                                          "mean-bias",        mbiasf,
+                                          "halo-mass-function", mfp,
+                                          "mean-bias",          mbiasf,
                                           NULL);
   return cad;
 }
 
 /**
  * nc_cluster_abundance_nodist_new:
- * @mfp: a #NcMassFunction.
+ * @mfp: a #NcHaloMassFunction.
  * @mbiasf: (allow-none): a #NcHaloBiasFunc.
-   *
+ *
  * This function allocates memory for a new #NcClusterAbundance object and sets its properties to the values from
  * the input arguments.
  *
  * Returns: A new #NcClusterAbundance.
  */
 NcClusterAbundance *
-nc_cluster_abundance_nodist_new (NcMassFunction *mfp, NcHaloBiasFunc *mbiasf)
+nc_cluster_abundance_nodist_new (NcHaloMassFunction *mfp, NcHaloBiasFunc *mbiasf)
 {
   NcClusterAbundance *cad = g_object_new (NC_TYPE_CLUSTER_ABUNDANCE,
-                                          "mass-function",    mfp,
-                                          "mean-bias",        mbiasf,
+                                          "halo-mass-function", mfp,
+                                          "mean-bias",          mbiasf,
                                           NULL);
   return cad;
 }
@@ -317,19 +315,19 @@ typedef struct _observables_integrand_data
 } observables_integrand_data;
 
 static gdouble
-_nc_cluster_abundance_z_p_lnm_p_d2n_integrand (gdouble lnM, gdouble z, gpointer userdata)
+_nc_cluster_abundance_z_p_lnM_p_d2n_integrand (gdouble lnM, gdouble z, gpointer userdata)
 {
   observables_integrand_data *obs_data = (observables_integrand_data *) userdata;
   NcClusterAbundance *cad = obs_data->cad;
   const gdouble p_z_zr = nc_cluster_redshift_p (obs_data->clusterz, lnM, z, obs_data->z_obs, obs_data->z_obs_params);
   const gdouble p_M_Mobs = nc_cluster_mass_p (obs_data->clusterm, obs_data->cosmo, lnM, z, obs_data->lnM_obs, obs_data->lnM_obs_params);
-  gdouble d2NdzdlnM = nc_mass_function_d2n_dzdlnm (cad->mfp, obs_data->cosmo, lnM, z);
+  gdouble d2NdzdlnM = nc_halo_mass_function_d2n_dzdlnM (cad->mfp, obs_data->cosmo, lnM, z);
 
   return p_z_zr * p_M_Mobs * d2NdzdlnM;
 }
 
 /**
- * nc_cluster_abundance_z_p_lnm_p_d2n:
+ * nc_cluster_abundance_z_p_lnM_p_d2n:
  * @cad: a #NcClusterAbundance
  * @cosmo: a #NcHICosmo
  * @clusterz: a #NcClusterRedshift
@@ -347,7 +345,7 @@ _nc_cluster_abundance_z_p_lnm_p_d2n_integrand (gdouble lnM, gdouble z, gpointer
  * Returns: a gdouble which represents /f$ \frac{d^2N(\ln M^{obs}, z^{phot})}{dzd\lnM} /f$.
  */
 gdouble
-nc_cluster_abundance_z_p_lnm_p_d2n (NcClusterAbundance *cad, NcHICosmo *cosmo, NcClusterRedshift *clusterz, NcClusterMass *clusterm, gdouble *lnM_obs, gdouble *lnM_obs_params, gdouble *z_obs, gdouble *z_obs_params)
+nc_cluster_abundance_z_p_lnM_p_d2n (NcClusterAbundance *cad, NcHICosmo *cosmo, NcClusterRedshift *clusterz, NcClusterMass *clusterm, gdouble *lnM_obs, gdouble *lnM_obs_params, gdouble *z_obs, gdouble *z_obs_params)
 {
   gdouble d2N, zl, zu, lnMl, lnMu, err;
   observables_integrand_data obs_data;
@@ -362,7 +360,7 @@ nc_cluster_abundance_z_p_lnm_p_d2n (NcClusterAbundance *cad, NcHICosmo *cosmo, N
   obs_data.z_obs          = z_obs;
   obs_data.z_obs_params   = z_obs_params;
 
-  integ.f = _nc_cluster_abundance_z_p_lnm_p_d2n_integrand;
+  integ.f = _nc_cluster_abundance_z_p_lnM_p_d2n_integrand;
   integ.userdata = &obs_data;
 
   nc_cluster_redshift_p_limits (clusterz, z_obs, z_obs_params, &zl, &zu);
@@ -379,7 +377,7 @@ _nc_cluster_abundance_z_p_d2n_integrand (gdouble z, gpointer params)
   observables_integrand_data *obs_data = (observables_integrand_data *) params;
   NcClusterAbundance *cad = obs_data->cad;
   const gdouble p_z_zr = nc_cluster_redshift_p (obs_data->clusterz, obs_data->lnM, z, obs_data->z_obs, obs_data->z_obs_params);
-  const gdouble d2NdzdlnM = nc_mass_function_d2n_dzdlnm (cad->mfp, obs_data->cosmo, obs_data->lnM, z);
+  const gdouble d2NdzdlnM = nc_halo_mass_function_d2n_dzdlnM (cad->mfp, obs_data->cosmo, obs_data->lnM, z);
 
   return p_z_zr * d2NdzdlnM;
 }
@@ -430,7 +428,7 @@ nc_cluster_abundance_z_p_d2n (NcClusterAbundance *cad, NcHICosmo *cosmo, NcClust
 }
 
 /**
- * _nc_cluster_abundance_lnm_p_d2n_integrand:
+ * _nc_cluster_abundance_lnM_p_d2n_integrand:
  * @lnM: logarithm base e of the mass
  * @params: a gpointer
  *
@@ -441,20 +439,18 @@ nc_cluster_abundance_z_p_d2n (NcClusterAbundance *cad, NcHICosmo *cosmo, NcClust
  * Returns: a gdouble which is the integrand value at lnM.
  */
 static gdouble
-_nc_cluster_abundance_lnm_p_d2n_integrand (gdouble lnM, gpointer params)
+_nc_cluster_abundance_lnM_p_d2n_integrand (gdouble lnM, gpointer params)
 {
   observables_integrand_data *obs_data = (observables_integrand_data *) params;
   NcClusterAbundance *cad = obs_data->cad;
   const gdouble p_M_Mobs = nc_cluster_mass_p (obs_data->clusterm, obs_data->cosmo, lnM, obs_data->z, obs_data->lnM_obs, obs_data->lnM_obs_params);
-  const gdouble d2NdzdlnM = nc_mass_function_d2n_dzdlnm (cad->mfp, obs_data->cosmo, lnM, obs_data->z);
-
-  //printf ("pM = % 20.8g d2NdzdlnM = % 20.8g res = % 20.8g\n", p_M_Mobs, d2NdzdlnM, p_M_Mobs * d2NdzdlnM);
+  const gdouble d2NdzdlnM = nc_halo_mass_function_d2n_dzdlnM (cad->mfp, obs_data->cosmo, lnM, obs_data->z);
 
   return p_M_Mobs * d2NdzdlnM;
 }
 
 /**
- * nc_cluster_abundance_lnm_p_d2n:
+ * nc_cluster_abundance_lnM_p_d2n:
  * @cad: a #NcClusterAbundance
  * @cosmo: a #NcHICosmo
  * @clusterz: a #NcClusterRedshift
@@ -471,7 +467,7 @@ _nc_cluster_abundance_lnm_p_d2n_integrand (gdouble lnM, gpointer params)
  * \frac{d^2N}{dzdlnM} * P(\ln M^{obs}|\ln M) /f$.
  */
 gdouble
-nc_cluster_abundance_lnm_p_d2n (NcClusterAbundance *cad, NcHICosmo *cosmo, NcClusterRedshift *clusterz, NcClusterMass *clusterm, gdouble *lnM_obs, gdouble *lnM_obs_params, gdouble z)
+nc_cluster_abundance_lnM_p_d2n (NcClusterAbundance *cad, NcHICosmo *cosmo, NcClusterRedshift *clusterz, NcClusterMass *clusterm, gdouble *lnM_obs, gdouble *lnM_obs_params, gdouble z)
 {
   observables_integrand_data obs_data;
   gdouble d2N, lnMl, lnMu, err;
@@ -486,7 +482,7 @@ nc_cluster_abundance_lnm_p_d2n (NcClusterAbundance *cad, NcHICosmo *cosmo, NcClu
   obs_data.lnM_obs_params = lnM_obs_params;
   obs_data.z              = z;
 
-  F.function = &_nc_cluster_abundance_lnm_p_d2n_integrand;
+  F.function = &_nc_cluster_abundance_lnM_p_d2n_integrand;
   F.params = &obs_data;
 
   nc_cluster_mass_p_limits (clusterm, cosmo, lnM_obs, lnM_obs_params, &lnMl, &lnMu);
@@ -508,7 +504,7 @@ if (FALSE)
     const gdouble E = nc_hicosmo_E (cosmo, z);
     const gdouble lnzeta = log (zeta);
     const gdouble lnM = log (msz->M0) + (lnzeta - log (A_SZ) - C_SZ * log (E / E0)) / B_SZ;
-    const gdouble d2N_lnM = nc_mass_function_d2n_dzdlnm (cad->mfp, cosmo, lnM, z);
+    const gdouble d2N_lnM = nc_halo_mass_function_d2n_dzdlnM (cad->mfp, cosmo, lnM, z);
 
     printf ("xi % 8.5g zeta % 8.5g M % 8.5g [% 8.5g % 8.5g] : d2N_lnM % 8.5g d2N_xi % 8.5g r % 8.5g m2lnL % 8.5g\n",
             xi, zeta, exp (lnM), exp (lnMl), exp (lnMu), d2N_lnM, d2N, d2N / d2N_lnM, -2.0 * log (d2N));
@@ -539,7 +535,7 @@ nc_cluster_abundance_d2n (NcClusterAbundance *cad, NcHICosmo *cosmo, NcClusterRe
 {
   NCM_UNUSED (clusterz);
   NCM_UNUSED (clusterm);
-  return nc_mass_function_d2n_dzdlnm (cad->mfp, cosmo, lnM, z);
+  return nc_halo_mass_function_d2n_dzdlnM (cad->mfp, cosmo, lnM, z);
 }
 
 static gdouble
@@ -547,7 +543,7 @@ _nc_cluster_abundance_z_intp_lnM_intp_d2N (NcClusterAbundance *cad, NcHICosmo *c
 {
   const gdouble z_intp = nc_cluster_redshift_intp (clusterz, lnM, z);
   const gdouble lnM_intp = nc_cluster_mass_intp (clusterm, cosmo, lnM, z);
-  gdouble d2NdzdlnM = nc_mass_function_d2n_dzdlnm (cad->mfp, cosmo, lnM, z);
+  gdouble d2NdzdlnM = nc_halo_mass_function_d2n_dzdlnM (cad->mfp, cosmo, lnM, z);
   return z_intp * lnM_intp * d2NdzdlnM;
 }
 
@@ -585,7 +581,7 @@ static gdouble
 _nc_cluster_abundance_z_intp_d2N (NcClusterAbundance *cad, NcHICosmo *cosmo, NcClusterRedshift *clusterz, NcClusterMass *clusterm, gdouble lnM, gdouble z)
 {
   const gdouble z_intp = nc_cluster_redshift_intp (clusterz, lnM, z);
-  gdouble d2NdzdlnM = nc_mass_function_d2n_dzdlnm (cad->mfp, cosmo, lnM, z);
+  gdouble d2NdzdlnM = nc_halo_mass_function_d2n_dzdlnM (cad->mfp, cosmo, lnM, z);
   NCM_UNUSED (clusterm);
   return z_intp * d2NdzdlnM;
 }
@@ -624,7 +620,7 @@ static gdouble
 _nc_cluster_abundance_lnM_intp_d2N (NcClusterAbundance *cad, NcHICosmo *cosmo, NcClusterRedshift *clusterz, NcClusterMass *clusterm, gdouble lnM, gdouble z)
 {
   const gdouble lnM_intp = nc_cluster_mass_intp (clusterm, cosmo, lnM, z);
-  gdouble d2NdzdlnM = nc_mass_function_d2n_dzdlnm (cad->mfp, cosmo, lnM, z);
+  gdouble d2NdzdlnM = nc_halo_mass_function_d2n_dzdlnM (cad->mfp, cosmo, lnM, z);
   NCM_UNUSED (clusterz);
   return lnM_intp * d2NdzdlnM;
 }
@@ -692,7 +688,6 @@ _nc_cluster_abundance_funcs (NcClusterAbundance *cad, NcClusterRedshift *cluster
 /**
  * nc_cluster_abundance_prepare:
  * @cad: a #NcClusterAbundance
- * @reion: a #NcHIReion
  * @cosmo: a #NcHICosmo
  * @clusterz: a #NcClusterRedshift
  * @clusterm: a #NcClusterMass
@@ -701,23 +696,22 @@ _nc_cluster_abundance_funcs (NcClusterAbundance *cad, NcClusterRedshift *cluster
  *
  */
 void
-nc_cluster_abundance_prepare (NcClusterAbundance *cad, NcHIReion *reion, NcHICosmo *cosmo, NcClusterRedshift *clusterz, NcClusterMass *clusterm)
+nc_cluster_abundance_prepare (NcClusterAbundance *cad, NcHICosmo *cosmo, NcClusterRedshift *clusterz, NcClusterMass *clusterm)
 {
   _nc_cluster_abundance_funcs (cad, clusterz, clusterm);
   nc_cluster_redshift_n_limits (clusterz, &cad->zi, &cad->zf);
   nc_cluster_mass_n_limits (clusterm, cosmo, &cad->lnMi, &cad->lnMf);
 
-  nc_mass_function_set_eval_limits (cad->mfp, cosmo, cad->lnMi, cad->lnMf, cad->zi, cad->zf);
-  nc_mass_function_prepare_if_needed (cad->mfp, reion, cosmo);
+  nc_halo_mass_function_set_eval_limits (cad->mfp, cosmo, cad->lnMi, cad->lnMf, cad->zi, cad->zf);
+  nc_halo_mass_function_prepare_if_needed (cad->mfp, cosmo);
 
   if (cad->zi == 0.0)
     cad->zi = 1.0e-6;
 
-  cad->norma = nc_cluster_abundance_true_n (cad, cosmo, clusterz, clusterm);
+  cad->norma     = nc_cluster_abundance_true_n (cad, cosmo, clusterz, clusterm);
   cad->log_norma = log (cad->norma);
 
   ncm_model_ctrl_update (cad->ctrl_cosmo, NCM_MODEL (cosmo));
-  ncm_model_ctrl_update (cad->ctrl_reion, NCM_MODEL (reion));
   ncm_model_ctrl_update (cad->ctrl_z, NCM_MODEL (clusterz));
   ncm_model_ctrl_update (cad->ctrl_m, NCM_MODEL (clusterm));
 }
@@ -736,40 +730,43 @@ _nc_cad_inv_dNdz_convergence_f_onemn (gdouble onemn, gdouble epsilon)
 
 /**
  * nc_cluster_abundance_prepare_inv_dNdz:
- * @cad: a #NcClusterAbundance.
- * @cosmo: a #NcHICosmo.
+ * @cad: a #NcClusterAbundance
+ * @cosmo: a #NcHICosmo
+ * @lnMi: logarithm base e of the minimum mass $\ln(M_i)$
  *
  * This function prepares a bidimensional spline...
  *
  */
 void
-nc_cluster_abundance_prepare_inv_dNdz (NcClusterAbundance *cad, NcHICosmo *cosmo)
+nc_cluster_abundance_prepare_inv_dNdz (NcClusterAbundance *cad, NcHICosmo *cosmo, const gdouble lnMi)
 {
-  guint i, j;
-  gdouble z0 = cad->zi;
-  guint middle = cad->inv_z->len / 2;
+  NcHaloMassFunctionSplineOptimize sp_optimize = NC_HALO_MASS_FUNCTION_SPLINE_Z;
+  const gdouble delta_z   = (cad->zf - cad->zi) / (cad->inv_z->len - 1.0);
+  const gdouble delta_lnM = (cad->lnMf - lnMi) / (cad->inv_lnM->len - 1.0);
+  const gdouble norma     = nc_halo_mass_function_n (cad->mfp, cosmo, lnMi, cad->lnMf, cad->zi, cad->zf, NC_HALO_MASS_FUNCTION_SPLINE_LNM);
   gboolean use_spline = FALSE;
-  NcMassFunctionSplineOptimize sp_optimize = NC_MASS_FUNCTION_SPLINE_Z;
-  const gdouble delta_z = (cad->zf - cad->zi) / (cad->inv_z->len - 1.0);
-  const gdouble delta_lnM = (cad->lnMf - cad->lnMi) / (cad->inv_lnM->len - 1.0);
+  guint middle = cad->inv_z->len / 2;
+  gdouble z0   = cad->zi;
+  guint i, j;
+
   g_assert (cad->zi != 0);
 
   {    
-    const gdouble zfm1 = cad->zf - delta_z;
+    const gdouble zfm1   = cad->zf - delta_z;
     const gdouble lnMfm1 = cad->lnMf - delta_lnM;
     
-    cad->z_epsilon = nc_mass_function_n (cad->mfp, cosmo, cad->lnMi, cad->lnMf, zfm1, cad->zf, sp_optimize) / cad->norma;   
-    cad->lnM_epsilon = nc_mass_function_dn_dz (cad->mfp, cosmo, lnMfm1, cad->lnMf, cad->zf, use_spline) /
-      nc_mass_function_dn_dz (cad->mfp, cosmo, cad->lnMi, cad->lnMf, cad->zf, use_spline);
+    cad->z_epsilon   = fabs (nc_halo_mass_function_n (cad->mfp, cosmo, lnMi, cad->lnMf, zfm1, cad->zf, sp_optimize) / norma);   
+    cad->lnM_epsilon = fabs (nc_halo_mass_function_dn_dz (cad->mfp, cosmo, lnMfm1, cad->lnMf, cad->zf, use_spline) /
+      nc_halo_mass_function_dn_dz (cad->mfp, cosmo, lnMi, cad->lnMf, cad->zf, use_spline));
   }
 
   {
     gdouble zm = cad->zi + delta_z * middle;
-    nc_cluster_abundance_prepare_inv_dNdlnM_z (cad, cosmo, zm);
+    nc_cluster_abundance_prepare_inv_dNdlnM_z (cad, cosmo, lnMi, zm);
 
     ncm_vector_set (cad->inv_lnM_z->xv, 0, _nc_cad_inv_dNdz_convergence_f (0.0, cad->lnM_epsilon));
-    ncm_matrix_set (cad->inv_lnM_z->zm, middle, 0, cad->lnMi);
-    
+    ncm_matrix_set (cad->inv_lnM_z->zm, middle, 0, lnMi);
+
     for (j = 1; j < ncm_vector_len (cad->inv_lnM_z->xv) - 1; j++)
     {
       gdouble u2 = ncm_vector_get (cad->inv_lnM->xv, j);
@@ -780,8 +777,8 @@ nc_cluster_abundance_prepare_inv_dNdz (NcClusterAbundance *cad, NcHICosmo *cosmo
     ncm_matrix_set (cad->inv_lnM_z->zm, middle, j, cad->lnMf);
   }
 
-  nc_cluster_abundance_prepare_inv_dNdlnM_z (cad, cosmo, z0);
-  ncm_matrix_set (cad->inv_lnM_z->zm, 0, 0, cad->lnMi);
+  nc_cluster_abundance_prepare_inv_dNdlnM_z (cad, cosmo, lnMi, z0);
+  ncm_matrix_set (cad->inv_lnM_z->zm, 0, 0, lnMi);
 
   for (j = 1; j < ncm_vector_len(cad->inv_lnM_z->xv) - 1; j++)
   {
@@ -801,13 +798,13 @@ nc_cluster_abundance_prepare_inv_dNdz (NcClusterAbundance *cad, NcHICosmo *cosmo
       gdouble z1 = cad->zi + delta_z * i;
       if (nztot < 0.99)
       {
-        gdouble delta = nc_mass_function_n (cad->mfp, cosmo, cad->lnMi, cad->lnMf, z0, z1, sp_optimize) / cad->norma;
+        gdouble delta = nc_halo_mass_function_n (cad->mfp, cosmo, lnMi, cad->lnMf, z0, z1, sp_optimize) / norma;
         nztot += fabs (delta);
         f = _nc_cad_inv_dNdz_convergence_f (nztot, cad->z_epsilon);
       }
       else
       {
-        gdouble onemn = nc_mass_function_n (cad->mfp, cosmo, cad->lnMi, cad->lnMf, z1, cad->zf, sp_optimize) / cad->norma;
+        gdouble onemn = nc_halo_mass_function_n (cad->mfp, cosmo, lnMi, cad->lnMf, z1, cad->zf, sp_optimize) / norma;
         gdouble f_try = _nc_cad_inv_dNdz_convergence_f_onemn (onemn, cad->z_epsilon);
         if (f_try < f)
           f = f * (1.0 + GSL_SIGN (f) * 0.01);
@@ -821,9 +818,9 @@ nc_cluster_abundance_prepare_inv_dNdz (NcClusterAbundance *cad, NcHICosmo *cosmo
       if (i == middle)
         continue;
 
-      nc_cluster_abundance_prepare_inv_dNdlnM_z (cad, cosmo, z1);
+      nc_cluster_abundance_prepare_inv_dNdlnM_z (cad, cosmo, lnMi, z1);
 
-      ncm_matrix_set (cad->inv_lnM_z->zm, i, 0, cad->lnMi);
+      ncm_matrix_set (cad->inv_lnM_z->zm, i, 0, lnMi);
       for (j = 1; j < ncm_vector_len(cad->inv_lnM_z->xv) - 1; j++)
       {
         gdouble u2 = ncm_vector_get (cad->inv_lnM_z->xv, j);
@@ -839,9 +836,10 @@ nc_cluster_abundance_prepare_inv_dNdz (NcClusterAbundance *cad, NcHICosmo *cosmo
 
 /**
  * nc_cluster_abundance_prepare_inv_dNdlnM_z:
- * @cad: a #NcClusterAbundance.
- * @cosmo: a #NcHICosmo.
- * @z: redshift.
+ * @cad: a #NcClusterAbundance
+ * @cosmo: a #NcHICosmo
+ * @lnMi: logarithm base e of the minimum mass $\ln(M_i)$
+ * @z: redshift $z$
  *
  * This function prepares a spline where the x array corresponds to the value
  * of $\int_{\ln M_0} ^{\ln M_1} d^2N/dzd\ln M dM/ \int_lnMi^lnMf dN/dz dM$ given a redshift $z$
@@ -850,15 +848,14 @@ nc_cluster_abundance_prepare_inv_dNdz (NcClusterAbundance *cad, NcHICosmo *cosmo
  *
  */
 void
-nc_cluster_abundance_prepare_inv_dNdlnM_z (NcClusterAbundance *cad, NcHICosmo *cosmo, gdouble z)
+nc_cluster_abundance_prepare_inv_dNdlnM_z (NcClusterAbundance *cad, NcHICosmo *cosmo, const gdouble lnMi, gdouble z)
 {
   gboolean use_spline = FALSE;
-  gdouble dNdz = nc_mass_function_dn_dz (cad->mfp, cosmo, cad->lnMi, cad->lnMf, z, use_spline);
-  gdouble lnM0 = cad->lnMi;
+  gdouble dNdz = nc_halo_mass_function_dn_dz (cad->mfp, cosmo, lnMi, cad->lnMf, z, use_spline);
+  gdouble lnM0 = lnMi;
   gdouble ntot = 0.0;
   gdouble f = _nc_cad_inv_dNdz_convergence_f (0.0, cad->lnM_epsilon);
-  gdouble Delta;
-  const gdouble dlnM = (cad->lnMf - cad->lnMi) / (cad->inv_lnM->len - 1.0);
+  const gdouble dlnM = (cad->lnMf - lnMi) / (cad->inv_lnM->len - 1.0);
   guint i;
 
   g_assert (z > 0.0);
@@ -868,17 +865,18 @@ nc_cluster_abundance_prepare_inv_dNdlnM_z (NcClusterAbundance *cad, NcHICosmo *c
 
   for (i = 1; i < cad->inv_lnM->len; i++)
   {
-    gdouble lnM1 = cad->lnMi + dlnM * i;
+    const gdouble lnM1 = lnMi + dlnM * i;
     if (ntot < 0.99)
     {
-      Delta = nc_mass_function_dn_dz (cad->mfp, cosmo, lnM0, lnM1, z, use_spline) / dNdz;
+      const gdouble Delta = nc_halo_mass_function_dn_dz (cad->mfp, cosmo, lnM0, lnM1, z, use_spline) / dNdz;
       ntot += fabs (Delta);
       f = _nc_cad_inv_dNdz_convergence_f (ntot, cad->lnM_epsilon);
     }
     else
     {
-      gdouble onemn = nc_mass_function_dn_dz (cad->mfp, cosmo, lnM1, cad->lnMf, z, use_spline) / dNdz;
-      gdouble f_try = _nc_cad_inv_dNdz_convergence_f_onemn (fabs (onemn), cad->lnM_epsilon);
+      const gdouble onemn = nc_halo_mass_function_dn_dz (cad->mfp, cosmo, lnM1, cad->lnMf, z, use_spline) / dNdz;
+      const gdouble f_try = _nc_cad_inv_dNdz_convergence_f_onemn (fabs (onemn), cad->lnM_epsilon);
+
       if (f_try < f)
         f = f * (1.0 + GSL_SIGN (f) * 0.01);
       else
@@ -909,7 +907,7 @@ nc_cluster_abundance_true_n (NcClusterAbundance *cad, NcHICosmo *cosmo, NcCluste
 {
   NCM_UNUSED (clusterz);
   NCM_UNUSED (clusterm);
-  return nc_mass_function_n (cad->mfp, cosmo, cad->lnMi, cad->lnMf, cad->zi, cad->zf, NC_MASS_FUNCTION_SPLINE_LNM);
+  return nc_halo_mass_function_n (cad->mfp, cosmo, cad->lnMi, cad->lnMf, cad->zi, cad->zf, NC_HALO_MASS_FUNCTION_SPLINE_LNM);
 }
 
 /**
@@ -1110,7 +1108,7 @@ _nc_ca_mean_bias_denominator_integrand (gdouble lnM, gpointer params)
   observables_integrand_data *obs_data = (observables_integrand_data *) params;
   NcClusterAbundance *cad = obs_data->cad;
 
-  gdouble n = nc_mass_function_dn_dlnm (cad->mfp, obs_data->cosmo, lnM, obs_data->z);
+  gdouble n = nc_halo_mass_function_dn_dlnM (cad->mfp, obs_data->cosmo, lnM, obs_data->z);
 
   //printf ("% 20.8e % 20.8g % 20.15g\n", obs_data->lnMobs, obs_data->zp, dbdlnM);
   return n;
@@ -1133,8 +1131,6 @@ nc_ca_mean_bias_denominator (NcClusterAbundance *cad, NcHICosmo *cosmo, gdouble
     gdouble lnMf = cad->lnMf;
     obs_data.z = z;
     obs_data.lnM = lnM;
-    //printf ("%5.5e, %5.5e\n", exp(lnM), exp(lnMf));
-
     {
       gsl_integration_workspace **w = ncm_integral_get_workspace ();
       gsl_integration_qag (&F, lnM, lnMf, 0.0, NCM_DEFAULT_PRECISION, NCM_INTEGRAL_PARTITION, _NC_CLUSTER_ABUNDANCE_DEFAULT_INT_KEY, *w, &res, &err);
@@ -1149,12 +1145,10 @@ nc_ca_mean_bias_denominator (NcClusterAbundance *cad, NcHICosmo *cosmo, gdouble
 gdouble
 nc_ca_mean_bias (NcClusterAbundance *cad, NcHICosmo *cosmo, gdouble lnM, gdouble z)
 {
-  //gdouble M1 = exp(lnM);
   gdouble numerator = nc_ca_mean_bias_numerator (cad, cosmo, lnM, z);
   gdouble denominator = nc_ca_mean_bias_denominator (cad, cosmo, lnM, z);
   gdouble mean_bias = numerator / denominator;
 
-  //printf ("M1 = %5.5e num = %10.5g den = %10.5g\n", M1, numerator, denominator);
   return mean_bias;
 }
 
@@ -1168,7 +1162,7 @@ _nc_ca_mean_bias_Mobs_numerator_integrand (gdouble lnMobs, gpointer params)
   gdouble p_M_Mobs = 0.0;//_nc_cluster_abundance_lognormal_mass_dist (obs_data, lnMobs);
   gdouble dbdlnM = nc_halo_bias_func_integrand (cad->mbiasf, obs_data->cosmo, lnMobs, obs_data->z);
   g_assert_not_reached ();
-  //printf ("% 20.8e % 20.8g % 20.15g % 20.15g % 20.15g\n", obs_data->lnMobs, obs_data->zp, p_M_Mobs, dbdlnM, p_M_Mobs * dbdlnM);
+
   return dbdlnM * p_M_Mobs;
 }
 
@@ -1216,10 +1210,9 @@ _nc_ca_mean_bias_Mobs_denominator_integrand (gdouble lnMobs, gpointer params)
 
   /* In this case zp is the true redshift, i.e., without uncertainty. */
   gdouble p_M_Mobs = 0.0;//_nc_cluster_abundance_lognormal_mass_dist (obs_data, lnMobs);
-  gdouble n = nc_mass_function_dn_dlnm (cad->mfp, obs_data->cosmo, lnMobs, obs_data->z);
+  gdouble n = nc_halo_mass_function_dn_dlnM (cad->mfp, obs_data->cosmo, lnMobs, obs_data->z);
   g_assert_not_reached ();
 
-  //printf ("% 20.8e % 20.8g % 20.15g\n", obs_data->lnMobs, obs_data->zp, n * p_M_Mobs);
   return n * p_M_Mobs;
 }
 
@@ -1262,7 +1255,6 @@ nc_ca_mean_bias_Mobs_denominator (NcClusterAbundance *cad, NcHICosmo *cosmo, gdo
 /**
  * nc_cluster_abundance_prepare_if_needed:
  * @cad: a #NcClusterAbundance
- * @reion: a #NcHIReion
  * @cosmo: a #NcHICosmo
  * @clusterz: a #NcClusterRedshift
  * @clusterm: a #NcClusterMass
