@@ -24,8 +24,8 @@
 
 /**
  * SECTION:nc_cluster_photoz_gauss
- * @title: Individual Gaussian Photoz Cluster
- * @short_description: Gaussian photometric redshift
+ * @title: NcClusterPhotozGauss
+ * @short_description: Individual gaussian photometric distribution for clusters.
  *
  * FIXME
  */
@@ -36,7 +36,10 @@
 #include "build_cfg.h"
 
 #include "lss/nc_cluster_photoz_gauss.h"
+#include "math/ncm_data.h"
+#include "math/ncm_rng.h"
 #include "math/ncm_cfg.h"
+
 #include <math.h>
 #include <gsl/gsl_randist.h>
 #include <gsl/gsl_math.h>
@@ -48,6 +51,7 @@ enum
   PROP_0,
   PROP_PZ_MIN,
   PROP_PZ_MAX,
+  PROP_SIZE
 };
 
 /**
@@ -72,6 +76,9 @@ _nc_cluster_photoz_gauss_p (NcClusterRedshift *clusterz, gdouble lnM, gdouble z,
   const gdouble sqrt2_sigma = M_SQRT2 * sigma;
   const gdouble y1 = (z_obs[0] - z_eff) / sqrt2_sigma;
 
+  NCM_UNUSED (clusterz);
+  NCM_UNUSED (lnM);
+
   return M_2_SQRTPI / M_SQRT2 * exp (- y1 * y1) / (sigma * (1.0 + erf ( z_eff / sqrt2_sigma )));
 }
 
@@ -84,33 +91,38 @@ _nc_cluster_photoz_gauss_intp (NcClusterRedshift *clusterz, gdouble lnM, gdouble
   const gdouble x_min = (z - pzg->pz_min) / sqrt2_sigma;
   const gdouble x_max = (z - pzg->pz_max) / sqrt2_sigma;
 
+  NCM_UNUSED (lnM);
+
   if (x_max > 4.0)
   {
-	return -(erfc (x_min) - erfc (x_max)) / 
-	  (1.0 + erf ( z / sqrt2_sigma ));
+    return -(erfc (x_min) - erfc (x_max)) / 
+      (1.0 + erf ( z / sqrt2_sigma ));
   }
   else
   {
-	return (erf (x_min) - erf (x_max)) / 
-	  (1.0 + erf ( z / sqrt2_sigma ));
+    return (erf (x_min) - erf (x_max)) / 
+      (1.0 + erf ( z / sqrt2_sigma ));
   }
 }
 
 static gboolean
-_nc_cluster_photoz_gauss_resample (NcClusterRedshift *clusterz, gdouble lnM, gdouble z, gdouble *z_obs, gdouble *z_obs_params)
+_nc_cluster_photoz_gauss_resample (NcClusterRedshift *clusterz, gdouble lnM, gdouble z, gdouble *z_obs, gdouble *z_obs_params, NcmRNG *rng)
 {
   NcClusterPhotozGauss *pzg = NC_CLUSTER_PHOTOZ_GAUSS (clusterz);
-  gsl_rng *rng = ncm_cfg_rng_get ();
   gdouble sigma_z;
 
+  NCM_UNUSED (lnM);
+  
   z_obs_params[NC_CLUSTER_PHOTOZ_GAUSS_BIAS] = 0.0;
   z_obs_params[NC_CLUSTER_PHOTOZ_GAUSS_SIGMA] = 0.03 * (1.0 + z);
 
   sigma_z = z_obs_params[NC_CLUSTER_PHOTOZ_GAUSS_SIGMA];
 
+  ncm_rng_lock (rng);
   do {
-	z_obs[0] = z + z_obs_params[NC_CLUSTER_PHOTOZ_GAUSS_BIAS] + gsl_ran_gaussian (rng, sigma_z);
+    z_obs[0] = z + z_obs_params[NC_CLUSTER_PHOTOZ_GAUSS_BIAS] + gsl_ran_gaussian (rng->r, sigma_z);
   } while (z_obs[0] < 0);
+  ncm_rng_unlock (rng);
 
   return (z_obs[0] <= pzg->pz_max) && (z_obs[0] >= pzg->pz_min);
 }
@@ -122,6 +134,8 @@ _nc_cluster_photoz_gauss_p_limits (NcClusterRedshift *clusterz, gdouble *z_obs,
   const gdouble zl = GSL_MAX (mean - 10.0 * z_obs_params[NC_CLUSTER_PHOTOZ_GAUSS_SIGMA], 0.0);
   const gdouble zu = mean + 10.0 * z_obs_params[NC_CLUSTER_PHOTOZ_GAUSS_SIGMA];
 
+  NCM_UNUSED (clusterz);
+  
   *z_lower = zl;
   *z_upper = zu;
 
@@ -141,8 +155,8 @@ _nc_cluster_photoz_gauss_n_limits (NcClusterRedshift *clusterz, gdouble *z_lower
   return;
 }
 
-guint _nc_cluster_photoz_gauss_obs_len (NcClusterRedshift *clusterz) { return 1; }
-guint _nc_cluster_photoz_gauss_obs_params_len (NcClusterRedshift *clusterz) { return 2; }
+guint _nc_cluster_photoz_gauss_obs_len (NcClusterRedshift *clusterz) { NCM_UNUSED (clusterz); return 1; }
+guint _nc_cluster_photoz_gauss_obs_params_len (NcClusterRedshift *clusterz) { NCM_UNUSED (clusterz); return 2; }
 
 static void
 nc_cluster_photoz_gauss_init (NcClusterPhotozGauss *pzg)
@@ -170,7 +184,7 @@ _nc_cluster_photoz_gauss_set_property (GObject * object, guint prop_id, const GV
     case PROP_PZ_MIN:
       pzg->pz_min = g_value_get_double (value);
       break;
-	case PROP_PZ_MAX:
+    case PROP_PZ_MAX:
       pzg->pz_max = g_value_get_double (value);
       break;
     default:
@@ -190,7 +204,7 @@ _nc_cluster_photoz_gauss_get_property (GObject *object, guint prop_id, GValue *v
     case PROP_PZ_MIN:
       g_value_set_double (value, pzg->pz_min);
       break;
-	case PROP_PZ_MAX:
+    case PROP_PZ_MAX:
       g_value_set_double (value, pzg->pz_max);
       break;
     default:
@@ -204,6 +218,7 @@ nc_cluster_photoz_gauss_class_init (NcClusterPhotozGaussClass *klass)
 {
   GObjectClass* object_class = G_OBJECT_CLASS (klass);
   NcClusterRedshiftClass* parent_class = NC_CLUSTER_REDSHIFT_CLASS (klass);
+  NcmModelClass *model_class = NCM_MODEL_CLASS (klass);
 
   parent_class->P              = &_nc_cluster_photoz_gauss_p;
   parent_class->intP           = &_nc_cluster_photoz_gauss_intp;
@@ -216,9 +231,13 @@ nc_cluster_photoz_gauss_class_init (NcClusterPhotozGaussClass *klass)
   parent_class->impl = NC_CLUSTER_REDSHIFT_IMPL_ALL;
 
   object_class->finalize = _nc_cluster_photoz_gauss_finalize;
-  object_class->set_property = _nc_cluster_photoz_gauss_set_property;
-  object_class->get_property = _nc_cluster_photoz_gauss_get_property;
 
+  model_class->set_property = _nc_cluster_photoz_gauss_set_property;
+  model_class->get_property = _nc_cluster_photoz_gauss_get_property;
+
+  ncm_model_class_set_name_nick (model_class, "Gaussian distribution", "Gaussian");
+  ncm_model_class_add_params (model_class, 0, 0, PROP_SIZE);
+  
   /**
    * NcClusterPhotozGauss:pz_min:
    *
@@ -244,4 +263,7 @@ nc_cluster_photoz_gauss_class_init (NcClusterPhotozGaussClass *klass)
                                                         "Maximum photoz",
                                                         0.0, G_MAXDOUBLE, 0.0,
                                                         G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY |G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
+
+  /* Check for errors in parameters initialization */
+  ncm_model_class_check_params_info (model_class);
 }
