@@ -41,7 +41,6 @@
 #include "math/ncm_cfg.h"
 #include "math/integral.h"
 #include "math/memory_pool.h"
-#include "levmar/levmar.h"
 
 #include <gsl/gsl_roots.h>
 
@@ -64,7 +63,8 @@ static void
 nc_cluster_pseudo_counts_init (NcClusterPseudoCounts *cpc)
 {
   cpc->nclusters = 1;
-  cpc->workz     = g_new0 (gdouble, LM_BC_DER_WORKSZ (3, 5));
+  cpc->T = gsl_multifit_fdfsolver_lmsder;
+  cpc->s = gsl_multifit_fdfsolver_alloc (cpc->T, 4, 2);
 }
 
 static void
@@ -113,6 +113,8 @@ _nc_cluster_pseudo_counts_dispose (GObject *object)
 static void
 _nc_cluster_pseudo_counts_finalize (GObject *object)
 {
+  NcClusterPseudoCounts *cpc = NC_CLUSTER_PSEUDO_COUNTS (object);
+  gsl_multifit_fdfsolver_free (cpc->s);
   
   /* Chain up : end */
   G_OBJECT_CLASS (nc_cluster_pseudo_counts_parent_class)->finalize (object);
@@ -148,18 +150,19 @@ nc_cluster_pseudo_counts_class_init (NcClusterPseudoCountsClass *klass)
                                                       G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
   
   /**
-   * NcClusterPseudoCounts:lnMcut:
+   * NcClusterPseudoCounts:lnMCut:
    * 
-   * Logarithm base e of the lower mass cut-off, $\ln (M_{CUT}) \in [12.0 \ln(10), 16.0 \ln(10)]$.
+   * Logarithm base e of the lower mass cut-off, 
+   * $\ln M_{CUT} \in [12.0 \ln(10), 16.0 \ln(10)]$. 
    *  
    */
   /**
-   * NcClusterPseudoCounts:lnMcut-fit:
+   * NcClusterPseudoCounts:lnMCut-fit:
    * 
    * FIXME
    *  
    */
-  ncm_model_class_set_sparam (model_class, NC_CLUSTER_PSEUDO_COUNTS_LNMCUT, "\\ln(M_{CUT})", "lnMcut",
+  ncm_model_class_set_sparam (model_class, NC_CLUSTER_PSEUDO_COUNTS_LNMCUT, "\\ln{M_{CUT}}", "lnMCut",
                               12.0 * M_LN10, 16.0 * M_LN10, 2.0,
                               NC_CLUSTER_PSEUDO_COUNTS_DEFAULT_PARAMS_ABSTOL, NC_CLUSTER_PSEUDO_COUNTS_DEFAULT_LNMCUT,
                               NCM_PARAM_TYPE_FIXED);
@@ -198,7 +201,8 @@ nc_cluster_pseudo_counts_class_init (NcClusterPseudoCountsClass *klass)
                               "NcClusterPseudoCounts",
                               "Galaxy cluster observable: pseudo number counts.",
                               NULL,
-                              FALSE);
+                              FALSE,
+                              NCM_MSET_MODEL_MAIN);
 }
 
 /**
@@ -265,7 +269,7 @@ nc_cluster_pseudo_counts_clear (NcClusterPseudoCounts **cpc)
 typedef struct _integrand_data
 {
   NcClusterPseudoCounts *cpc;
-  NcMassFunction *mfp;
+  NcHaloMassFunction *mfp;
   NcClusterMass *clusterm;
   NcHICosmo *cosmo;
   gdouble z;
@@ -274,13 +278,16 @@ typedef struct _integrand_data
   gdouble peak[3];
   gdouble func_peak;
   gdouble lnM_M0;
+  gdouble lnMsz_M0;
+  gdouble lnMl_M0;
   gdouble lnM0;
 } integrand_data;
 
 /**
  * nc_cluster_pseudo_counts_posterior_ndetone:
  * @cpc: a #NcClusterPseudoCounts
- * @mfp: a @NcMassFunction
+ * @mfp: a @NcHaloMassFunction
+ * @cosmo: a @NcHICosmo
  * @clusterm: a #NcClusterMass
  * @z: redshift
  * @Mpl: Planck cluster mass
@@ -297,9 +304,11 @@ typedef struct _integrand_data
  * Returns: FIXME
 */
 gdouble
-nc_cluster_pseudo_counts_posterior_ndetone (NcClusterPseudoCounts *cpc, NcMassFunction *mfp, NcClusterMass *clusterm, gdouble z, gdouble Mpl, gdouble Mcl, gdouble sigma_pl, gdouble sigma_cl)
+nc_cluster_pseudo_counts_posterior_ndetone (NcClusterPseudoCounts *cpc, NcHaloMassFunction *mfp, NcHICosmo *cosmo, NcClusterMass *clusterm, gdouble z, gdouble Mpl, gdouble Mcl, gdouble sigma_pl, gdouble sigma_cl)
 {
   g_assert (NC_IS_CLUSTER_MASS_PLCL (clusterm));
+  //gdouble lnEz = 0.0; //log (nc_hicosmo_E (cosmo, z));
+  //gdouble lnMcut = _lnMcut_from_lnTstar_cut (LNMCUT, lnEz);
   
   return nc_cluster_mass_plcl_Msz_Ml_p_ndetone (clusterm, LNMCUT, z, Mpl, Mcl, sigma_pl, sigma_cl);
 }
@@ -307,11 +316,12 @@ nc_cluster_pseudo_counts_posterior_ndetone (NcClusterPseudoCounts *cpc, NcMassFu
 static gdouble
 _selection_function (NcClusterPseudoCounts *cpc, gdouble lnM500)
 {
-  const gdouble sqrt2_sdcut = sqrt(2) * SD_MCUT;
-  const gdouble difM = lnM500 - LNMCUT;
+  const gdouble sqrt2       = sqrt (2.0);
+  const gdouble sqrt2_sdcut = sqrt2 * SD_MCUT;
+  gdouble difM = lnM500 - LNMCUT;
 
   if (difM < 0.0)
-    return 0.5 * erfc (fabs(difM) / sqrt2_sdcut);
+    return 0.5 * erfc (fabs (difM) / sqrt2_sdcut);
   else
     return 0.5 * (1.0 + erf (difM / sqrt2_sdcut));
 }
@@ -320,15 +330,36 @@ _selection_function (NcClusterPseudoCounts *cpc, gdouble lnM500)
  * nc_cluster_pseudo_counts_selection_function:
  * @cpc: a #NcClusterPseudoCounts
  * @lnM: logarithm base e of the true mass 
+ * @z: true redshift
  *
  * This function computes the selection function (include equation). FIXME 
  *
  * Returns: FIXME
-*/
+ */
 gdouble 
-nc_cluster_pseudo_counts_selection_function (NcClusterPseudoCounts *cpc, gdouble lnM)
+nc_cluster_pseudo_counts_selection_function (NcClusterPseudoCounts *cpc, gdouble lnM, gdouble z)
 {
-  return _selection_function (cpc, lnM);
+  if (z < ZMIN || z > (ZMIN + DELTAZ))
+    return 0.0;
+  else 
+    return _selection_function (cpc, lnM);
+}
+
+/**
+ * nc_cluster_pseudo_counts_selection_function_lnMi:
+ * @cpc: a #NcClusterPseudoCounts
+ * @cosmo: a #NcHICosmo
+ *
+ * This function computes the lower mass threshold used in the resample function, namely, $l\ln M_i = lnM_{cut} - 6\sigma_{cut}$.  
+ *
+ * Returns: $\ln M_i$
+ */
+gdouble
+nc_cluster_pseudo_counts_selection_function_lnMi (NcClusterPseudoCounts *cpc, NcHICosmo *cosmo)
+{
+  gdouble lnMi = LNMCUT - 6.0 * SD_MCUT;
+
+  return lnMi;
 }
 
 static gdouble
@@ -336,8 +367,8 @@ _Ndet_wout_volume_integrand (gdouble lnM500, gpointer userdata)
 {
   integrand_data *data = (integrand_data *) userdata;
   NcClusterPseudoCounts *cpc = data->cpc;
-  gdouble sf = _selection_function (cpc,  lnM500);
-  gdouble mf = nc_mass_function_dn_dlnm (data->mfp, data->cosmo, lnM500, data->z);
+  gdouble sf = nc_cluster_pseudo_counts_selection_function (cpc, lnM500, data->z);
+  gdouble mf = nc_halo_mass_function_dn_dlnM (data->mfp, data->cosmo, lnM500, data->z);
 
   gdouble result = sf * mf;
   //printf("M = %.5g sf = %.5g mfp = %.5g result = %.5g\n", exp(lnM500), sf, mf, result);
@@ -364,10 +395,10 @@ nc_cluster_pseudo_counts_ndet_no_z_integral (NcClusterPseudoCounts *cpc, NcHICos
   gsl_function F;
   gsl_integration_workspace **w = ncm_integral_get_workspace ();
   
-  data.cpc =   cpc;
+  data.cpc   = cpc;
   data.cosmo = cosmo;
-  data.z = z;
-
+  data.z     = z;
+  
   F.function = _Ndet_wout_volume_integrand;
   F.params = &data;
 
@@ -383,8 +414,8 @@ _Ndet_integrand (gdouble lnM500, gdouble z, gpointer userdata)
 {
   integrand_data *data       = (integrand_data *) userdata;
   NcClusterPseudoCounts *cpc = data->cpc;
-  const gdouble sf     = _selection_function (cpc,  lnM500);
-  const gdouble result = sf * nc_mass_function_d2n_dzdlnm (data->mfp, data->cosmo, lnM500, z);
+  const gdouble sf     = nc_cluster_pseudo_counts_selection_function (cpc, lnM500, z);
+  const gdouble result = sf * nc_halo_mass_function_d2n_dzdlnM (data->mfp, data->cosmo, lnM500, z);
   
   return result;
 }
@@ -392,7 +423,7 @@ _Ndet_integrand (gdouble lnM500, gdouble z, gpointer userdata)
 /**
  * nc_cluster_pseudo_counts_ndet:
  * @cpc: a #NcClusterPseudoCounts
- * @mfp: a #NcMassFunction
+ * @mfp: a #NcHaloMassFunction
  * @cosmo: a #NcHICosmo 
  *
  * FIXME
@@ -400,7 +431,7 @@ _Ndet_integrand (gdouble lnM500, gdouble z, gpointer userdata)
  * Returns: FIXME
 */
 gdouble 
-nc_cluster_pseudo_counts_ndet (NcClusterPseudoCounts *cpc, NcMassFunction *mfp, NcHICosmo *cosmo)
+nc_cluster_pseudo_counts_ndet (NcClusterPseudoCounts *cpc, NcHaloMassFunction *mfp, NcHICosmo *cosmo)
 {
   integrand_data data;
   gdouble P, err;
@@ -423,7 +454,6 @@ nc_cluster_pseudo_counts_ndet (NcClusterPseudoCounts *cpc, NcMassFunction *mfp,
   ncm_integrate_2dim (&integ, lnM_min, z_min, lnM_max, z_max, NCM_DEFAULT_PRECISION, 0.0, &P, &err);
   ncm_spline2d_use_acc (mfp->d2NdzdlnM, FALSE);
 
-  
   return P;
 }
 
@@ -432,14 +462,14 @@ _posterior_numerator_integrand (gdouble lnM, gpointer userdata)
 {
   integrand_data *data = (integrand_data *) userdata;
   NcClusterPseudoCounts *cpc = data->cpc;
-  const gdouble sf = _selection_function (cpc,  lnM);
+  const gdouble sf = nc_cluster_pseudo_counts_selection_function (cpc, lnM, data->z);
   const gdouble small = exp (-200.0);
   
   if (sf == 0.0)
     return small;
   else
   {
-    const gdouble mf = nc_mass_function_d2n_dzdlnm (data->mfp, data->cosmo, lnM, data->z);
+    const gdouble mf = nc_halo_mass_function_d2n_dzdlnM (data->mfp, data->cosmo, lnM, data->z);
     const gdouble pdf_Mobs_Mtrue = nc_cluster_mass_p (data->clusterm, data->cosmo, lnM, data->z, data->Mobs, data->Mobs_params);
     const gdouble result = sf * mf * pdf_Mobs_Mtrue + small;
 
@@ -450,7 +480,7 @@ _posterior_numerator_integrand (gdouble lnM, gpointer userdata)
 /**
  * nc_cluster_pseudo_counts_posterior_numerator:
  * @cpc: a #NcClusterPseudoCounts
- * @mfp: a #NcMassFunction
+ * @mfp: a #NcHaloMassFunction
  * @clusterm: a #NcClusterMass
  * @cosmo: a #NcHICosmo 
  * @z: spectroscopic redshift
@@ -462,7 +492,7 @@ _posterior_numerator_integrand (gdouble lnM, gpointer userdata)
  * Returns: FIXME
 */
 gdouble
-nc_cluster_pseudo_counts_posterior_numerator (NcClusterPseudoCounts *cpc, NcMassFunction *mfp, NcClusterMass *clusterm, NcHICosmo *cosmo, const gdouble z, const gdouble *Mobs, const gdouble *Mobs_params)
+nc_cluster_pseudo_counts_posterior_numerator (NcClusterPseudoCounts *cpc, NcHaloMassFunction *mfp, NcClusterMass *clusterm, NcHICosmo *cosmo, const gdouble z, const gdouble *Mobs, const gdouble *Mobs_params)
 {
   integrand_data data;
   gdouble P, err;
@@ -498,90 +528,178 @@ nc_cluster_pseudo_counts_posterior_numerator (NcClusterPseudoCounts *cpc, NcMass
   }
 }
 
+static gdouble
+_massfunc_lognormal_integrand (gdouble lnM, gpointer userdata)
+{
+  integrand_data *data = (integrand_data *) userdata;
+  //NcClusterPseudoCounts *cpc = data->cpc;
+  //const gdouble sf = nc_cluster_pseudo_counts_selection_function (cpc, lnM, data->z);
+  const gdouble small = exp (-200.0);
+  
+  const gdouble mf = nc_halo_mass_function_d2n_dzdlnM (data->mfp, data->cosmo, lnM, data->z);
+  const gdouble pdf_lognormal = nc_cluster_mass_plcl_pdf_only_lognormal (data->clusterm, lnM, data->lnMsz_M0, data->lnMl_M0);
+  const gdouble result = mf * pdf_lognormal + small; //sf * mf * pdf_Mobs_Mtrue + small;
+
+  return result;    
+   
+}
+
+/**
+ * nc_cluster_pseudo_counts_mf_lognormal_integral:
+ * @cpc: a #NcClusterPseudoCounts
+ * @mfp: a #NcHaloMassFunction
+ * @clusterm: a #NcClusterMass
+ * @cosmo: a #NcHICosmo
+ * @lnMsz: logarithm base e of SZ mass
+ * @lnMl: logarithm base e of lensing mass
+ * @z: spectroscopic redshift
+ *
+ * FIXME
+ *
+ * Returns: FIXME
+*/
+gdouble
+nc_cluster_pseudo_counts_mf_lognormal_integral (NcClusterPseudoCounts *cpc, NcHaloMassFunction *mfp, NcClusterMass *clusterm, NcHICosmo *cosmo, const gdouble lnMsz, const gdouble lnMl, const gdouble z)
+{
+  integrand_data data;
+  gdouble P, err;
+  const gdouble lnM0 = log (5.7e14);
+
+  if (z < ZMIN || z > (ZMIN + DELTAZ))
+    return 0.0;
+  else
+  {
+    gsl_function F;
+    gsl_integration_workspace **w = ncm_integral_get_workspace ();
+
+    data.cpc      = cpc;
+    data.mfp      = mfp;
+    data.clusterm = clusterm;
+    data.cosmo    = cosmo;
+    data.z        = z;
+    data.lnM0     = lnM0;
+    data.lnMsz_M0 = lnMsz - data.lnM0;
+    data.lnMl_M0  = lnMl - data.lnM0;
+
+    F.function = &_massfunc_lognormal_integrand;
+    F.params = &data;
+
+    //printf ("z = %.5g lnMsz = %.5g lnMsz_M0 = %.5g lnMl = %.5g lnMl_M0 = %.5g\n", data.z, lnMsz, data.lnMsz_M0, lnMl, data.lnMl_M0);
+    {
+      gdouble lnM_min, lnM_max;
+      lnM_min = log (1.0e12); //32.292; //    
+      lnM_max = log (1.0e16); //34.561; //log (1.0e16);     
+      gsl_integration_qag (&F, lnM_min, lnM_max, 0.0, 1.0e2 * NCM_DEFAULT_PRECISION, NCM_INTEGRAL_PARTITION, 6, *w, &P, &err);
+    }
+
+    ncm_memory_pool_return (w);
+    /*printf ("numerator = %.8g err = %.8g\n", P, err / P);*/
+    return P;
+  }
+}
+
 /* 3-dimensional integration: real, SZ and Lensing masses*/
 
-static void
-_nc_cluster_pseudo_counts_levmar_f (gdouble *p, gdouble *hx, gint m, gint n, gpointer adata)
+static gint
+_nc_cluster_pseudo_counts_gsl_f (const gsl_vector *p, gpointer adata, gsl_vector *hx)
 {
   integrand_data *data    = (integrand_data *) adata;
   NcClusterMass *clusterm = data->clusterm;
   NcClusterMassPlCL *mszl = NC_CLUSTER_MASS_PLCL (clusterm);
-  const gint m1 = m;
-  const gint n1 = n;
-  
-  nc_cluster_mass_plcl_levmar_f_new_variables (p, hx, m1, n1, mszl, data->lnM_M0, data->Mobs, data->Mobs_params);
+
+  nc_cluster_mass_plcl_gsl_f_new_variables ( p, hx, mszl, data->lnM_M0, data->Mobs, data->Mobs_params);
+  return GSL_SUCCESS;
 }
 
-static void
-_nc_cluster_pseudo_counts_levmar_J (gdouble *p, gdouble *J, gint m, gint n, gpointer adata)
+static gint
+_nc_cluster_pseudo_counts_gsl_J (const gsl_vector *p, void *adata, gsl_matrix *J)
 {
   integrand_data *data    = (integrand_data *) adata;
   NcClusterMass *clusterm = data->clusterm;
   NcClusterMassPlCL *mszl = NC_CLUSTER_MASS_PLCL (clusterm); 
-  const gint m1 = m;
-  const gint n1 = n;
   
-  nc_cluster_mass_plcl_levmar_J_new_variables (p, J, m1, n1, mszl, data->lnM_M0, data->Mobs, data->Mobs_params);
+  nc_cluster_mass_plcl_gsl_J_new_variables (p, J, mszl, data->lnM_M0, data->Mobs, data->Mobs_params);
+  return GSL_SUCCESS;
 }
 
+
 static void
-peakfinder (gdouble lnM_M0, gdouble p0[], const gint *ndim, const gdouble bounds[], gint *n, gdouble x[], void *userdata)
+_peakfinder (gdouble lnM_M0, gdouble p0[], const gint *ndim, const gdouble bounds[], gint *n, gdouble x[], void *userdata)
 {
   integrand_data *data = (integrand_data *) userdata;
   NcClusterPseudoCounts *cpc = data->cpc;
   NcClusterMass *clusterm = data->clusterm;
+  gsl_multifit_function_fdf f;
+  gint status, info;
+  
   gdouble lb[] = {bounds[0], bounds[2]};
   gdouble ub[] = {bounds[1], bounds[3]};
-  gdouble info[LM_INFO_SZ];
-  gdouble opts[LM_OPTS_SZ];
-  gint ret;
 
+  const gdouble xtol = 1e-8;
+  const gdouble gtol = 1e-8;
+  const gdouble ftol = 0.0;
+  
   p0[0] = log (data->Mobs[NC_CLUSTER_MASS_PLCL_MPL]);
   p0[1] = log (data->Mobs[NC_CLUSTER_MASS_PLCL_MCL]);
   
   data->lnM_M0 = lnM_M0;
   
   g_assert (NC_IS_CLUSTER_MASS_PLCL (clusterm));
-  opts[0] = LM_INIT_MU; 
-  opts[1] = 1.0e-7; 
-  opts[2] = 1.0e-7;
-  opts[3] = 1.0e-7;
   
+  /*printf ("% 20.15g % 20.15g\n", data->Mobs[NC_CLUSTER_MASS_PLCL_MPL], data->Mobs[NC_CLUSTER_MASS_PLCL_MCL]);*/
+  /*printf ("% 20.15g % 20.15g % 20.15g % 20.15g % 20.15g % 20.15g\n", p0[0], p0[1], lb[0], lb[1], ub[0], ub[1]);*/
+
   p0[0] = GSL_MAX (p0[0], lb[0]);
   p0[1] = GSL_MAX (p0[1], lb[1]);
   p0[0] = GSL_MIN (p0[0], ub[0]);
   p0[1] = GSL_MIN (p0[1], ub[1]);
 
-  ret = dlevmar_der (
-                     &_nc_cluster_pseudo_counts_levmar_f, 
-                     &_nc_cluster_pseudo_counts_levmar_J,
-                     p0, NULL, 2, 4, 1.0e5, opts, info, cpc->workz, NULL, data
-                     );
+  gsl_vector_view p0_vec = gsl_vector_view_array (p0, 2);
   
-  if (ret < 0)
+  f.f  = &_nc_cluster_pseudo_counts_gsl_f;
+  f.df = &_nc_cluster_pseudo_counts_gsl_J; 
+  f.n = 4;
+  f.p = 2;
+  f.params = data;
+
+  /* initialize solver with starting point */
+  gsl_multifit_fdfsolver_set (cpc->s, &f, &p0_vec.vector);
+
+  /* solve the system with a maximum of 20 iterations */
+#ifdef HAVE_GSL_2_2
+  status = gsl_multifit_fdfsolver_driver (cpc->s, 2.0e4, xtol, gtol, ftol, &info);
+#else /* HAVE_GSL_2_2 */
+  g_error ("_peakfinder: this model requires gsl >= 2.2.");
+#endif /* HAVE_GSL_2_2 */
+
+  if (status != GSL_SUCCESS)
     g_error ("error: NcClusterPseudoCounts peakfinder function.\n");
 
-  x[0] = p0[0];
-  x[1] = p0[1];
-  x[2] = lnM_M0; 
+  //printf ("Inicial: p0 = %.5g p1 = %.5g\n", p0[0], p0[1]);
+  //printf ("3d Minimo : p  = %.5g p  = %.5g\n", gsl_vector_get (cpc->s->x, 0), gsl_vector_get (cpc->s->x, 1));
+  x[0] = gsl_vector_get (cpc->s->x, 0);
+  x[1] = gsl_vector_get (cpc->s->x, 1);
+  x[2] = lnM_M0;
+  
   *n = 1;
 }
 
+
 static gdouble
 _posterior_numerator_integrand_plcl (gdouble w1, gdouble w2, gdouble lnM_M0, gpointer userdata)
 {
   integrand_data *data = (integrand_data *) userdata;
   NcClusterPseudoCounts *cpc = data->cpc;   
   const gdouble lnM   = lnM_M0 + data->lnM0;
-  const gdouble sf    = _selection_function (cpc, lnM);
+  const gdouble sf    = nc_cluster_pseudo_counts_selection_function (cpc, lnM, data->z);
   const gdouble small = exp (-200.0);
   gdouble res;
-    
+
   if (sf == 0.0)
     res = small;
   else
   {
-    const gdouble mf             = nc_mass_function_d2n_dzdlnm (data->mfp, data->cosmo, lnM, data->z);
+    const gdouble mf             = nc_halo_mass_function_d2n_dzdlnM (data->mfp, data->cosmo, lnM, data->z);
     const gdouble pdf_Mobs_Mtrue = nc_cluster_mass_plcl_pdf (data->clusterm, lnM_M0, w1, w2, data->Mobs, data->Mobs_params);
 
     res = sf * mf * pdf_Mobs_Mtrue + small; 
@@ -592,7 +710,7 @@ _posterior_numerator_integrand_plcl (gdouble w1, gdouble w2, gdouble lnM_M0, gpo
 /**
  * nc_cluster_pseudo_counts_posterior_numerator_plcl:
  * @cpc: a #NcClusterPseudoCounts
- * @mfp: a #NcMassFunction
+ * @mfp: a #NcHaloMassFunction
  * @clusterm: a #NcClusterMass
  * @cosmo: a #NcHICosmo 
  * @z: spectroscopic redshift
@@ -606,16 +724,19 @@ _posterior_numerator_integrand_plcl (gdouble w1, gdouble w2, gdouble lnM_M0, gpo
  * Returns: FIXME
 */
 gdouble
-nc_cluster_pseudo_counts_posterior_numerator_plcl (NcClusterPseudoCounts *cpc, NcMassFunction *mfp, NcClusterMass *clusterm, NcHICosmo *cosmo, const gdouble z, const gdouble Mpl, const gdouble Mcl, const gdouble sigma_pl, const gdouble sigma_cl)
+nc_cluster_pseudo_counts_posterior_numerator_plcl (NcClusterPseudoCounts *cpc, NcHaloMassFunction *mfp, NcClusterMass *clusterm, NcHICosmo *cosmo, const gdouble z, const gdouble Mpl, const gdouble Mcl, const gdouble sigma_pl, const gdouble sigma_cl)
 {
   integrand_data data;
   gdouble P, err;
   NcmIntegrand3dim integ;
   gdouble norma_p;
-  const gdouble M0 = 5.7e14; //1.0e14;
+  const gdouble M0 = 5.7e14;
   const gdouble Mobs[] = {Mpl / M0, Mcl / M0};
   const gdouble Mobs_params[] = {sigma_pl / M0, sigma_cl / M0};
-  
+
+  /*printf ("% 20.15g % 20.15g % 20.15g\n", z, ZMIN, ZMIN + DELTAZ);*/
+  /*printf ("% 20.15g % 20.15g\n", Mpl, Mcl);*/
+
   if (z < ZMIN || z > (ZMIN + DELTAZ))
     return 0.0;
   else
@@ -630,13 +751,13 @@ nc_cluster_pseudo_counts_posterior_numerator_plcl (NcClusterPseudoCounts *cpc, N
     data.Mobs        = Mobs;
     data.Mobs_params = Mobs_params;
     data.lnM0        = log (M0);
-
+ 
     integ.f = _posterior_numerator_integrand_plcl;
     integ.userdata = &data;
 
     {
-      gint n = 1;
-      gint ndim = 3;
+      gint n    = 1;
+      const gint ndim = 3;
       gdouble a_w1, a_w2, b_w1, b_w2, a_true, b_true;
       gdouble lb[3], ub[3]; 
       gdouble bounds[ndim * 2], x1[ndim], p0[ndim];
@@ -675,7 +796,7 @@ nc_cluster_pseudo_counts_posterior_numerator_plcl (NcClusterPseudoCounts *cpc, N
       for (i = 0; i < ngiven; i++)
       {
         gdouble lnM_M0 = log (2.0e12) + (log (7.0e15) - log (2.0e12)) * i * 1.0 / (ngiven - 1.0) - data.lnM0;
-        peakfinder (lnM_M0, p0, &ndim, bounds, &n, x1, &data); 
+        _peakfinder (lnM_M0, p0, &ndim, bounds, &n, x1, &data); 
         x[i * ldxgiven + 0] = x1[0]; /* w1 */
         x[i * ldxgiven + 1] = x1[1]; /* w2 */
         x[i * ldxgiven + 2] = x1[2]; /* True mass */
@@ -686,7 +807,8 @@ nc_cluster_pseudo_counts_posterior_numerator_plcl (NcClusterPseudoCounts *cpc, N
       ncm_integrate_3dim_divonne (&integ, lb[0], lb[1], lb[2], ub[0], ub[1], ub[2], 1e-5, 0.0, ngiven, ldxgiven, x, &P, &err);
       ncm_spline2d_use_acc (mfp->d2NdzdlnM, FALSE);
       
-      norma_p = 4.0 * M_PI * M_PI * (Mobs_params[NC_CLUSTER_MASS_PLCL_MPL] * Mobs_params[NC_CLUSTER_MASS_PLCL_MCL]);
+      //norma_p = 4.0 * M_PI * M_PI * (Mobs_params[NC_CLUSTER_MASS_PLCL_MPL] * Mobs_params[NC_CLUSTER_MASS_PLCL_MCL]);
+      norma_p = M_PI * M_PI * (Mobs_params[NC_CLUSTER_MASS_PLCL_MPL] * Mobs_params[NC_CLUSTER_MASS_PLCL_MCL]);
     }
 
     /*printf ("P = %.8g err = %.8e\n", P / norma_p, err / P);*/
