@@ -31,7 +31,6 @@
 #include <numcosmo/build_cfg.h>
 #include <numcosmo/lss/nc_growth_func.h>
 #include <numcosmo/lss/nc_transfer_func.h>
-#include <numcosmo/lss/nc_matter_var.h>
 #include <numcosmo/nc_distance.h>
 
 G_BEGIN_DECLS
@@ -46,6 +45,12 @@ G_BEGIN_DECLS
 typedef struct _NcGalaxyAcfClass NcGalaxyAcfClass;
 typedef struct _NcGalaxyAcf NcGalaxyAcf;
 
+struct _NcGalaxyAcfClass
+{
+  /*< private >*/
+  GObjectClass parent_class;
+};
+
 struct _NcGalaxyAcf
 {
   /*< private >*/
@@ -54,21 +59,14 @@ struct _NcGalaxyAcf
   NcDistance *dist;
   NcTransferFunc *tf;
   NcmSpline *s;
-  NcMatterVar *vp;
   gdouble b;
 };
 
-struct _NcGalaxyAcfClass
-{
-  /*< private >*/
-  GObjectClass parent_class;
-};
-
 GType nc_galaxy_acf_get_type (void) G_GNUC_CONST;
 
 NcGalaxyAcf *nc_galaxy_acf_new (NcGrowthFunc *gf, NcDistance *dist, NcTransferFunc *tf);
 gdouble nc_galaxy_acf_psi (NcGalaxyAcf *acf, NcHICosmo *cosmo, gdouble k, guint l);
-void nc_galaxy_acf_prepare_psi (NcGalaxyAcf *acf, NcHIReion *reion, NcHICosmo *cosmo, guint l);
+void nc_galaxy_acf_prepare_psi (NcGalaxyAcf *acf, NcHICosmo *cosmo, guint l);
 
 
 G_END_DECLS
