@@ -45,6 +45,12 @@ G_BEGIN_DECLS
 typedef struct _NcGrowthFuncClass NcGrowthFuncClass;
 typedef struct _NcGrowthFunc NcGrowthFunc;
 
+struct _NcGrowthFuncClass
+{
+  /*< private >*/
+  GObjectClass parent_class;
+};
+
 struct _NcGrowthFunc
 {
   /*< private >*/
@@ -52,20 +58,16 @@ struct _NcGrowthFunc
   NcmSpline *s;
   gpointer cvode;
   N_Vector yv;
+  N_Vector yQ;
   gdouble zf;
+  gdouble Da0;
   NcmModelCtrl *ctrl_cosmo;
 };
 
-struct _NcGrowthFuncClass
-{
-  /*< private >*/
-  GObjectClass parent_class;
-};
-
 GType nc_growth_func_get_type (void) G_GNUC_CONST;
 
 NcGrowthFunc * nc_growth_func_new (void);
-NcGrowthFunc * nc_growth_func_copy (NcGrowthFunc *gf);
+NcGrowthFunc * nc_growth_func_ref (NcGrowthFunc *gf);
 void nc_growth_func_free (NcGrowthFunc *gf);
 void nc_growth_func_clear (NcGrowthFunc **gf);
 
@@ -75,6 +77,7 @@ void nc_growth_func_prepare_if_needed (NcGrowthFunc *gf, NcHICosmo *cosmo);
 G_INLINE_FUNC gdouble nc_growth_func_eval (NcGrowthFunc *gf, NcHICosmo *cosmo, gdouble z);
 G_INLINE_FUNC gdouble nc_growth_func_eval_deriv (NcGrowthFunc *gf, NcHICosmo *cosmo, gdouble z);
 G_INLINE_FUNC void nc_growth_func_eval_both (NcGrowthFunc *gf, NcHICosmo *cosmo, gdouble z, gdouble *d, gdouble *f);
+G_INLINE_FUNC gdouble nc_growth_func_get_dust_norma_Da0 (NcGrowthFunc *gf);
 
 G_END_DECLS
 
@@ -92,20 +95,29 @@ G_BEGIN_DECLS
 G_INLINE_FUNC gdouble
 nc_growth_func_eval (NcGrowthFunc *gf, NcHICosmo *cosmo, gdouble z)
 {
-  return ncm_spline_eval (gf->s, z);
+  const gdouble a = 1.0 / (1.0 + z);
+  return ncm_spline_eval (gf->s, a);
 }
 
 G_INLINE_FUNC gdouble
 nc_growth_func_eval_deriv (NcGrowthFunc *gf, NcHICosmo *cosmo, gdouble z)
 {
-  return ncm_spline_eval_deriv (gf->s, z);
+  const gdouble a = 1.0 / (1.0 + z);
+  return - a * a * ncm_spline_eval_deriv (gf->s, a);
 }
 
 G_INLINE_FUNC void
 nc_growth_func_eval_both (NcGrowthFunc *gf, NcHICosmo *cosmo, gdouble z, gdouble *d, gdouble *f)
 {
-  *d = ncm_spline_eval (gf->s, z);
-  *f = ncm_spline_eval_deriv (gf->s, z);
+  const gdouble a = 1.0 / (1.0 + z);
+  *d = ncm_spline_eval (gf->s, a);
+  *f = - a * a * ncm_spline_eval_deriv (gf->s, a);
+}
+
+G_INLINE_FUNC gdouble 
+nc_growth_func_get_dust_norma_Da0 (NcGrowthFunc *gf)
+{
+  return gf->Da0;
 }
 
 G_END_DECLS
