@@ -40,6 +40,40 @@
 
 G_DEFINE_TYPE (NcTransferFuncBBKS, nc_transfer_func_bbks, NC_TYPE_TRANSFER_FUNC);
 
+static void
+nc_transfer_func_bbks_init (NcTransferFuncBBKS *tf_bbks)
+{
+  tf_bbks->c1    = 0.0;
+  tf_bbks->c2    = 0.0;
+  tf_bbks->c3    = 0.0;
+  tf_bbks->c4    = 0.0;
+  tf_bbks->c5_wm = 0.0;
+  tf_bbks->h     = 0.0;
+}
+
+static void
+nc_transfer_func_bbks_finalize (GObject *object)
+{
+
+  /* Chain up : end */
+  G_OBJECT_CLASS (nc_transfer_func_bbks_parent_class)->finalize (object);
+}
+
+static void _nc_transfer_func_bbks_prepare (NcTransferFunc *tf, NcHICosmo *cosmo);
+static gdouble _nc_transfer_func_bbks_calc (NcTransferFunc *tf, gdouble kh);
+
+static void
+nc_transfer_func_bbks_class_init (NcTransferFuncBBKSClass *klass)
+{
+  GObjectClass* object_class = G_OBJECT_CLASS (klass);
+  NcTransferFuncClass* parent_class = NC_TRANSFER_FUNC_CLASS (klass);
+
+  parent_class->prepare = &_nc_transfer_func_bbks_prepare;
+  parent_class->calc = &_nc_transfer_func_bbks_calc;
+
+  object_class->finalize = nc_transfer_func_bbks_finalize;
+}
+
 /**
  * nc_transfer_func_bbks_new:
  *
@@ -54,18 +88,18 @@ nc_transfer_func_bbks_new ()
 }
 
 static void
-_nc_transfer_func_bbks_prepare (NcTransferFunc *tf, NcHIReion *reion, NcHICosmo *cosmo)
+_nc_transfer_func_bbks_prepare (NcTransferFunc *tf, NcHICosmo *cosmo)
 {
   NcTransferFuncBBKS *tf_BBKS = NC_TRANSFER_FUNC_BBKS (tf);
   const gdouble T_0 = nc_hicosmo_T_gamma0 (cosmo);
-  const gdouble c1 = 3.89;
-  const gdouble c2 = gsl_pow_2 (16.1);
-  const gdouble c3 = gsl_pow_3 (5.46);
-  const gdouble c4 = gsl_pow_4 (6.71);
-  const gdouble c5 = gsl_pow_2 (T_0 / 2.7);   /* CMB: (T_0/2.7)^2 = (2.725/2.7)^2 */
-  const gdouble h = nc_hicosmo_h (cosmo);
-  const gdouble h2 = h * h;
-  const gdouble wm = nc_hicosmo_Omega_m0 (cosmo) * h2;
+  const gdouble c1  = 3.89;
+  const gdouble c2  = gsl_pow_2 (16.1);
+  const gdouble c3  = gsl_pow_3 (5.46);
+  const gdouble c4  = gsl_pow_4 (6.71);
+  const gdouble c5  = gsl_pow_2 (T_0 / 2.7);   /* CMB: (T_0/2.7)^2 = (2.725/2.7)^2 */
+  const gdouble h   = nc_hicosmo_h (cosmo);
+  const gdouble h2  = h * h;
+  const gdouble wm  = nc_hicosmo_Omega_m0 (cosmo) * h2;
 
   tf_BBKS->c1    = c1;
   tf_BBKS->c2    = c2;
@@ -86,46 +120,5 @@ _nc_transfer_func_bbks_calc (NcTransferFunc *tf, gdouble kh)
   const gdouble q3 = q2 * q;
   const gdouble q4 = q3 * q;
 
-  return (q1 == 0.0 ? 1.0 : (log1p(q1)/q1) ) * pow(1.0 + tf_BBKS->c1 * q + tf_BBKS->c2 * q2 + tf_BBKS->c3 * q3 + tf_BBKS->c4 * q4, -1.0/4.0);
+  return (q1 == 0.0 ? 1.0 : (log1p (q1) / q1)) * pow (1.0 + tf_BBKS->c1 * q + tf_BBKS->c2 * q2 + tf_BBKS->c3 * q3 + tf_BBKS->c4 * q4, -1.0 / 4.0);
 }
-
-static gdouble
-_nc_transfer_func_bbks_calc_matter_P (NcTransferFunc *tf, NcHICosmo *cosmo, gdouble kh)
-{
-  gdouble T = _nc_transfer_func_bbks_calc (tf, kh);
-  return T * T * nc_hicosmo_powspec (cosmo, kh);
-}
-
-static void
-nc_transfer_func_bbks_init (NcTransferFuncBBKS *tf_bbks)
-{
-  /* TODO: Add initialization code here */
-  tf_bbks->c1 = 0.0;
-  tf_bbks->c2 = 0.0;
-  tf_bbks->c3 = 0.0;
-  tf_bbks->c4 = 0.0;
-  tf_bbks->c5_wm = 0.0;
-  tf_bbks->h = 0.0;
-}
-
-static void
-nc_transfer_func_bbks_finalize (GObject *object)
-{
-  /* TODO: Add deinitalization code here */
-
-  G_OBJECT_CLASS (nc_transfer_func_bbks_parent_class)->finalize (object);
-}
-
-static void
-nc_transfer_func_bbks_class_init (NcTransferFuncBBKSClass *klass)
-{
-  GObjectClass* object_class = G_OBJECT_CLASS (klass);
-  NcTransferFuncClass* parent_class = NC_TRANSFER_FUNC_CLASS (klass);
-
-  parent_class->prepare = &_nc_transfer_func_bbks_prepare;
-  parent_class->calc = &_nc_transfer_func_bbks_calc;
-  parent_class->calc_matter_P = &_nc_transfer_func_bbks_calc_matter_P;
-
-  object_class->finalize = nc_transfer_func_bbks_finalize;
-}
-
