@@ -25,8 +25,8 @@
 
 /**
  * SECTION:nc_window
- * @title: Window Function Abstract Class
- * @short_description: Defines the prototype of the #NcWindow object. 
+ * @title: NcWindow
+ * @short_description: Abstract class for window functions.
  * 
  * This module comprises the set of functions to compute the window function in both real 
  * and Fourier spaces as well as its derivative with respect to the scale $R$ in Fourier space. 
@@ -63,7 +63,7 @@ nc_window_new_from_name (gchar *window_name)
   GObject *obj = ncm_serialize_global_from_string (window_name);
   GType window_type = G_OBJECT_TYPE (obj);
   if (!g_type_is_a (window_type, NC_TYPE_WINDOW))
-	g_error ("nc_window_new_from_name: NcWindow %s do not descend from %s\n", window_name, g_type_name (NC_TYPE_WINDOW));
+	g_error ("nc_window_new_from_name: NcWindow %s do not descend from %s.", window_name, g_type_name (NC_TYPE_WINDOW));
   return NC_WINDOW (obj);
 }
 
