@@ -46,18 +46,18 @@ G_BEGIN_DECLS
 typedef struct _NcmCClass NcmCClass;
 typedef struct _NcmC NcmC;
 
-struct _NcmC
-{
-  /*< private >*/
-  GObject parent_instance;
-};
-
 struct _NcmCClass
 {
   /*< private >*/
   GObjectClass parent_class;
 };
 
+struct _NcmC
+{
+  /*< private >*/
+  GObject parent_instance;
+};
+
 GType ncm_c_get_type (void) G_GNUC_CONST;
 
 /*******************************************************************************
@@ -66,10 +66,15 @@ GType ncm_c_get_type (void) G_GNUC_CONST;
 
 G_INLINE_FUNC long double ncm_c_sqrt_1_4pi (void) G_GNUC_CONST;
 G_INLINE_FUNC long double ncm_c_sqrt_2pi (void) G_GNUC_CONST;
+G_INLINE_FUNC long double ncm_c_sqrt_pi_2 (void) G_GNUC_CONST;
 G_INLINE_FUNC long double ncm_c_sqrt_3_4pi (void) G_GNUC_CONST;
+G_INLINE_FUNC long double ncm_c_ln2 (void) G_GNUC_CONST;
+G_INLINE_FUNC long double ncm_c_ln3 (void) G_GNUC_CONST;
 G_INLINE_FUNC long double ncm_c_lnpi_4 (void) G_GNUC_CONST;
 G_INLINE_FUNC long double ncm_c_ln2pi (void) G_GNUC_CONST;
+G_INLINE_FUNC long double ncm_c_lnpi (void) G_GNUC_CONST;
 G_INLINE_FUNC long double ncm_c_pi (void) G_GNUC_CONST;
+G_INLINE_FUNC long double ncm_c_2_pi_2 (void) G_GNUC_CONST;
 G_INLINE_FUNC long double ncm_c_tan_1arcsec (void) G_GNUC_CONST;
 
 G_INLINE_FUNC gdouble ncm_c_degree_to_radian (const gdouble d) G_GNUC_CONST;
@@ -360,8 +365,8 @@ G_INLINE_FUNC gdouble ncm_c_wmap5_coadded_I_W (void) G_GNUC_CONST;
 G_INLINE_FUNC gdouble ncm_c_hubble_cte_wmap (void) G_GNUC_CONST;
 G_INLINE_FUNC gdouble ncm_c_hubble_cte_hst (void) G_GNUC_CONST;
 G_INLINE_FUNC gdouble ncm_c_hubble_cte_msa (void) G_GNUC_CONST;
-G_INLINE_FUNC gdouble ncm_c_hubble_radius (void) ;
-G_INLINE_FUNC gdouble ncm_c_hubble_radius_planck (void) G_GNUC_CONST;
+G_INLINE_FUNC gdouble ncm_c_hubble_radius_hm1_Mpc (void) ;
+G_INLINE_FUNC gdouble ncm_c_hubble_radius_hm1_planck (void) G_GNUC_CONST;
 G_INLINE_FUNC gdouble ncm_c_crit_density_h2 (void) G_GNUC_CONST;
 G_INLINE_FUNC gdouble ncm_c_crit_mass_density_h2 (void) G_GNUC_CONST;
 G_INLINE_FUNC gdouble ncm_c_crit_mass_density_h2_solar_mass_Mpc3 (void) G_GNUC_CONST;
@@ -395,18 +400,33 @@ G_INLINE_FUNC long double ncm_c_sqrt_1_4pi (void)
 G_INLINE_FUNC long double ncm_c_sqrt_2pi (void)
 { return 2.5066282746310005024157652848110452L; }
 
+G_INLINE_FUNC long double ncm_c_sqrt_pi_2 (void)
+{ return 1.2533141373155002512078826424055226L; }
+
 G_INLINE_FUNC long double ncm_c_sqrt_3_4pi (void)
 { return 0.48860251190291992158638462283834700L; }
 
+G_INLINE_FUNC long double ncm_c_ln2 (void)
+{ return 0.69314718055994530941723212145817657L; }
+
+G_INLINE_FUNC long double ncm_c_ln3 (void)
+{ return 1.0986122886681096913952452369225257L; }
+
 G_INLINE_FUNC long double ncm_c_lnpi_4 (void)
 { return 0.28618247146235004353585683783826468L; }
 
 G_INLINE_FUNC long double ncm_c_ln2pi (void)
 { return 1.8378770664093454835606594728112353L; }
 
+G_INLINE_FUNC long double ncm_c_lnpi (void)
+{ return 1.1447298858494001741434273513530587L; }
+
 G_INLINE_FUNC long double ncm_c_pi (void)
 { return 3.1415926535897932384626433832795029L; }
 
+G_INLINE_FUNC long double ncm_c_2_pi_2 (void)
+{ return 19.739208802178717237668981999752302L; }
+
 G_INLINE_FUNC long double ncm_c_tan_1arcsec (void)
 { return 4.8481368111333441675396429478852853e-6L; }
 
@@ -1007,11 +1027,11 @@ G_INLINE_FUNC gdouble ncm_c_hubble_cte_hst (void)
 G_INLINE_FUNC gdouble ncm_c_hubble_cte_msa (void)
 { return 68.0; }
 
-G_INLINE_FUNC gdouble ncm_c_hubble_radius (void)
+G_INLINE_FUNC gdouble ncm_c_hubble_radius_hm1_Mpc (void)
 { return ncm_c_c () / (100.0e3); }
 
-G_INLINE_FUNC gdouble ncm_c_hubble_radius_planck (void)
-{ return ncm_c_hubble_radius () * ncm_c_Mpc () / ncm_c_planck_length (); }
+G_INLINE_FUNC gdouble ncm_c_hubble_radius_hm1_planck (void)
+{ return ncm_c_hubble_radius_hm1_Mpc () * ncm_c_Mpc () / ncm_c_planck_length (); }
 
 G_INLINE_FUNC gdouble ncm_c_crit_density_h2 (void)
 { return 3.0 * pow (ncm_c_c () / (10.0 * ncm_c_pc ()), 2.0) / (8.0 * M_PI * ncm_c_G ()); }
