@@ -131,6 +131,7 @@
 #include "data/nc_data_bao_rdv.h"
 #include "data/nc_data_bao_empirical_fit.h"
 #include "data/nc_data_bao_dhr_dar.h"
+#include "data/nc_data_bao_dmr_hr.h"
 #include "data/nc_data_dist_mu.h"
 #include "data/nc_data_cluster_pseudo_counts.h"
 #include "data/nc_data_cmb_shift_param.h"
@@ -224,6 +225,7 @@ void clencurt_gen (int M);
 
 void _nc_hicosmo_register_functions (void);
 void _nc_hicosmo_de_register_functions (void);
+void _nc_hireion_register_functions (void);
 void _nc_distance_register_functions (void);
 void _nc_planck_fi_cor_tt_register_functions (void);
 
@@ -417,6 +419,7 @@ ncm_cfg_init (void)
   ncm_cfg_register_obj (NC_TYPE_DATA_BAO_RDV);
   ncm_cfg_register_obj (NC_TYPE_DATA_BAO_EMPIRICAL_FIT);
   ncm_cfg_register_obj (NC_TYPE_DATA_BAO_DHR_DAR);
+  ncm_cfg_register_obj (NC_TYPE_DATA_BAO_DMR_HR);
 
   ncm_cfg_register_obj (NC_TYPE_DATA_DIST_MU);
 
@@ -435,7 +438,8 @@ ncm_cfg_init (void)
 
   _nc_hicosmo_register_functions ();
   _nc_hicosmo_de_register_functions ();
-  _nc_distance_register_functions ();
+  _nc_hireion_register_functions ();
+    _nc_distance_register_functions ();
   _nc_planck_fi_cor_tt_register_functions ();
 
   numcosmo_init = TRUE;
