@@ -25,8 +25,8 @@
 
 /**
  * SECTION:ncm_lh_ratio1d
- * @title: Likelihood Ratio 1D
- * @short_description: Likelihood ratio object for one dimensional analysis
+ * @title: NcmLHRatio1d
+ * @short_description: Likelihood ratio for one dimensional parameter analysis.
  *
  * FIXME
  * 
@@ -41,7 +41,7 @@
 
 #include "math/ncm_c.h"
 #include "math/ncm_cfg.h"
-#include "math/util.h"
+#include "math/ncm_util.h"
 
 #include <gsl/gsl_cdf.h>
 #include <gsl/gsl_roots.h>
@@ -78,15 +78,16 @@ ncm_lh_ratio1d_constructed (GObject *object)
   G_OBJECT_CLASS (ncm_lh_ratio1d_parent_class)->constructed (object);
   {
     NcmLHRatio1d *lhr1d = NCM_LH_RATIO1D (object);
-    NcmMSet *mset = ncm_mset_dup (lhr1d->fit->mset);
+    NcmSerialize *ser = ncm_serialize_global ();
+    NcmMSet *mset = ncm_mset_dup (lhr1d->fit->mset, ser);
 
+    ncm_serialize_free (ser);
     g_assert_cmpint (lhr1d->pi.mid, >=, 0);
-    g_assert_cmpint (lhr1d->pi.mid,  <, NCM_MODEL_MAX_ID);
     
     g_assert (lhr1d->fit->fstate->is_best_fit);
 
     if (ncm_mset_peek (lhr1d->fit->mset, lhr1d->pi.mid) == NULL)
-      g_error ("ncm_lh_ratio1d_constructed: cannot use parameter[%d:%u], model not set\n", 
+      g_error ("ncm_lh_ratio1d_constructed: cannot use parameter[%d:%u], model not set.", 
                lhr1d->pi.mid, lhr1d->pi.pid);
     
     if (ncm_mset_param_get_ftype (lhr1d->fit->mset, lhr1d->pi.mid, lhr1d->pi.pid) != NCM_PARAM_TYPE_FREE)
@@ -124,6 +125,9 @@ ncm_lh_ratio1d_set_property (GObject *object, guint prop_id, const GValue *value
       lhr1d->pi = *pi;
       break;
     }
+    case PROP_CONSTRAINT:
+      lhr1d->constraint = g_value_dup_object (value);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -138,12 +142,18 @@ ncm_lh_ratio1d_get_property (GObject *object, guint prop_id, GValue *value, GPar
 
   switch (prop_id)
   {
+    case PROP_FIT:
+      g_value_set_object (value, lhr1d->fit);
+      break;
     case PROP_PI:
     {
       NcmMSetPIndex *pi = ncm_mset_pindex_new (lhr1d->pi.mid, lhr1d->pi.pid);
       g_value_take_boxed (value, pi);
       break;
     }
+    case PROP_CONSTRAINT:
+      g_value_set_object (value, lhr1d->constraint);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -187,7 +197,7 @@ ncm_lh_ratio1d_class_init (NcmLHRatio1dClass *klass)
                                                         NULL,
                                                         "NcmFit object",
                                                         NCM_TYPE_FIT,
-                                                        G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
+                                                        G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
 
   g_object_class_install_property (object_class,
                                    PROP_PI,
@@ -198,37 +208,36 @@ ncm_lh_ratio1d_class_init (NcmLHRatio1dClass *klass)
                                                        G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
   
   g_object_class_install_property (object_class,
-                                   PROP_PI,
+                                   PROP_CONSTRAINT,
                                    g_param_spec_object ("constraint",
                                                         NULL,
                                                         "Constraint",
                                                         NCM_TYPE_MSET_FUNC,
-                                                        G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
+                                                        G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
 }
 
 
 /**
  * ncm_lh_ratio1d_new:
- * @fit: FIXME
- * @pi: FIXME
+ * @fit: a #NcmFit
+ * @pi: a #NcmMSetPIndex
  *
  * FIXME
  * 
  * Returns: FIXME
  */
 NcmLHRatio1d *
-ncm_lh_ratio1d_new (NcmFit *fit, NcmMSetPIndex *pi)
+ncm_lh_ratio1d_new (NcmFit *fit, const NcmMSetPIndex *pi)
 {
   return g_object_new (NCM_TYPE_LH_RATIO1D, 
                        "fit", fit,
                        "pi", pi,
-                       NULL);
-  
+                       NULL); 
 }
 
 /**
  * ncm_lh_ratio1d_free:
- * @lhr1d: FIXME
+ * @lhr1d: a #NcmLHRatio1d
  *
  * FIXME
  *
@@ -241,7 +250,7 @@ ncm_lh_ratio1d_free (NcmLHRatio1d *lhr1d)
 
 /**
  * ncm_lh_ratio1d_clear:
- * @lhr1d: FIXME
+ * @lhr1d: a #NcmLHRatio1d
  *
  * FIXME
  *
@@ -254,8 +263,8 @@ ncm_lh_ratio1d_clear (NcmLHRatio1d **lhr1d)
 
 /**
  * ncm_lh_ratio1d_set_pindex:
- * @lhr1d: a #NcmLHRatio1d.
- * @pi: FIXME
+ * @lhr1d: a #NcmLHRatio1d
+ * @pi: a #NcmMSetPIndex
  *
  * FIXME
  *
@@ -412,8 +421,12 @@ ncm_lh_ratio1d_f (gdouble x, gpointer ptr)
     g_warning ("reached upper bound stoping...");
     return 0.0;
   }
-  
-  return lhr1d->constrained->fstate->m2lnL - (lhr1d->fit->fstate->m2lnL + lhr1d->chisquare);
+
+  {
+    const gdouble m2lnL_const = ncm_fit_state_get_m2lnL_curval (lhr1d->constrained->fstate);
+    const gdouble m2lnL = ncm_fit_state_get_m2lnL_curval (lhr1d->fit->fstate);
+    return m2lnL_const - (m2lnL + lhr1d->chisquare);
+  }
 }
 
 static gdouble
@@ -548,11 +561,11 @@ ncm_lh_ratio1d_root_steffenson (NcmLHRatio1d *lhr1d, gdouble x0, gdouble x1)
 
 /**
  * ncm_lh_ratio1d_find_bounds:
- * @lhr1d: a #NcmLHRatio1d.
- * @clevel: The confidence level (0,1).
- * @mtype: FIXME
- * @lb: (out): Lower bound
- * @ub: (out): Upper bound 
+ * @lhr1d: a #NcmLHRatio1d
+ * @clevel: the confidence level (0,1)
+ * @mtype: a #NcmFitRunMsgs
+ * @lb: (out): lower bound
+ * @ub: (out): upper bound 
  * 
  * FIXME
  * 
@@ -563,7 +576,8 @@ ncm_lh_ratio1d_find_bounds (NcmLHRatio1d *lhr1d, gdouble clevel, NcmFitRunMsgs m
   gdouble scale, r, r_min, r_max, val;
   static gdouble (*root) (NcmLHRatio1d *lhr1d, gdouble x0, gdouble x);
 
-  g_assert (clevel > 0.0 && clevel < 1.0);
+  g_assert_cmpfloat (clevel, >, 0.0);
+  g_assert_cmpfloat (clevel, <, 1.0);
 
   lhr1d->chisquare = gsl_cdf_chisq_Qinv (1.0 - clevel, 1.0);
   scale = sqrt (lhr1d->chisquare) * 
@@ -598,7 +612,6 @@ ncm_lh_ratio1d_find_bounds (NcmLHRatio1d *lhr1d, gdouble clevel, NcmFitRunMsgs m
   r_min = root (lhr1d, r_min, r);
 
   r = 0.0;
-  r_max = scale;
   while ((val = ncm_lh_ratio1d_f (r_max, lhr1d)) < 0.0)
   {
     ncm_lh_ratio1d_log_param_val (lhr1d, r_max, val);
