@@ -46,6 +46,32 @@ typedef struct _NcmModelClass NcmModelClass;
 typedef struct _NcmModel NcmModel;
 typedef gint NcmModelID;
 
+typedef void (*NcmModelAddSubmodel) (NcmModel *model, NcmModel *submodel);
+
+struct _NcmModelClass
+{
+  /*< private >*/
+  GObjectClass parent_class;
+  void (*get_property) (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
+  void (*set_property) (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
+  NcmModelAddSubmodel add_submodel;
+  gboolean (*valid) (NcmModel *model);
+  NcmModelID model_id;
+  gboolean can_stack;
+  NcmModelID main_model_id;
+  gboolean is_submodel;
+  gchar *name;
+  gchar *nick;
+  guint64 impl;
+  guint nonparam_prop_len;
+  guint sparam_len;
+  guint vparam_len;
+  guint parent_sparam_len;
+  guint parent_vparam_len;
+  GPtrArray *sparam;
+  GPtrArray *vparam;
+};
+
 /**
  * NcmModel:
  *
@@ -63,32 +89,13 @@ struct _NcmModel
   GArray *vparam_len;
   GArray *ptypes;
   GHashTable *sparams_name_id;
+  GHashTable *submodel_mid_pos;
+  GPtrArray *submodel_array;
   guint total_len;
   guint64 pkey;
   guint64 skey;
 };
 
-struct _NcmModelClass
-{
-  /*< private >*/
-  GObjectClass parent_class;
-  void (*get_property) (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
-  void (*set_property) (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
-  gboolean (*valid) (NcmModel *model);
-  NcmModelID model_id;
-  gboolean can_stack;
-  gchar *name;
-  gchar *nick;
-  guint64 impl;
-  guint nonparam_prop_len;
-  guint sparam_len;
-  guint vparam_len;
-  guint parent_sparam_len;
-  guint parent_vparam_len;
-  GPtrArray *sparam;
-  GPtrArray *vparam;
-};
-
 typedef gdouble (*NcmModelFunc0) (NcmModel *model);
 typedef gdouble (*NcmModelFunc1) (NcmModel *model, const gdouble x);
 typedef gdouble (*NcmModelFunc2) (NcmModel *model, const gdouble x, const gdouble y);
@@ -152,7 +159,7 @@ G_INLINE_FUNC NcmVector *ncm_model_orig_vparam_get_vector (NcmModel *model, guin
 void ncm_model_params_copyto (NcmModel *model, NcmModel *model_dest);
 void ncm_model_params_set_default (NcmModel *model);
 void ncm_model_params_save_as_default (NcmModel *model);
-void ncm_model_params_set_all (NcmModel *model, ...);
+void ncm_model_params_set_all (NcmModel *model, ...) G_GNUC_NULL_TERMINATED;
 void ncm_model_params_set_all_data (NcmModel *model, gdouble *data);
 void ncm_model_params_set_vector (NcmModel *model, NcmVector *v);
 void ncm_model_params_set_model (NcmModel *model, NcmModel *model_src);
@@ -195,6 +202,17 @@ void ncm_model_param_set_ftype (NcmModel *model, guint n, const NcmParamType pty
 void ncm_model_reparam_df (NcmModel *model, NcmVector *fv, NcmVector *v);
 void ncm_model_reparam_J (NcmModel *model, NcmMatrix *fJ, NcmMatrix *J);
 
+gboolean ncm_model_is_submodel (NcmModel *model);
+NcmModelID ncm_model_main_model (NcmModel *model);
+void ncm_model_add_submodel (NcmModel *model, NcmModel *submodel);
+guint ncm_model_get_submodel_len (NcmModel *model);
+NcmModel *ncm_model_peek_submodel (NcmModel *model, guint i);
+NcmModel *ncm_model_peek_submodel_by_mid (NcmModel *model, NcmModelID mid);
+gint ncm_model_peek_submodel_pos_by_mid (NcmModel *model, NcmModelID mid);
+
+gboolean ncm_model_type_is_submodel (GType model_type);
+NcmModelID ncm_model_type_main_model (GType model_type);
+
 /*
  * Model set functions
  */
