@@ -78,19 +78,20 @@ G_DEFINE_TYPE (NcmPowspecFilter, ncm_powspec_filter, G_TYPE_OBJECT);
 static void
 ncm_powspec_filter_init (NcmPowspecFilter *psf)
 {
-  psf->ps         = NULL;
-  psf->lnr0       = 0.0;
-  psf->lnk0       = 0.0;
-  psf->Lk         = 0.0;
-  psf->zi         = 0.0;
-  psf->zf         = 0.0;
-  psf->reltol     = 0.0;
-  psf->type       = NCM_POWSPEC_FILTER_TYPE_LEN;
-  psf->fftlog     = NULL;
-  psf->calibrated = FALSE;
-  psf->var        = ncm_spline2d_bicubic_notaknot_new ();
-  psf->dvar       = ncm_spline2d_bicubic_notaknot_new ();
-  psf->ctrl       = ncm_model_ctrl_new (NULL);
+  psf->ps          = NULL;
+  psf->lnr0        = 0.0;
+  psf->lnk0        = 0.0;
+  psf->Lk          = 0.0;
+  psf->zi          = 0.0;
+  psf->zf          = 0.0;
+  psf->reltol      = 0.0;
+  psf->type        = NCM_POWSPEC_FILTER_TYPE_LEN;
+  psf->fftlog      = NULL;
+  psf->calibrated  = FALSE;
+  psf->var         = ncm_spline2d_bicubic_notaknot_new ();
+  psf->dvar        = ncm_spline2d_bicubic_notaknot_new ();
+  psf->ctrl        = ncm_model_ctrl_new (NULL);
+  psf->constructed = FALSE;
 }
 
 static void
@@ -159,6 +160,22 @@ _ncm_powspec_filter_get_property (GObject *object, guint prop_id, GValue *value,
   }
 }
 
+static void
+_ncm_powspec_filter_constructed (GObject *object)
+{
+  /* Chain up : start */
+  G_OBJECT_CLASS (ncm_powspec_filter_parent_class)->constructed (object);
+  {
+    NcmPowspecFilter *psf     = NCM_POWSPEC_FILTER (object);
+    NcmPowspecFilterType type = psf->type;
+
+    psf->constructed = TRUE;
+    psf->type        = NCM_POWSPEC_FILTER_TYPE_LEN;
+
+    ncm_powspec_filter_set_type (psf, type);
+  }
+}
+
 static void
 _ncm_powspec_filter_dispose (GObject *object)
 {
@@ -191,6 +208,7 @@ ncm_powspec_filter_class_init (NcmPowspecFilterClass *klass)
 
   object_class->set_property = &_ncm_powspec_filter_set_property;
   object_class->get_property = &_ncm_powspec_filter_get_property;
+  object_class->constructed  = &_ncm_powspec_filter_constructed;
   object_class->dispose      = &_ncm_powspec_filter_dispose;
   object_class->finalize     = &_ncm_powspec_filter_finalize;
 
@@ -200,7 +218,7 @@ ncm_powspec_filter_class_init (NcmPowspecFilterClass *klass)
                                                         NULL,
                                                         "Output center value",
                                                         -G_MAXDOUBLE, G_MAXDOUBLE, 0.0,
-                                                        G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
+                                                        G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
   g_object_class_install_property (object_class,
                                    PROP_ZI,
                                    g_param_spec_double ("zi",
@@ -228,7 +246,7 @@ ncm_powspec_filter_class_init (NcmPowspecFilterClass *klass)
                                                       NULL,
                                                       "Filter type",
                                                       NCM_TYPE_POWSPEC_FILTER_TYPE, NCM_POWSPEC_FILTER_TYPE_TOPHAT,
-                                                      G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
+                                                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
   g_object_class_install_property (object_class,
                                    PROP_POWERSPECTRUM,
                                    g_param_spec_object ("powerspectrum",
@@ -310,7 +328,11 @@ ncm_powspec_filter_clear (NcmPowspecFilter **psf)
 void
 ncm_powspec_filter_set_type (NcmPowspecFilter *psf, NcmPowspecFilterType type)
 {
-  if (type != psf->type)
+  if (!psf->constructed)
+  {
+    psf->type = type;
+  }
+  else if (type != psf->type)
   {
     const gdouble lnk_min = log (ncm_powspec_get_kmin (psf->ps));
     const gdouble lnk_max = log (ncm_powspec_get_kmax (psf->ps));
@@ -337,6 +359,8 @@ ncm_powspec_filter_set_type (NcmPowspecFilter *psf, NcmPowspecFilterType type)
     ncm_fftlog_set_padding (psf->fftlog, 1.0);
     ncm_fftlog_set_nderivs (psf->fftlog, 1);
 
+    ncm_powspec_filter_set_best_lnr0 (psf);
+    
     ncm_model_ctrl_force_update (psf->ctrl);
     psf->calibrated = FALSE;
   }
@@ -464,6 +488,8 @@ ncm_powspec_filter_prepare (NcmPowspecFilter *psf, NcmModel *model)
       ncm_vector_memcpy (var_z, ncm_fftlog_peek_output_vector (psf->fftlog, 0));
       ncm_vector_memcpy (dvar_z, ncm_fftlog_peek_output_vector (psf->fftlog, 1));
 
+      /*ncm_vector_log_vals (var_z, "NADA: ", "% 11.5e");*/
+
       ncm_vector_free (var_z);
       ncm_vector_free (dvar_z);
     }
