@@ -53,8 +53,6 @@ enum
 
 G_DEFINE_TYPE (NcmSerialize, ncm_serialize, G_TYPE_OBJECT);
 
-GVariant *_ncm_serialize_to_variant (NcmSerialize *ser, GObject *obj);
-
 static void
 ncm_serialize_init (NcmSerialize *ser)
 {
@@ -69,10 +67,10 @@ ncm_serialize_init (NcmSerialize *ser)
                                                &g_free);
   ser->saved_name_ser = g_hash_table_new_full (&g_str_hash, &g_str_equal, &g_free,
                                                (GDestroyNotify)&g_variant_unref);
-
-  ser->is_named_regex  = g_regex_new ("^\\s*[A-Z][A-Za-z0-9]+\\s*\\[([A-Za-z0-9\\:]+)\\]\\s*$", 0, 0, &error);
-  ser->parse_obj_regex = g_regex_new ("^\\s*([A-Z][A-Za-z0-9]+)\\s*([\\{]?.*[\\}]?)\\s*$", 0, 0, &error);
-  ser->autosave_count = 0;
+  
+  ser->is_named_regex  = g_regex_new ("^\\s*([A-Za-z][A-Za-z0-9\\+\\_]+)\\s*\\[([A-Za-z0-9\\:]+)\\]\\s*$", 0, 0, &error);
+  ser->parse_obj_regex = g_regex_new ("^\\s*([A-Za-z][A-Za-z0-9\\+\\_]+\\s*(?:\\[[A-Za-z0-9\\:]+\\])?)\\s*([\\{]?.*[\\}]?)\\s*$", 0, 0, &error);
+  ser->autosave_count  = 0;
 }
 
 static void
@@ -242,6 +240,7 @@ ncm_serialize_reset (NcmSerialize *ser)
 
   g_hash_table_remove_all (ser->saved_ptr_name);
   g_hash_table_remove_all (ser->saved_name_ser);
+
   ser->autosave_count = 0;
 }
 
@@ -289,7 +288,7 @@ gboolean
 ncm_serialize_contain_instance (NcmSerialize *ser, gpointer obj)
 {
   g_assert (G_IS_OBJECT (obj));
-  return (g_hash_table_lookup (ser->ptr_name, obj) != NULL);
+  return g_hash_table_lookup_extended (ser->ptr_name, obj, NULL, NULL);
 }
 
 /**
@@ -305,7 +304,7 @@ gboolean
 ncm_serialize_contain_name (NcmSerialize *ser, const gchar *name)
 {
   g_assert (name != NULL);
-  return (g_hash_table_lookup (ser->name_ptr, name) != NULL);
+  return g_hash_table_lookup_extended (ser->name_ptr, name, NULL, NULL);
 }
 
 /**
@@ -322,6 +321,22 @@ ncm_serialize_count_instances (NcmSerialize *ser)
   return g_hash_table_size (ser->name_ptr);
 }
 
+/**
+ * ncm_serialize_peek_by_name:
+ * @ser: a #NcmSerialize.
+ * @name: an instance name.
+ *
+ * Peeks the instance @name or null if there isn't a instance named @name.
+ *
+ * Returns: (transfer none) (type GObject): Gets the instance named @name or NULL.
+ */
+gpointer
+ncm_serialize_peek_by_name (NcmSerialize *ser, const gchar *name)
+{
+  g_assert (name != NULL);
+  return g_hash_table_lookup (ser->name_ptr, name);
+}
+
 /**
  * ncm_serialize_get_by_name:
  * @ser: a #NcmSerialize.
@@ -336,8 +351,8 @@ ncm_serialize_get_by_name (NcmSerialize *ser, const gchar *name)
 {
   g_assert (name != NULL);
   {
-    GObject *obj = g_hash_table_lookup (ser->name_ptr, name);
-    if (obj != NULL)
+    gpointer obj = NULL;
+    if (g_hash_table_lookup_extended (ser->name_ptr, name, NULL, &obj))
       return g_object_ref (obj);
     else
       return NULL;
@@ -399,6 +414,46 @@ ncm_serialize_set (NcmSerialize *ser, gpointer obj, const gchar *name, gboolean
   }
 }
 
+/**
+ * ncm_serialize_unset:
+ * @ser: a #NcmSerialize.
+ * @obj: (type GObject): a #GObject.
+ *
+ * Removes the object @obj to @ser using @name, it does nothing
+ * if the instance @obj is not present in @ser.
+ *
+ */
+void
+ncm_serialize_unset (NcmSerialize *ser, gpointer obj)
+{
+  if (ncm_serialize_contain_instance (ser, obj))
+  {
+    const gchar *name = ncm_serialize_peek_name (ser, obj);
+    g_hash_table_remove (ser->name_ptr, name);
+    g_hash_table_remove (ser->ptr_name, obj);
+  }
+}
+
+/**
+ * ncm_serialize_remove_ser:
+ * @ser: a #NcmSerialize.
+ * @obj: (type GObject): a #GObject.
+ *
+ * Removes the object @obj to @ser using @name, it does nothing
+ * if the instance @obj is not present in @ser.
+ *
+ */
+void
+ncm_serialize_remove_ser (NcmSerialize *ser, gpointer obj)
+{
+  gchar *saved_name = NULL;
+  if (g_hash_table_lookup_extended (ser->saved_ptr_name, obj, NULL, (gpointer *)&saved_name))
+  {
+    g_hash_table_remove (ser->saved_ptr_name, obj);
+    g_hash_table_remove (ser->saved_name_ser, saved_name);
+  }
+}
+
 static void
 _ncm_serialize_save_ser (NcmSerialize *ser, gchar *name, gpointer obj, GVariant *ser_var)
 {
@@ -406,19 +461,17 @@ _ncm_serialize_save_ser (NcmSerialize *ser, gchar *name, gpointer obj, GVariant
   g_assert (name != NULL);
   g_assert (ser != NULL);
 
-  if (g_hash_table_lookup (ser->saved_name_ser, name) != NULL)
+  if (g_hash_table_lookup_extended (ser->saved_name_ser, name, NULL, NULL))
     g_error ("_ncm_serialize_save_ser: instance already saved.");
-  if (g_hash_table_lookup (ser->saved_ptr_name, obj) != NULL)
+  if (g_hash_table_lookup_extended (ser->saved_ptr_name, obj, NULL, NULL))
     g_error ("_ncm_serialize_save_ser: instance already saved.");
 
-  /*printf ("Saving: ``%s'' <=> %s\n", name, g_variant_print (ser_var, TRUE));*/
+  //printf ("Saving: ``%s'' <=> %s\n", name, g_variant_print (ser_var, TRUE));
 
   g_hash_table_insert (ser->saved_ptr_name,
                        g_object_ref (obj), g_strdup (name));
   g_hash_table_insert (ser->saved_name_ser,
                        g_strdup (name), g_variant_ref_sink (ser_var));
-
-  ser->autosave_count++;
 }
 
 /**
@@ -435,349 +488,48 @@ _ncm_serialize_save_ser (NcmSerialize *ser, gchar *name, gpointer obj, GVariant
 gboolean
 ncm_serialize_is_named (NcmSerialize *ser, const gchar *serobj, gchar **name)
 {
-  GError *error = NULL;
+  GError *error          = NULL;
+  GVariant *var_obj      = g_variant_parse (G_VARIANT_TYPE (NCM_SERIALIZE_OBJECT_TYPE), serobj, NULL, NULL, &error);
   GMatchInfo *match_info = NULL;
-  GVariant *var_obj = NULL;
-  GVariant *obj_name = NULL;
-  GVariant *params = NULL;
+  gchar *obj_name_str    = NULL;
+  gboolean is_named      = FALSE;
 
-  var_obj = g_variant_parse (G_VARIANT_TYPE (NCM_SERIALIZE_OBJECT_TYPE), serobj, NULL, NULL, &error);
   g_clear_error (&error);
 
   if (var_obj != NULL)
   {
-    obj_name = g_variant_get_child_value (var_obj, 0);
-    params = g_variant_get_child_value (var_obj, 1);
-    serobj = g_variant_get_string (obj_name, NULL);
+    GVariant *obj_name = g_variant_get_child_value (var_obj, 0);
+    obj_name_str       = g_variant_dup_string (obj_name, NULL);
+    
+    g_variant_unref (obj_name);
+    g_variant_unref (var_obj);
   }
-
-  if (g_regex_match (ser->is_named_regex, serobj, 0, &match_info))
+  else if (g_regex_match (ser->parse_obj_regex, serobj, 0, &match_info))
   {
-    if (name != NULL)
-      *name = g_match_info_fetch (match_info, 1);
+    obj_name_str = g_match_info_fetch (match_info, 1);
     g_match_info_free (match_info);
-
-    if (params != NULL && g_variant_n_children (params) > 0)
-      g_error ("ncm_serialize_is_named: Invalid named object ``%s'', named objects cannot have properties ``%s''.",
-               serobj, g_variant_print (params, TRUE));
-
-    if (obj_name != NULL)
-      g_variant_unref (obj_name);
-    if (var_obj != NULL)
-      g_variant_unref (var_obj);
-    if (params != NULL)
-      g_variant_unref (params);
-    return TRUE;
   }
   else
   {
-    g_match_info_free (match_info);
-    if (obj_name != NULL)
-      g_variant_unref (obj_name);
-    if (var_obj != NULL)
-      g_variant_unref (var_obj);
-    if (params != NULL)
-      g_variant_unref (params);
+    g_error ("ncm_serialize_is_named: cannot identify object (%s) in string '%s'.",
+             NCM_SERIALIZE_OBJECT_TYPE,
+             serobj);
+  }
+
+  *name = NULL;
+  if (g_regex_match (ser->is_named_regex, obj_name_str, 0, &match_info))
+  {
     if (name != NULL)
-      *name = NULL;
-    return FALSE;
+      *name = g_match_info_fetch (match_info, 2);
+    is_named = TRUE;
   }
+  
+  g_match_info_free (match_info);
+  g_free (obj_name_str);
+  
+  return is_named;
 }
 
-/* Stole from glib 2.36.1 */
-/* GDBus - GLib D-Bus Library
- *
- * Copyright (C) 2008-2010 Red Hat, Inc.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
- *
- * Author: David Zeuthen <davidz@redhat.com>
- */
-#if ((GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 30))
-
-static void
-g_dbus_gvariant_to_gvalue (GVariant *value, GValue *out_gvalue)
-{
-  const GVariantType *type;
-  gchar **array;
-
-  g_return_if_fail (value != NULL);
-  g_return_if_fail (out_gvalue != NULL);
-
-  memset (out_gvalue, '\0', sizeof (GValue));
-
-  switch (g_variant_classify (value))
-  {
-    case G_VARIANT_CLASS_BOOLEAN:
-      g_value_init (out_gvalue, G_TYPE_BOOLEAN);
-      g_value_set_boolean (out_gvalue, g_variant_get_boolean (value));
-      break;
-
-    case G_VARIANT_CLASS_BYTE:
-      g_value_init (out_gvalue, G_TYPE_UCHAR);
-      g_value_set_uchar (out_gvalue, g_variant_get_byte (value));
-      break;
-
-    case G_VARIANT_CLASS_INT16:
-      g_value_init (out_gvalue, G_TYPE_INT);
-      g_value_set_int (out_gvalue, g_variant_get_int16 (value));
-      break;
-
-    case G_VARIANT_CLASS_UINT16:
-      g_value_init (out_gvalue, G_TYPE_UINT);
-      g_value_set_uint (out_gvalue, g_variant_get_uint16 (value));
-      break;
-
-    case G_VARIANT_CLASS_INT32:
-      g_value_init (out_gvalue, G_TYPE_INT);
-      g_value_set_int (out_gvalue, g_variant_get_int32 (value));
-      break;
-
-    case G_VARIANT_CLASS_UINT32:
-      g_value_init (out_gvalue, G_TYPE_UINT);
-      g_value_set_uint (out_gvalue, g_variant_get_uint32 (value));
-      break;
-
-    case G_VARIANT_CLASS_INT64:
-      g_value_init (out_gvalue, G_TYPE_INT64);
-      g_value_set_int64 (out_gvalue, g_variant_get_int64 (value));
-      break;
-
-    case G_VARIANT_CLASS_UINT64:
-      g_value_init (out_gvalue, G_TYPE_UINT64);
-      g_value_set_uint64 (out_gvalue, g_variant_get_uint64 (value));
-      break;
-
-    case G_VARIANT_CLASS_DOUBLE:
-      g_value_init (out_gvalue, G_TYPE_DOUBLE);
-      g_value_set_double (out_gvalue, g_variant_get_double (value));
-      break;
-
-    case G_VARIANT_CLASS_STRING:
-      g_value_init (out_gvalue, G_TYPE_STRING);
-      g_value_set_string (out_gvalue, g_variant_get_string (value, NULL));
-      break;
-
-    case G_VARIANT_CLASS_OBJECT_PATH:
-      g_value_init (out_gvalue, G_TYPE_STRING);
-      g_value_set_string (out_gvalue, g_variant_get_string (value, NULL));
-      break;
-
-    case G_VARIANT_CLASS_SIGNATURE:
-      g_value_init (out_gvalue, G_TYPE_STRING);
-      g_value_set_string (out_gvalue, g_variant_get_string (value, NULL));
-      break;
-
-    case G_VARIANT_CLASS_ARRAY:
-    {
-      type = g_variant_get_type (value);
-      switch (g_variant_type_peek_string (type)[1])
-      {
-        case G_VARIANT_CLASS_BYTE:
-          g_value_init (out_gvalue, G_TYPE_STRING);
-          g_value_set_string (out_gvalue, g_variant_get_bytestring (value));
-          break;
-
-        case G_VARIANT_CLASS_STRING:
-          g_value_init (out_gvalue, G_TYPE_STRV);
-          array = g_variant_dup_strv (value, NULL);
-          g_value_take_boxed (out_gvalue, array);
-          break;
-
-        case G_VARIANT_CLASS_ARRAY:
-        {
-          switch (g_variant_type_peek_string (type)[2])
-          {
-            case G_VARIANT_CLASS_BYTE:
-              g_value_init (out_gvalue, G_TYPE_STRV);
-              array = g_variant_dup_bytestring_array (value, NULL);
-              g_value_take_boxed (out_gvalue, array);
-              break;
-
-            default:
-              g_value_init (out_gvalue, G_TYPE_VARIANT);
-              g_value_set_variant (out_gvalue, value);
-              break;
-          }
-          break;
-        }
-        default:
-          g_value_init (out_gvalue, G_TYPE_VARIANT);
-          g_value_set_variant (out_gvalue, value);
-          break;
-      }
-      break;
-    }
-    case G_VARIANT_CLASS_HANDLE:
-    case G_VARIANT_CLASS_VARIANT:
-    case G_VARIANT_CLASS_MAYBE:
-    case G_VARIANT_CLASS_TUPLE:
-    case G_VARIANT_CLASS_DICT_ENTRY:
-      g_value_init (out_gvalue, G_TYPE_VARIANT);
-      g_value_set_variant (out_gvalue, value);
-      break;
-  }
-}
-
-static GVariant *
-g_dbus_gvalue_to_gvariant (const GValue *gvalue, const GVariantType *type)
-{
-  GVariant *ret;
-  const gchar *s;
-  const gchar * const *as;
-  const gchar *empty_strv[1] = {NULL};
-
-  g_return_val_if_fail (gvalue != NULL, NULL);
-  g_return_val_if_fail (type != NULL, NULL);
-
-  ret = NULL;
-
-  if (G_VALUE_TYPE (gvalue) == G_TYPE_VARIANT)
-  {
-    ret = g_value_dup_variant (gvalue);
-  }
-  else
-  {
-    switch (g_variant_type_peek_string (type)[0])
-    {
-      case G_VARIANT_CLASS_BOOLEAN:
-        ret = g_variant_ref_sink (g_variant_new_boolean (g_value_get_boolean (gvalue)));
-        break;
-
-      case G_VARIANT_CLASS_BYTE:
-        ret = g_variant_ref_sink (g_variant_new_byte (g_value_get_uchar (gvalue)));
-        break;
-
-      case G_VARIANT_CLASS_INT16:
-        ret = g_variant_ref_sink (g_variant_new_int16 (g_value_get_int (gvalue)));
-        break;
-
-      case G_VARIANT_CLASS_UINT16:
-        ret = g_variant_ref_sink (g_variant_new_uint16 (g_value_get_uint (gvalue)));
-        break;
-
-      case G_VARIANT_CLASS_INT32:
-        ret = g_variant_ref_sink (g_variant_new_int32 (g_value_get_int (gvalue)));
-        break;
-
-      case G_VARIANT_CLASS_UINT32:
-        ret = g_variant_ref_sink (g_variant_new_uint32 (g_value_get_uint (gvalue)));
-        break;
-
-      case G_VARIANT_CLASS_INT64:
-        ret = g_variant_ref_sink (g_variant_new_int64 (g_value_get_int64 (gvalue)));
-        break;
-
-      case G_VARIANT_CLASS_UINT64:
-        ret = g_variant_ref_sink (g_variant_new_uint64 (g_value_get_uint64 (gvalue)));
-        break;
-
-      case G_VARIANT_CLASS_DOUBLE:
-        ret = g_variant_ref_sink (g_variant_new_double (g_value_get_double (gvalue)));
-        break;
-
-      case G_VARIANT_CLASS_STRING:
-        s = g_value_get_string (gvalue);
-        if (s == NULL)
-          s = "";
-        ret = g_variant_ref_sink (g_variant_new_string (s));
-        break;
-
-      case G_VARIANT_CLASS_OBJECT_PATH:
-        s = g_value_get_string (gvalue);
-        if (s == NULL)
-          s = "/";
-        ret = g_variant_ref_sink (g_variant_new_object_path (s));
-        break;
-
-      case G_VARIANT_CLASS_SIGNATURE:
-        s = g_value_get_string (gvalue);
-        if (s == NULL)
-          s = "";
-        ret = g_variant_ref_sink (g_variant_new_signature (s));
-        break;
-
-      case G_VARIANT_CLASS_ARRAY:
-      {
-        switch (g_variant_type_peek_string (type)[1])
-        {
-          case G_VARIANT_CLASS_BYTE:
-          {
-            s = g_value_get_string (gvalue);
-            if (s == NULL)
-              s = "";
-            ret = g_variant_ref_sink (g_variant_new_bytestring (s));
-            break;
-          }
-          case G_VARIANT_CLASS_STRING:
-          {
-            as = g_value_get_boxed (gvalue);
-            if (as == NULL)
-              as = empty_strv;
-            ret = g_variant_ref_sink (g_variant_new_strv (as, -1));
-            break;
-          }
-          case G_VARIANT_CLASS_ARRAY:
-          {
-            switch (g_variant_type_peek_string (type)[2])
-            {
-              case G_VARIANT_CLASS_BYTE:
-                as = g_value_get_boxed (gvalue);
-                if (as == NULL)
-                  as = empty_strv;
-                ret = g_variant_ref_sink (g_variant_new_bytestring_array (as, -1));
-                break;
-              default:
-                ret = g_value_dup_variant (gvalue);
-                break;
-            }
-            break;
-          }
-          default:
-            ret = g_value_dup_variant (gvalue);
-            break;
-        }
-        break;
-      }
-      case G_VARIANT_CLASS_HANDLE:
-      case G_VARIANT_CLASS_VARIANT:
-      case G_VARIANT_CLASS_MAYBE:
-      case G_VARIANT_CLASS_TUPLE:
-      case G_VARIANT_CLASS_DICT_ENTRY:
-        ret = g_value_dup_variant (gvalue);
-        break;
-    }
-  }
-
-  if (ret == NULL)
-  {
-    GVariant *untrusted_empty;
-    untrusted_empty = g_variant_new_from_data (type, NULL, 0, FALSE, NULL, NULL);
-    ret = g_variant_ref_sink (g_variant_get_normal_form (untrusted_empty));
-    g_variant_unref (untrusted_empty);
-  }
-
-  g_assert (!g_variant_is_floating (ret));
-
-  return ret;
-}
-
-#endif
-/* Stole from glib 2.36.1 */
-
 /**
  * ncm_serialize_set_property:
  * @ser: a #NcmSerialize.
@@ -935,43 +687,6 @@ ncm_serialize_from_variant (NcmSerialize *ser, GVariant *var_obj)
   }
 }
 
-static GObject *
-_ncm_serialize_from_saved_or_named (NcmSerialize *ser, const gchar *obj_ser, GVariant *params)
-{
-  GObject *obj = NULL;
-  gchar *ni_name = NULL;
-
-  if (ncm_serialize_is_named (ser, obj_ser, &ni_name))
-  {
-    GVariant *var_obj;
-    if (params != NULL && g_variant_n_children (params) > 0)
-      g_error ("_ncm_serialize_from_saved_or_named: Invalid named object parameters ``%s'', named objects cannot have properties.",
-               g_variant_print (params, TRUE));
-
-    if (ncm_serialize_contain_name (ser, ni_name))
-    {
-      obj = ncm_serialize_get_by_name (ser, ni_name);
-      /*printf ("found ni: ``%s'' <=> %s [%d]\n", ni_name, obj_ser, obj->ref_count);*/
-      g_free (ni_name);
-      return obj;
-    }
-    else if ((var_obj = g_hash_table_lookup (ser->saved_name_ser, ni_name)) != NULL)
-    {
-      obj = ncm_serialize_from_variant (ser, var_obj);
-      if (ser->opts & NCM_SERIALIZE_OPT_AUTONAME_SER)
-        ncm_serialize_set (ser, obj, ni_name, FALSE);
-      /*printf ("found saved: ``%s'' <=> %s [%d]\n", ni_name, obj_ser, obj->ref_count);*/
-      g_free (ni_name);
-      return obj;
-    }
-    else
-      g_error ("_ncm_serialize_from_saved_or_named: Creating object from ``%s'', depending object ``%s'' not found.",
-               obj_ser, ni_name);
-  }
-
-  return obj;
-}
-
 /**
  * ncm_serialize_from_string:
  * @ser: a #NcmSerialize.
@@ -984,19 +699,16 @@ _ncm_serialize_from_saved_or_named (NcmSerialize *ser, const gchar *obj_ser, GVa
 GObject *
 ncm_serialize_from_string (NcmSerialize *ser, const gchar *obj_ser)
 {
-  GError *error = NULL;
   GMatchInfo *match_info = NULL;
-  GVariant *var_obj = NULL;
-  GObject *obj = _ncm_serialize_from_saved_or_named (ser, obj_ser, NULL);
-  gchar *error_msg = NULL;
+  GObject *obj           = NULL;
+  GError *error          = NULL;
+  gchar *error_msg       = NULL;
+  GVariant *var_obj      = g_variant_parse (G_VARIANT_TYPE (NCM_SERIALIZE_OBJECT_TYPE), obj_ser, NULL, NULL, &error);
 
-  if (obj != NULL)
-    return obj;
-
-  var_obj = g_variant_parse (G_VARIANT_TYPE (NCM_SERIALIZE_OBJECT_TYPE), obj_ser, NULL, NULL, &error);
   if (error != NULL)
     error_msg = g_strdup (error->message);
   g_clear_error (&error);
+
   if (var_obj != NULL)
   {
     obj = ncm_serialize_from_variant (ser, var_obj);
@@ -1004,9 +716,9 @@ ncm_serialize_from_string (NcmSerialize *ser, const gchar *obj_ser)
   }
   else if (g_regex_match (ser->parse_obj_regex, obj_ser, 0, &match_info))
   {
+    GVariant *params = NULL;
     gchar *obj_name = g_match_info_fetch (match_info, 1);
     gchar *obj_prop = g_match_info_fetch (match_info, 2);
-    GVariant *params = NULL;
 
     g_free (error_msg);
     if (obj_prop != NULL && strlen (obj_prop) > 0)
@@ -1015,7 +727,7 @@ ncm_serialize_from_string (NcmSerialize *ser, const gchar *obj_ser)
                                 obj_prop, NULL, NULL, &error);
       if (error != NULL)
       {
-        g_error ("ncm_serialize_from_string: cannot parse object '%s' parameters '%s', error %s.", obj_name, obj_prop, error->message);
+        g_error ("ncm_serialize_from_string: cannot parse object `%s' parameters `%s', error: %s.", obj_name, obj_prop, error->message);
         g_error_free (error);
       }
     }
@@ -1031,7 +743,7 @@ ncm_serialize_from_string (NcmSerialize *ser, const gchar *obj_ser)
   else
   {
     g_match_info_free (match_info);
-    g_error ("ncm_serialize_from_string: cannot indentify object (%s) in string '%s', variant error `%s'.",
+    g_error ("ncm_serialize_from_string: cannot identify object (%s) in string '%s', variant error `%s'.",
              NCM_SERIALIZE_OBJECT_TYPE,
              obj_ser,
              error_msg);
@@ -1085,26 +797,54 @@ ncm_serialize_from_file (NcmSerialize *ser, const gchar *filename)
 GObject *
 ncm_serialize_from_name_params (NcmSerialize *ser, const gchar *obj_name, GVariant *params)
 {
-  GType gtype = g_type_from_name (obj_name);
-  GObject *obj = _ncm_serialize_from_saved_or_named (ser, obj_name, params);
+  GMatchInfo *match_info = NULL;
+  gsize nprop            = (params != NULL) ? g_variant_n_children (params) : 0;
+  GObject *obj           = NULL;
+  gchar *name            = NULL;
+  GType gtype;
+
+  if (g_regex_match (ser->is_named_regex, obj_name, 0, &match_info))
+  {
+    gchar *cobj_name = g_match_info_fetch (match_info, 1);
+
+    name = g_match_info_fetch (match_info, 2);
+
+    gtype = g_type_from_name (cobj_name);
+    g_free (cobj_name);
+  }
+  else
+    gtype = g_type_from_name (obj_name);
+
+  g_match_info_free (match_info);
+
+  if ((name != NULL) && ncm_serialize_contain_name (ser, name))
+    obj = ncm_serialize_get_by_name (ser, name);
 
   if (obj != NULL)
-    return obj;
+  {
+    if (nprop > 0)
+      g_error ("ncm_serialize_from_name_params: cannot create object `%s' with properties, it was found on saved/named instances.",
+               obj_name);
+    else
+    {
+      g_clear_pointer (&name, g_free);
+      return obj;
+    }
+  }
 
   if (gtype == 0)
-    g_error ("ncm_serialize_from_name_params: object '%s' is not registered.", obj_name);
+    g_error ("ncm_serialize_from_name_params: object `%s' is not registered.", obj_name);
 
   g_assert (params == NULL || g_variant_is_of_type (params, G_VARIANT_TYPE (NCM_SERIALIZE_PROPERTIES_TYPE)));
 
   if (params != NULL)
   {
-    GVariantIter *p_iter = g_variant_iter_new (params);
-    gsize nprop = g_variant_iter_n_children (p_iter);
-    GParameter *gprop = g_new (GParameter, nprop);
-    GVariant *var = NULL;
-    guint i = 0;
+    GVariantIter *p_iter  = g_variant_iter_new (params);
+    GParameter *gprop     = g_new (GParameter, nprop);
+    GVariant *var         = NULL;
     gboolean is_NcmVector = g_type_is_a (gtype, NCM_TYPE_VECTOR);
     gboolean is_NcmMatrix = g_type_is_a (gtype, NCM_TYPE_MATRIX);
+    guint i               = 0;
 
     while ((var = g_variant_iter_next_value (p_iter)))
     {
@@ -1147,15 +887,17 @@ ncm_serialize_from_name_params (NcmSerialize *ser, const gchar *obj_name, GVaria
       }
       else if (g_variant_is_of_type (val, G_VARIANT_TYPE (NCM_SERIALIZE_OBJECT_TYPE)))
       {
-        GVariant *nest_obj_key = g_variant_get_child_value (val, 0);
+        GVariant *nest_obj_key    = g_variant_get_child_value (val, 0);
         GVariant *nest_obj_params = g_variant_get_child_value (val, 1);
-        GValue lval = G_VALUE_INIT;
-        GObject *nest_obj =
+        GValue lval               = G_VALUE_INIT;
+        GObject *nest_obj         =
           ncm_serialize_from_name_params (ser,
                                           g_variant_get_string (nest_obj_key, NULL),
                                           nest_obj_params);
+
         g_value_init (&lval, G_TYPE_OBJECT);
         gprop[i].value = lval;
+        
         g_value_take_object (&gprop[i].value, nest_obj);
         g_variant_unref (nest_obj_key);
         g_variant_unref (nest_obj_params);
@@ -1180,6 +922,12 @@ ncm_serialize_from_name_params (NcmSerialize *ser, const gchar *obj_name, GVaria
   else
     obj = g_object_new (gtype, NULL);
 
+  if ((name != NULL) && (ser->opts & NCM_SERIALIZE_OPT_AUTOSAVE_SER))
+  {
+    ncm_serialize_set (ser, obj, name, FALSE);
+    g_free (name);
+  }
+  
   return obj;
 }
 
@@ -1293,9 +1041,6 @@ _ncm_serialize_gtype_to_gvariant_type (GType t)
   }
 }
 
-GVariant *_ncm_obj_array_ser (NcmObjArray *oa, NcmSerialize *ser);
-
-
 /**
  * ncm_serialize_gvalue_to_gvariant:
  * @ser: a #NcmSerialize.
@@ -1321,7 +1066,7 @@ ncm_serialize_gvalue_to_gvariant (NcmSerialize *ser, GValue *val)
       {
         GObject *nest_obj = g_value_get_object (val);
         if (nest_obj != NULL)
-          var = _ncm_serialize_to_variant (ser, nest_obj);
+          var = ncm_serialize_to_variant (ser, nest_obj);
         break;
       }
       case G_TYPE_ENUM:
@@ -1336,7 +1081,7 @@ ncm_serialize_gvalue_to_gvariant (NcmSerialize *ser, GValue *val)
         {
           NcmObjArray *oa = g_value_get_boxed (val);
           if (oa != NULL)
-            var = _ncm_obj_array_ser (oa, ser);
+            var = ncm_obj_array_ser (oa, ser);
         }
         else if (g_type_is_a (t, G_TYPE_STRV))
         {
@@ -1363,11 +1108,20 @@ ncm_serialize_gvalue_to_gvariant (NcmSerialize *ser, GValue *val)
   return var;
 }
 
+/**
+ * ncm_serialize_to_variant:
+ * @ser: a #NcmSerialize.
+ * @obj: a #GObject.
+ *
+ * Serialize the @obj to a @GVariant representation.
+ *
+ * Returns: (transfer full): A #GVariant dictionary describing the @obj.
+ */
 GVariant *
-_ncm_serialize_to_variant (NcmSerialize *ser, GObject *obj)
+ncm_serialize_to_variant (NcmSerialize *ser, GObject *obj)
 {
   GVariant *ser_var;
-  const gchar *obj_name = G_OBJECT_TYPE_NAME (obj);
+  gchar *obj_name = g_strdup (G_OBJECT_TYPE_NAME (obj));
   gchar *saved_name = NULL;
 
   if (ncm_serialize_contain_instance (ser, obj))
@@ -1378,7 +1132,7 @@ _ncm_serialize_to_variant (NcmSerialize *ser, GObject *obj)
     ser_var = g_variant_ref_sink (g_variant_new (NCM_SERIALIZE_OBJECT_TYPE, fname, NULL));
     g_free (fname);
   }
-  else if ((saved_name = g_hash_table_lookup (ser->saved_ptr_name, obj)) != NULL)
+  else if (g_hash_table_lookup_extended (ser->saved_ptr_name, obj, NULL, (gpointer *)&saved_name))
   {
     gchar *fname = g_strdup_printf ("%s[%s]", obj_name, saved_name);
     /*printf ("# Found instante %p at saved_ptr_name %s.\n", obj, fname);*/
@@ -1389,8 +1143,22 @@ _ncm_serialize_to_variant (NcmSerialize *ser, GObject *obj)
   {
     GObjectClass *klass = G_OBJECT_GET_CLASS (obj);
     guint n_properties, i;
-    GParamSpec **prop = g_object_class_list_properties (klass, &n_properties);
+    GParamSpec **prop   = g_object_class_list_properties (klass, &n_properties);
+    gchar *name = NULL;
 
+    if (ser->opts & NCM_SERIALIZE_OPT_AUTONAME_SER)
+    {
+      gchar *tmp  = obj_name;
+      
+      name = g_strdup_printf (NCM_SERIALIZE_AUTOSAVE_NAME NCM_SERIALIZE_AUTOSAVE_NFORMAT, ser->autosave_count);
+
+      obj_name = g_strdup_printf ("%s[%s]", tmp, name);
+
+      g_free (tmp);
+
+      ser->autosave_count++;
+    }
+    
     if (n_properties == 0)
     {
       g_free (prop);
@@ -1435,47 +1203,17 @@ _ncm_serialize_to_variant (NcmSerialize *ser, GObject *obj)
       ser_var = g_variant_ref_sink (g_variant_new (NCM_SERIALIZE_OBJECT_FORMAT, obj_name, params));
     }
 
-    if (ser->opts & NCM_SERIALIZE_OPT_AUTOSAVE_SER)
+    if (name != NULL)
     {
-      gchar *name = g_strdup_printf (NCM_SERIALIZE_AUTOSAVE_NAME NCM_SERIALIZE_AUTOSAVE_NFORMAT, ser->autosave_count);
       _ncm_serialize_save_ser (ser, name, obj, ser_var);
       g_free (name);
-      g_variant_unref (ser_var);
-      ser_var = _ncm_serialize_to_variant (ser, obj);
     }
   }
+
+  g_free (obj_name);
   return ser_var;
 }
 
-/**
- * ncm_serialize_to_variant:
- * @ser: a #NcmSerialize.
- * @obj: a #GObject.
- *
- * Serialize the @obj to a @GVariant representation.
- *
- * Returns: (transfer full): A #GVariant dictionary describing the @obj.
- */
-GVariant *
-ncm_serialize_to_variant (NcmSerialize *ser, GObject *obj)
-{
-  if (ser->opts & NCM_SERIALIZE_OPT_AUTOSAVE_SER)
-  {
-    GVariant *cser_var = _ncm_serialize_to_variant (ser, obj);
-    gchar *name = g_hash_table_lookup (ser->saved_ptr_name, obj);
-    GVariant *ser_var = g_hash_table_lookup (ser->saved_name_ser, name);
-
-    g_assert (name != NULL);
-    g_assert (ser_var != NULL);
-
-    g_variant_unref (cser_var);
-
-    return g_variant_ref_sink (ser_var);
-  }
-  else
-    return _ncm_serialize_to_variant (ser, obj);
-}
-
 /**
  * ncm_serialize_to_string:
  * @ser: a #NcmSerialize.
@@ -1500,6 +1238,7 @@ ncm_serialize_to_string (NcmSerialize *ser, GObject *obj, gboolean valid_variant
     gchar *obj_name = NULL;
     gchar *params_str;
     g_variant_get (ser_var, NCM_SERIALIZE_OBJECT_FORMAT, &obj_name, &params);
+
     if (g_variant_n_children (params) == 0)
     {
       serstr = obj_name;
@@ -1509,10 +1248,11 @@ ncm_serialize_to_string (NcmSerialize *ser, GObject *obj, gboolean valid_variant
       params_str = g_variant_print (params, TRUE);
       serstr = g_strdup_printf ("%s%s", obj_name, params_str);
       g_free (params_str);
+      g_free (obj_name);
     }
-    g_free (obj_name);
     g_variant_unref (params);
   }
+
   g_variant_unref (ser_var);
   return serstr;
 }
@@ -1556,7 +1296,7 @@ GObject *
 ncm_serialize_dup_obj (NcmSerialize *ser, GObject *obj)
 {
   GVariant *var = ncm_serialize_to_variant (ser, obj);
-  GObject *dup = ncm_serialize_from_variant (ser, var);
+  GObject *dup  = ncm_serialize_from_variant (ser, var);
   g_variant_unref (var);
   return dup;
 }
@@ -1726,6 +1466,36 @@ ncm_serialize_global_set (gpointer obj, const gchar *name, gboolean overwrite)
   ncm_serialize_unref (ser);
 }
 
+/**
+ * ncm_serialize_global_unset:
+ * @obj: (type GObject): a #GObject.
+ *
+ * Global version of ncm_serialize_unset().
+ *
+ */
+void
+ncm_serialize_global_unset (gpointer obj)
+{
+  NcmSerialize *ser = ncm_serialize_global ();
+  ncm_serialize_unset (ser, obj);
+  ncm_serialize_unref (ser);
+}
+
+/**
+ * ncm_serialize_global_remove_ser:
+ * @obj: (type GObject): a #GObject.
+ *
+ * Global version of ncm_serialize_remove_ser().
+ *
+ */
+void
+ncm_serialize_global_remove_ser (gpointer obj)
+{
+  NcmSerialize *ser = ncm_serialize_global ();
+  ncm_serialize_remove_ser (ser, obj);
+  ncm_serialize_unref (ser);
+}
+
 /**
  * ncm_serialize_global_is_named:
  * @serobj: serialized object.
