@@ -24,9 +24,9 @@
 
 /**
  * SECTION:ncm_sparam
- * @title: Model Scalar Parameter Description
- * @short_description: Describes the properties of a scalar parameter
- *
+ * @title: NcmSParam
+ * @short_description: Properties of a scalar parameter.
+ * 
  * This object comprises the necessary properties to define a scalar parameter.
  * It is used by #NcmModel to store the description of the scalar model parameters.
  * 
@@ -60,14 +60,14 @@ G_DEFINE_TYPE (NcmSParam, ncm_sparam, G_TYPE_OBJECT);
 
 /**
  * ncm_sparam_new:
- * @name: #NcmSParam:name.
- * @symbol: #NcmSParam:symbol.
- * @lower_bound: value of #NcmSParam:lower-bound.
- * @upper_bound: value of #NcmSParam:upper-bound.
- * @scale: value of #NcmSParam:scale.
- * @abstol: value of #NcmSParam:absolute-tolerance.
- * @default_val: value of #NcmSParam:default-value.
- * @ftype: a #NcmParamType.
+ * @name: #NcmSParam:name
+ * @symbol: #NcmSParam:symbol
+ * @lower_bound: value of #NcmSParam:lower-bound
+ * @upper_bound: value of #NcmSParam:upper-bound
+ * @scale: value of #NcmSParam:scale
+ * @abstol: value of #NcmSParam:absolute-tolerance
+ * @default_val: value of #NcmSParam:default-value
+ * @ftype: a #NcmParamType
  *
  * This function allocates memory for a new #NcmSParam object and sets its properties to the values from
  * the input arguments.
@@ -77,32 +77,32 @@ G_DEFINE_TYPE (NcmSParam, ncm_sparam, G_TYPE_OBJECT);
  * @abstol is the absolute error tolerance of the parameter.
  * @ftype indicates if the parameter will be fitted or not.
  *
- * Returns: A new #NcmSParam.
+ * Returns: A new #NcmSParam
  */
 NcmSParam *
-ncm_sparam_new (gchar *name, gchar *symbol, gdouble lower_bound, gdouble upper_bound, gdouble scale, gdouble abstol, gdouble default_val, NcmParamType ftype)
+ncm_sparam_new (const gchar *name, const gchar *symbol, gdouble lower_bound, gdouble upper_bound, gdouble scale, gdouble abstol, gdouble default_val, NcmParamType ftype)
 {
   NcmSParam *sparam = g_object_new (NCM_TYPE_SPARAM,
-                                        "name",               name,
-                                        "symbol",             symbol,
-                                        "lower-bound",        lower_bound,
-                                        "upper-bound",        upper_bound,
-                                        "scale",              scale,
-                                        "absolute-tolerance", abstol,
-                                        "default-value",      default_val,
-                                        "fit-type",           ftype,
-                                        NULL);
+                                    "name",               name,
+                                    "symbol",             symbol,
+                                    "lower-bound",        lower_bound,
+                                    "upper-bound",        upper_bound,
+                                    "scale",              scale,
+                                    "absolute-tolerance", abstol,
+                                    "default-value",      default_val,
+                                    "fit-type",           ftype,
+                                    NULL);
   return sparam;
 }
 
 /**
  * ncm_sparam_copy:
- * @sparam: a #NcmSParam.
+ * @sparam: a #NcmSParam
  *
  * Duplicates the #NcmSParam object setting the same values of the original propertities.
  *
- * Returns: (transfer full): A new #NcmSParam.
- */
+ * Returns: (transfer full): A new #NcmSParam
+   */
 NcmSParam *
 ncm_sparam_copy (NcmSParam *sparam)
 {
@@ -113,7 +113,7 @@ ncm_sparam_copy (NcmSParam *sparam)
 
 /**
  * ncm_sparam_free:
- * @sparam: a #NcmSParam.
+ * @sparam: a #NcmSParam
  *
  * Atomically decrements the reference count of @sparam by one. If the reference count drops to 0,
  * all memory allocated by @sparam is released.
@@ -127,7 +127,7 @@ ncm_sparam_free (NcmSParam *sparam)
 
 /**
  * ncm_sparam_clear:
- * @sparam: a #NcmSParam.
+ * @sparam: a #NcmSParam
  *
  * Atomically decrements the reference count of @sparam by one. If the reference count drops to 0,
  * all memory allocated by @sparam is released. Set the pointer to NULL.
@@ -141,12 +141,12 @@ ncm_sparam_clear (NcmSParam **sparam)
 
 /**
  * ncm_sparam_ref:
- * @sparam: a #NcmSParam.
+ * @sparam: a #NcmSParam
  *
- * Atomically increase the reference count of @sparam by one.
+ * Atomically increases the reference count of @sparam by one.
  *
  * Returns: (transfer full): @sparam
- */
+   */
 NcmSParam *
 ncm_sparam_ref (NcmSParam *sparam)
 {
@@ -155,8 +155,8 @@ ncm_sparam_ref (NcmSParam *sparam)
 
 /**
  * ncm_sparam_set_lower_bound:
- * @sparam: a #NcmSParam.
- * @lb: value of #NcmSParam:lower-bound.
+ * @sparam: a #NcmSParam
+ * @lb: value of #NcmSParam:lower-bound
  *
  * Sets the value @lb to the #NcmSParam:lower-bound property.
  *
@@ -170,7 +170,7 @@ ncm_sparam_set_lower_bound (NcmSParam *sparam, const gdouble lb)
 
 /**
  * ncm_sparam_get_lower_bound:
- * @sparam: a #NcmSParam.
+ * @sparam: a #NcmSParam
  *
  * Returns: the value of #NcmSParam:lower-bound property.
  */
@@ -182,8 +182,8 @@ ncm_sparam_get_lower_bound (const NcmSParam *sparam)
 
 /**
  * ncm_sparam_set_upper_bound:
- * @sparam: a #NcmSParam.
- * @ub: value of #NcmSParam:upper-bound.
+ * @sparam: a #NcmSParam
+ * @ub: value of #NcmSParam:upper-bound
  *
  * Sets the value @ub to the #NcmSParam:upper-bound property.
  *
@@ -197,7 +197,7 @@ ncm_sparam_set_upper_bound (NcmSParam *sparam, const gdouble ub)
 
 /**
  * ncm_sparam_get_upper_bound:
- * @sparam: a #NcmSParam.
+ * @sparam: a #NcmSParam
  *
  * Returns: The value of #NcmSParam:upper-bound property.
  */
@@ -209,8 +209,8 @@ ncm_sparam_get_upper_bound (const NcmSParam *sparam)
 
 /**
  * ncm_sparam_set_scale:
- * @sparam: a #NcmSParam.
- * @scale: value of #NcmSParam:scale.
+ * @sparam: a #NcmSParam
+ * @scale: value of #NcmSParam:scale
  *
  * Sets the value @scale to the #NcmSParam:scale property.
  *
@@ -225,7 +225,7 @@ ncm_sparam_set_scale (NcmSParam *sparam, const gdouble scale)
 
 /**
  * ncm_sparam_get_scale:
- * @sparam: a #NcmSParam.
+ * @sparam: a #NcmSParam
  *
  * Returns: The value of #NcmSParam:scale property.
  */
@@ -237,8 +237,8 @@ ncm_sparam_get_scale (const NcmSParam *sparam)
 
 /**
  * ncm_sparam_set_absolute_tolerance:
- * @sparam: a #NcmSParam.
- * @abstol: value of #NcmSParam:absolute-tolerance.
+ * @sparam: a #NcmSParam
+ * @abstol: value of #NcmSParam:absolute-tolerance
  *
  * Sets the value @abstol to the #NcmSParam:absolute-tolerance property.
  *
@@ -252,7 +252,7 @@ ncm_sparam_set_absolute_tolerance (NcmSParam *sparam, gdouble abstol)
 
 /**
  * ncm_sparam_get_absolute_tolerance:
- * @sparam: a #NcmSParam.
+ * @sparam: a #NcmSParam
  *
  * Returns: the value of #NcmSParam:absolute_tolerance property.
  */
@@ -264,8 +264,8 @@ ncm_sparam_get_absolute_tolerance (const NcmSParam *sparam)
 
 /**
  * ncm_sparam_set_default_value:
- * @sparam: a #NcmSParam.
- * @default_val: value of #NcmSParam:default-value.
+ * @sparam: a #NcmSParam
+ * @default_val: value of #NcmSParam:default-value
  *
  * Sets the value @default_val to the #NcmSParam:default-value property.
  *
@@ -278,7 +278,7 @@ ncm_sparam_set_default_value (NcmSParam *sparam, gdouble default_val)
 
 /**
  * ncm_sparam_get_default_value:
- * @sparam: a #NcmSParam.
+ * @sparam: a #NcmSParam
  *
  * Returns: the value of #NcmSParam:default-value property.
  */
@@ -290,8 +290,8 @@ ncm_sparam_get_default_value (const NcmSParam *sparam)
 
 /**
  * ncm_sparam_set_fit_type:
- * @sparam: a #NcmSParam.
- * @ftype: a #NcmParamType.
+ * @sparam: a #NcmSParam
+ * @ftype: a #NcmParamType
  *
  * Sets the value @ftype to the #NcmSParam:fit-type property.
  *
@@ -304,7 +304,7 @@ ncm_sparam_set_fit_type (NcmSParam *sparam, NcmParamType ftype)
 
 /**
  * ncm_sparam_get_fit_type:
- * @sparam: a #NcmSParam.
+ * @sparam: a #NcmSParam
  *
  * Returns: the #NcmParamType value of #NcmSParam:fit-type property.
  */
@@ -316,10 +316,10 @@ ncm_sparam_get_fit_type (const NcmSParam *sparam)
 
 /**
  * ncm_sparam_take_name:
- * @sparam: a #NcmSParam.
+ * @sparam: a #NcmSParam
  * @name: a string
  *
- * Take @name as the name string.
+ * Takes @name as the name string.
  * The caller doesn't have to free it any more.
  *
  */
@@ -332,10 +332,10 @@ ncm_sparam_take_name (NcmSParam *sparam, gchar *name)
 
 /**
  * ncm_sparam_take_symbol:
- * @sparam: a #NcmSParam.
+ * @sparam: a #NcmSParam
  * @symbol: a string
  *
- * Take @symbol as the symbol string.
+ * Takes @symbol as the symbol string.
  * The caller doesn't have to free it any more.
  *
  */
@@ -348,7 +348,7 @@ ncm_sparam_take_symbol (NcmSParam *sparam, gchar *symbol)
 
 /**
  * ncm_sparam_name:
- * @sparam: a #NcmSParam.
+ * @sparam: a #NcmSParam
  *
  * Returns: the internal name string. The caller must not free it.
  */
@@ -360,7 +360,7 @@ ncm_sparam_name (const NcmSParam *sparam)
 
 /**
  * ncm_sparam_symbol:
- * @sparam: a #NcmSParam.
+ * @sparam: a #NcmSParam
  *
  * Returns: the internal symbol string. The caller must not free it.
  */
@@ -388,9 +388,9 @@ _ncm_sparam_finalize (GObject *object)
 {
   NcmSParam *sparam = NCM_SPARAM (object);
   if (sparam->name)
-	g_free (sparam->name);
+    g_free (sparam->name);
   if (sparam->symbol)
-	g_free (sparam->symbol);
+    g_free (sparam->symbol);
 
   G_OBJECT_CLASS (ncm_sparam_parent_class)->finalize (object);
 }
@@ -403,33 +403,33 @@ _ncm_sparam_set_property (GObject *object, guint prop_id, const GValue *value, G
 
   switch (prop_id)
   {
-	case PROP_NAME:
-	  sparam->name = g_value_dup_string (value);
-	  break;
-	case PROP_SYMBOL:
-	  sparam->symbol = g_value_dup_string (value);
-	  break;
-	case PROP_LOWER_BOUND:
-	  ncm_sparam_set_lower_bound (sparam, g_value_get_double (value));
-	  break;
-	case PROP_UPPER_BOUND:
-	  ncm_sparam_set_upper_bound (sparam, g_value_get_double (value));
-	  break;
-	case PROP_SCALE:
-	  ncm_sparam_set_scale (sparam, g_value_get_double (value));
-	  break;
-	case PROP_ABSOLUTE_TOLERANCE:
-	  ncm_sparam_set_absolute_tolerance (sparam, g_value_get_double (value));
-	  break;
-	case PROP_DEFAULT_VALUE:
-	  ncm_sparam_set_default_value (sparam, g_value_get_double (value));
-	  break;
-	case PROP_FIT_TYPE:
-	  ncm_sparam_set_fit_type (sparam, g_value_get_enum (value));
-	  break;
-	default:
-	  G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-	  break;
+    case PROP_NAME:
+      sparam->name = g_value_dup_string (value);
+      break;
+    case PROP_SYMBOL:
+      sparam->symbol = g_value_dup_string (value);
+      break;
+    case PROP_LOWER_BOUND:
+      ncm_sparam_set_lower_bound (sparam, g_value_get_double (value));
+      break;
+    case PROP_UPPER_BOUND:
+      ncm_sparam_set_upper_bound (sparam, g_value_get_double (value));
+      break;
+    case PROP_SCALE:
+      ncm_sparam_set_scale (sparam, g_value_get_double (value));
+      break;
+    case PROP_ABSOLUTE_TOLERANCE:
+      ncm_sparam_set_absolute_tolerance (sparam, g_value_get_double (value));
+      break;
+    case PROP_DEFAULT_VALUE:
+      ncm_sparam_set_default_value (sparam, g_value_get_double (value));
+      break;
+    case PROP_FIT_TYPE:
+      ncm_sparam_set_fit_type (sparam, g_value_get_enum (value));
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
   }
 }
 
@@ -441,33 +441,33 @@ _ncm_sparam_get_property (GObject *object, guint prop_id, GValue *value, GParamS
 
   switch (prop_id)
   {
-	case PROP_NAME:
-	  g_value_set_string (value, sparam->name);
-	  break;
-	case PROP_SYMBOL:
-	  g_value_set_string (value, sparam->symbol);
-	  break;
-	case PROP_LOWER_BOUND:
-	  g_value_set_double (value, ncm_sparam_get_lower_bound (sparam));
-	  break;
-	case PROP_UPPER_BOUND:
-	  g_value_set_double (value, ncm_sparam_get_upper_bound (sparam));
-	  break;
-	case PROP_SCALE:
-	  g_value_set_double (value, ncm_sparam_get_scale (sparam));
-	  break;
-	case PROP_ABSOLUTE_TOLERANCE:
-	  g_value_set_double (value, ncm_sparam_get_absolute_tolerance (sparam));
-	  break;
-	case PROP_DEFAULT_VALUE:
-	  g_value_set_double (value, ncm_sparam_get_default_value (sparam));
-	  break;
-	case PROP_FIT_TYPE:
-	  g_value_set_enum (value, ncm_sparam_get_fit_type (sparam));
-	  break;
-	default:
-	  G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-	  break;
+    case PROP_NAME:
+      g_value_set_string (value, sparam->name);
+      break;
+    case PROP_SYMBOL:
+      g_value_set_string (value, sparam->symbol);
+      break;
+    case PROP_LOWER_BOUND:
+      g_value_set_double (value, ncm_sparam_get_lower_bound (sparam));
+      break;
+    case PROP_UPPER_BOUND:
+      g_value_set_double (value, ncm_sparam_get_upper_bound (sparam));
+      break;
+    case PROP_SCALE:
+      g_value_set_double (value, ncm_sparam_get_scale (sparam));
+      break;
+    case PROP_ABSOLUTE_TOLERANCE:
+      g_value_set_double (value, ncm_sparam_get_absolute_tolerance (sparam));
+      break;
+    case PROP_DEFAULT_VALUE:
+      g_value_set_double (value, ncm_sparam_get_default_value (sparam));
+      break;
+    case PROP_FIT_TYPE:
+      g_value_set_enum (value, ncm_sparam_get_fit_type (sparam));
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
   }
 }
 
@@ -476,9 +476,9 @@ ncm_sparam_class_init (NcmSParamClass *klass)
 {
   GObjectClass* object_class = G_OBJECT_CLASS (klass);
 
-  object_class->finalize = _ncm_sparam_finalize;
   object_class->set_property = _ncm_sparam_set_property;
   object_class->get_property = _ncm_sparam_get_property;
+  object_class->finalize = _ncm_sparam_finalize;
 
   /**
    * NcmSParam:name:
@@ -497,7 +497,7 @@ ncm_sparam_class_init (NcmSParamClass *klass)
    * NcmSParam:symbol:
    *
    * Parameter's name written in a usual form (including latex).
-   */
+     */
   g_object_class_install_property (object_class,
                                    PROP_SYMBOL,
                                    g_param_spec_string ("symbol",
@@ -510,7 +510,7 @@ ncm_sparam_class_init (NcmSParamClass *klass)
    * NcmSParam:lower-bound:
    *
    * Lower parameter threshold whose value is restricted to [-G_MAXDOUBLE, G_MAXDOUBLE].
-	 */
+     */
   g_object_class_install_property (object_class,
                                    PROP_LOWER_BOUND,
                                    g_param_spec_double ("lower-bound",
@@ -523,7 +523,7 @@ ncm_sparam_class_init (NcmSParamClass *klass)
    * NcmSParam:upper-bound:
    *
    * Upper parameter threshold whose value is restricted to [-G_MAXDOUBLE, G_MAXDOUBLE].
-   */
+     */
   g_object_class_install_property (object_class,
                                    PROP_UPPER_BOUND,
                                    g_param_spec_double ("upper-bound",
@@ -536,7 +536,7 @@ ncm_sparam_class_init (NcmSParamClass *klass)
    * NcmSParam:scale:
    *
    * Scale, whose value is restricted to [0, G_MAXDOUBLE], is the step used by #NcmFit to increment the value of the parameter.
-   */
+     */
   g_object_class_install_property (object_class,
                                    PROP_SCALE,
                                    g_param_spec_double ("scale",
@@ -549,7 +549,7 @@ ncm_sparam_class_init (NcmSParamClass *klass)
    * NcmSParam:absolute-tolerance:
    *
    * Absolute tolerance, whose value is restricted to [0, G_MAXDOUBLE], is the size of the error used by #NcmFit.
-   */
+     */
   g_object_class_install_property (object_class,
                                    PROP_ABSOLUTE_TOLERANCE,
                                    g_param_spec_double ("absolute-tolerance",
