@@ -24,8 +24,8 @@
 
 /**
  * SECTION:ncm_spline_cubic_notaknot
- * @title: Notaknot Cubic Spline
- * @short_description: Cubic spline with 'not a knot' boundary conditions
+ * @title: NcmSplineCubicNotaknot
+ * @short_description: Cubic spline implementation with 'not a knot' boundary conditions.
  *
  * This object implements the necessary functions to compute a cubic spline with
  * boundary conditions obtained with the 'not a knot' method.
@@ -39,6 +39,8 @@
 
 #include "math/ncm_spline_cubic_notaknot.h"
 #include "math/ncm_cfg.h"
+#include "math/ncm_util.h"
+#include "math/ncm_lapack.h"
 
 #include <math.h>
 #include <gsl/gsl_math.h>
@@ -80,21 +82,26 @@ ncm_spline_cubic_notaknot_new_full (NcmVector *xv, NcmVector *yv, gboolean init)
 static NcmSpline *
 _ncm_spline_cubic_notaknot_copy_empty (const NcmSpline *s)
 {
+  NCM_UNUSED (s);
 	return ncm_spline_cubic_notaknot_new ();
 }
 
 static gsize
 _ncm_spline_notaknot_min_size (const NcmSpline *s)
 {
+  NCM_UNUSED (s);
 	return 6;
 }
 
 static const gchar *
 _ncm_spline_notaknot_name (NcmSpline *s)
 {
+  NCM_UNUSED (s);
   return "NcmSplineCubicNotaknot";
 }
 
+#define NUMCOSMO_CHECK_SPLINE_NODES 1
+
 static void
 _ncm_spline_notaknot_prepare_base (NcmSpline *s)
 {
@@ -109,119 +116,104 @@ _ncm_spline_notaknot_prepare_base (NcmSpline *s)
 	const gdouble h_1 = ncm_vector_get (s->xv, 2) - ncm_vector_get (s->xv, 1);
 	const gdouble h_nm1 = ncm_vector_get (s->xv, n)   - ncm_vector_get (s->xv, nm1);
 	const gdouble h_nm2 = ncm_vector_get (s->xv, nm1) - ncm_vector_get (s->xv, nm2);
-#ifdef HAVE_LAPACKA
+  const gdouble h_0_p_2h_1     = h_0   + 2.0 * h_1;
+  const gdouble h_nm1_p_2h_nm2 = h_nm1 + 2.0 * h_nm2;
+  const gdouble ydiff_0 = ncm_vector_get (s->yv, 1) - ncm_vector_get (s->yv, 0);
+  const gdouble ydiff_1 = ncm_vector_get (s->yv, 2) - ncm_vector_get (s->yv, 1);
+  register gdouble h_i        = h_0;
+  register gdouble h_ip1      = h_1;
+  register gdouble ydiff_i   = ydiff_0;
+  register gdouble ydiff_ip1 = ydiff_1;
+  
 	NcmVector *g = sc->g;
 	sc->g = sc->c;
-#endif
 
-	size_t start_i = 0, pad_i = 0;
 	size_t i;
 
 	g_assert (sys_size > 1);
+#ifdef NUMCOSMO_CHECK_SPLINE_NODES
+  if (h_0 < 0.0 || h_1 < 0.0 || h_nm1 < 0.0)
+  {                                                                          
+    g_error ("_ncm_spline_notaknot_prepare_base: in node [0, 1, 2, %zu, %zu] (% 20.15g, % 20.15g, % 20.15g, % 20.15g, % 20.15g), (% 20.15g, % 20.15g, % 20.15g, % 20.15g, % 20.15g).", nm1, n,
+             ncm_vector_get (s->xv, 0), ncm_vector_get (s->xv, 1), ncm_vector_get (s->xv, 2), ncm_vector_get (s->xv, nm1), ncm_vector_get (s->xv, n),
+             ncm_vector_get (s->yv, 0), ncm_vector_get (s->yv, 1), ncm_vector_get (s->yv, 2), ncm_vector_get (s->yv, nm1), ncm_vector_get (s->yv, n));
+  }
+#endif
 
 	for (i = 1; i <= nm3; i++)
 	{
-		const gdouble h_i       = ncm_vector_get (s->xv, i + 1) - ncm_vector_get (s->xv, i);
-		const gdouble h_ip1     = ncm_vector_get (s->xv, i + 2) - ncm_vector_get (s->xv, i + 1);
-		const gdouble ydiff_i   = ncm_vector_get (s->yv, i + 1) - ncm_vector_get (s->yv, i);
-		const gdouble ydiff_ip1 = ncm_vector_get (s->yv, i + 2) - ncm_vector_get (s->yv, i + 1);
-		const gdouble g_i = 1.0 / h_i;
-		const gdouble g_ip1 = 1.0 / h_ip1;
+    h_i       = h_ip1;
+		h_ip1     = ncm_vector_get (s->xv, i + 2) - ncm_vector_get (s->xv, i + 1);
+    ydiff_i   = ydiff_ip1;
+		ydiff_ip1 = ncm_vector_get (s->yv, i + 2) - ncm_vector_get (s->yv, i + 1);
 
-		ncm_vector_fast_set (sc->offdiag, i, h_ip1);
-		ncm_vector_fast_set (sc->diag, i,    2.0 * (h_ip1 + h_i));
-		ncm_vector_fast_set (sc->g, 1 + i,   3.0 * (ydiff_ip1 * g_ip1 -  ydiff_i * g_i));
-	}
-
-	{
-		const gdouble ydiff_0 = ncm_vector_get (s->yv, 1) - ncm_vector_get (s->yv, 0);
-		const gdouble ydiff_1 = ncm_vector_get (s->yv, 2) - ncm_vector_get (s->yv, 1);
-		if (fabs((h_0 - h_1) / h_0) < GSL_SQRT_DBL_EPSILON)
-		{
-			start_i = 1;
-			ncm_vector_fast_set (sc->c, 1, 3.0 * (ydiff_1 -  ydiff_0 * h_1 / h_0) / ((h_1 + h_0) * (2.0 * h_1 + h_0)));
-			ncm_vector_fast_subfrom (sc->g, 1 + 1, h_1 * ncm_vector_fast_get (sc->c, 1));
-		}
-		else
-		{
-			ncm_vector_fast_set (sc->offdiag, 0, h_1);
-			ncm_vector_fast_set (sc->diag, 0,    h_1 * (2.0 * h_1 + h_0) / (h_1 - h_0));
-			ncm_vector_fast_set (sc->g, 1 + 0,   3.0 * h_1 * (ydiff_1 -  ydiff_0 * h_1 / h_0) / (h_1 * h_1 - h_0 * h_0));
-		}
-	}
-
-	{
-		const gdouble ydiff_nm1 = ncm_vector_get (s->yv, n)   - ncm_vector_get (s->yv, nm1);
-		const gdouble ydiff_nm2 = ncm_vector_get (s->yv, nm1) - ncm_vector_get (s->yv, nm2);
-
-		if (fabs((h_nm2 - h_nm1) / h_nm2) < GSL_SQRT_DBL_EPSILON)
-		{
-			pad_i = 1;
-			ncm_vector_fast_set (sc->c, nm1, 3.0 * (ydiff_nm1 * h_nm2 / h_nm1 - ydiff_nm2) / ((h_nm2 + h_nm1) * (2.0 * h_nm2 + h_nm1)));
-			ncm_vector_fast_subfrom (sc->g, 1 + nm1 - 2, h_nm2 * ncm_vector_fast_get (sc->c, nm1));
-		}
-		else
-		{
-			ncm_vector_fast_set (sc->offdiag, nm2, h_nm1);
-			ncm_vector_fast_set (sc->diag,    nm2, h_nm2 * (2.0 * h_nm2 + h_nm1) / (h_nm2 - h_nm1));
-			ncm_vector_fast_set (sc->g,   1 + nm2, 3.0 * h_nm2 * (ydiff_nm1 * h_nm2 / h_nm1 - ydiff_nm2) / (h_nm2 * h_nm2 - h_nm1 * h_nm1));
-		}
-	}
-
-	{
-		gsize loc_sys_size = sys_size - start_i - pad_i;
-#ifdef HAVE_LAPACKA
-		{
-			printf ("# nhocC[%zu] % 20.15g\n", nm2, ncm_vector_fast_get (sc->diag, nm2));
-			gint info = ncm_lapack_dptsv (&NCM_VECTOR_DATA(sc->diag)[start_i],
-			                              &NCM_VECTOR_DATA(sc->offdiag)[start_i],
-			                              &NCM_VECTOR_DATA(sc->g)[start_i + 1],
-			                              loc_sys_size);
-			sc->g = g;
-			if (info != 0)
-			{
-				for (i = 0; i < s->len; i++)
-				{
-					printf ("[%zu/%zu] [%zu, %zu] % 20.15g %20.15g [% 20.15g % 20.15g]\n", i, loc_sys_size, start_i, pad_i, ncm_vector_get (s->xv, i), ncm_vector_get (s->yv, i),
-					        ncm_vector_fast_get (sc->diag, i),
-					        ncm_vector_fast_get (sc->offdiag, i));
-				}
-
-			}
-			NCM_LAPACK_CHECK_INFO ("dptsv", info);
-		}
-#else
-		{
-			gsl_vector_view g_vec = gsl_vector_subvector (ncm_vector_gsl (sc->g), 1 + start_i, loc_sys_size);
-			gsl_vector_view diag_vec = gsl_vector_subvector (ncm_vector_gsl (sc->diag), start_i, loc_sys_size);
-			gsl_vector_view offdiag_vec = gsl_vector_subvector (ncm_vector_gsl (sc->offdiag), start_i, loc_sys_size - 1);
-			gsl_vector_view solution_vec = gsl_vector_subvector (ncm_vector_gsl (sc->c), start_i + 1, loc_sys_size);
-			gint status = gsl_linalg_solve_symm_tridiag (&diag_vec.vector,
-			                                             &offdiag_vec.vector,
-			                                             &g_vec.vector,
-			                                             &solution_vec.vector);
-			if (status != GSL_SUCCESS)
-			{
-				gint i;
-				for (i = 0; i < s->len; i++)
-					printf ("x= % 20.8g y = % 20.8g\n", ncm_vector_get (s->xv, i), ncm_vector_get (s->yv, i));
-			}
-
-			NCM_TEST_GSL_RESULT ("_ncm_spline_notaknot_prepare[gsl_linalg_solve_symm_tridiag]", status);
-		}
+#ifdef NUMCOSMO_CHECK_SPLINE_NODES
+    if (h_ip1 <= 0.0)
+    {
+      g_error ("_ncm_spline_notaknot_prepare_base: in node %zd of %zd x_ip2 = % 20.15g and x_ip1 = % 20.15g, y_ip2 = % 20.15g and y_ip1 = % 20.15g.", 
+               i, n,
+               ncm_vector_get (s->xv, i + 2), ncm_vector_get (s->xv, i + 1),
+               ncm_vector_get (s->yv, i + 2), ncm_vector_get (s->yv, i + 1));
+    }
 #endif
-		{
-			const gdouble c1   = ncm_vector_fast_get (sc->c, 1);
-			const gdouble c2   = ncm_vector_fast_get (sc->c, 2);
-			const gdouble cnm1 = ncm_vector_fast_get (sc->c, nm1);
-			const gdouble cnm2 = ncm_vector_fast_get (sc->c, nm2);
+    
+    {
+      const gdouble g_i       = 1.0 / h_i;
+      const gdouble g_ip1     = 1.0 / h_ip1;
 
-			ncm_vector_fast_set (sc->c, 0, c1 + h_0 * (c1 - c2) / h_1);
-			ncm_vector_fast_set (sc->c, n, cnm1 + h_nm1 * (cnm1 - cnm2) / h_nm2);
-		}
-
-		return;
+      ncm_vector_fast_set (sc->offdiag, i, h_ip1);
+      ncm_vector_fast_set (sc->diag,    i, 2.0 * (h_ip1 + h_i));
+      ncm_vector_fast_set (sc->g,   1 + i, 3.0 * (ydiff_ip1 * g_ip1 -  ydiff_i * g_i));
+    }
 	}
+
+  
+	{
+		const gdouble g_0     = 1.0 / h_0;
+		const gdouble g_1     = 1.0 / h_1;
+    
+    ncm_vector_fast_set (sc->c,         0, 3.0 * (ydiff_1 * g_1 -  ydiff_0 * g_0) / h_0_p_2h_1);
+    ncm_vector_fast_set (sc->c,         1, ncm_vector_fast_get (sc->c, 0) * h_1 / (h_1 + h_0));
+
+    ncm_vector_fast_addto (sc->diag,    1, (h_0 - h_1) * h_1 / h_0_p_2h_1);
+    ncm_vector_fast_subfrom (sc->g,     2, h_1 * ncm_vector_fast_get (sc->c, 1));
+  }
+
+	{
+		const gdouble ydiff_nm2 = ncm_vector_get (s->yv, nm1) - ncm_vector_get (s->yv, nm2);
+		const gdouble ydiff_nm1 = ncm_vector_get (s->yv, n)   - ncm_vector_get (s->yv, nm1);
+		const gdouble g_nm2     = 1.0 / h_nm2;
+		const gdouble g_nm1     = 1.0 / h_nm1;
+
+    ncm_vector_fast_set (sc->c,   n, 3.0 * (ydiff_nm1 * g_nm1 - ydiff_nm2 * g_nm2) / h_nm1_p_2h_nm2);
+    ncm_vector_fast_set (sc->c, nm1, ncm_vector_fast_get (sc->c, n) * h_nm2 / (h_nm2 + h_nm1));
+
+    ncm_vector_fast_addto (sc->diag,    nm1 - 2, (h_nm1 - h_nm2) * h_nm2 / h_nm1_p_2h_nm2);
+    ncm_vector_fast_subfrom (sc->g, 1 + nm1 - 2, h_nm2 * ncm_vector_fast_get (sc->c, nm1));
+  }
+
+	{
+		gsize loc_sys_size = sys_size - 2;
+    gint info = ncm_lapack_dptsv (ncm_vector_ptr (sc->diag, 1),
+                                  ncm_vector_ptr (sc->offdiag, 1),
+                                  ncm_vector_ptr (sc->g, 2),
+                                  ncm_vector_ptr (sc->g, 2),
+                                  loc_sys_size);
+    sc->g = g;
+    NCM_LAPACK_CHECK_INFO ("dptsv", info);
+	}
+
+  {
+    const gdouble c_2   = ncm_vector_fast_get (sc->c, 2);
+    const gdouble c_nm2 = ncm_vector_fast_get (sc->c, nm2);
+
+    ncm_vector_fast_subfrom (sc->c, 0, c_2 * (2.0 * h_0 + h_1) / h_0_p_2h_1);
+    ncm_vector_fast_subfrom (sc->c, 1, c_2 * (h_1 - h_0) / h_0_p_2h_1);
+
+    ncm_vector_fast_subfrom (sc->c, nm1, c_nm2 * (h_nm2 - h_nm1) / h_nm1_p_2h_nm2);
+    ncm_vector_fast_subfrom (sc->c,   n, c_nm2 * (h_nm2 + 2.0 * h_nm1) / h_nm1_p_2h_nm2);
+  }
+  return;
 }
 
 static void
@@ -251,6 +243,7 @@ _ncm_spline_notaknot_prepare (NcmSpline *s)
 static void
 ncm_spline_cubic_notaknot_init (NcmSplineCubicNotaknot *object)
 {
+  NCM_UNUSED (object);
 }
 
 static void
