@@ -38,6 +38,7 @@
 #include "build_cfg.h"
 
 #include "math/ncm_spline_cubic_notaknot.h"
+#include "math/ncm_spline_func.h"
 #include "math/ncm_stats_dist1d_epdf.h"
 #include "math/ncm_c.h"
 #include "ncm_enum_types.h"
@@ -46,6 +47,7 @@
 #ifdef NUMCOSMO_HAVE_FFTW3
 #include <fftw3.h>
 #endif /* NUMCOSMO_HAVE_FFTW3 */
+#include <gsl/gsl_sort.h>
 
 enum
 {
@@ -60,6 +62,19 @@ enum
 
 G_DEFINE_TYPE (NcmStatsDist1dEPDF, ncm_stats_dist1d_epdf, NCM_TYPE_STATS_DIST1D);
 
+typedef struct _NcmStatsDist1dEPDFObs
+{
+  gdouble x;
+  gdouble w;
+  gdouble n;
+} NcmStatsDist1dEPDFObs;
+
+static void 
+_ncm_stats_dist1d_epdf_free_double_slice (gpointer d)
+{
+  g_slice_free (NcmStatsDist1dEPDFObs, d);
+}
+
 static void
 ncm_stats_dist1d_epdf_init (NcmStatsDist1dEPDF *epdf1d)
 {
@@ -73,6 +88,7 @@ ncm_stats_dist1d_epdf_init (NcmStatsDist1dEPDF *epdf1d)
   epdf1d->n_obs              = 0;
   epdf1d->np_obs             = 0;
   epdf1d->obs                = NULL;
+  epdf1d->obs_seq            = g_sequence_new (_ncm_stats_dist1d_epdf_free_double_slice);
   epdf1d->min                = GSL_POSINF;
   epdf1d->max                = GSL_NEGINF;
 
@@ -87,19 +103,13 @@ ncm_stats_dist1d_epdf_init (NcmStatsDist1dEPDF *epdf1d)
   epdf1d->fft_data_to_tilde  = NULL;
   epdf1d->fft_tilde_to_est   = NULL;
 
+  epdf1d->ph_spline          = ncm_spline_cubic_notaknot_new ();
   epdf1d->p_spline           = ncm_spline_cubic_notaknot_new ();
   epdf1d->bw_set             = FALSE;
 
   ncm_stats_vec_enable_quantile (epdf1d->obs_stats, 0.5);
 }
 
-typedef struct _NcmStatsDist1dEPDFObs
-{
-  gdouble x;
-  gdouble w;
-  gdouble n;
-} NcmStatsDist1dEPDFObs;
-
 static void
 ncm_stats_dist1d_epdf_constructed (GObject *object)
 {
@@ -180,7 +190,7 @@ ncm_stats_dist1d_epdf_dispose (GObject *object)
 
   ncm_stats_vec_clear (&epdf1d->obs_stats);
   g_clear_pointer (&epdf1d->obs, g_array_unref);
-
+  
   ncm_vector_clear (&epdf1d->Iv);
   ncm_vector_clear (&epdf1d->p_data);
   ncm_vector_clear (&epdf1d->p_tilde);
@@ -188,6 +198,7 @@ ncm_stats_dist1d_epdf_dispose (GObject *object)
   ncm_vector_clear (&epdf1d->p_est);
   ncm_vector_clear (&epdf1d->xv);
   ncm_vector_clear (&epdf1d->pv);
+  ncm_spline_clear (&epdf1d->ph_spline);  
   ncm_spline_clear (&epdf1d->p_spline);  
   
   /* Chain up : end */  
@@ -201,6 +212,7 @@ ncm_stats_dist1d_epdf_finalize (GObject *object)
 
   g_clear_pointer (&epdf1d->fft_data_to_tilde, fftw_destroy_plan);
   g_clear_pointer (&epdf1d->fft_tilde_to_est, fftw_destroy_plan);
+  g_clear_pointer (&epdf1d->obs_seq, g_sequence_free);
   
   /* Chain up : end */  
   G_OBJECT_CLASS (ncm_stats_dist1d_epdf_parent_class)->finalize (object);
@@ -227,7 +239,7 @@ ncm_stats_dist1d_epdf_class_init (NcmStatsDist1dEPDFClass *klass)
                                    g_param_spec_uint ("max-obs",
                                                       NULL,
                                                       "Maximum observations before compacting",
-                                                      10, G_MAXUINT, 200,
+                                                      10, G_MAXUINT, 100000,
                                                       G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_NAME | G_PARAM_STATIC_BLURB));
   g_object_class_install_property (object_class,
                                    PROP_NOBS,
@@ -272,7 +284,7 @@ ncm_stats_dist1d_epdf_class_init (NcmStatsDist1dEPDFClass *klass)
 
 #define _NCM_STATS_DIST1D_HROT(sd,R,n) (pow (4.0 / 3.0, 1.0 / 5.0) * GSL_MIN ((sd), ((R) / 1.34)) * pow (n * 1.0, -1.0 / 5.0))
 
-gint 
+static gint 
 _ncm_stats_dist1d_epdf_cmp_double (gconstpointer a,
                                    gconstpointer b)
 {
@@ -286,6 +298,15 @@ _ncm_stats_dist1d_epdf_cmp_double (gconstpointer a,
 #define _NCM_STATS_DIST1D_EPDF_OBS_N(obs,epdf1d,sd) \
 0.5 * (erf (((obs)->x - (epdf1d)->min) / (sd)) + erf (((epdf1d)->max - (obs)->x) / (sd)))
 
+static gdouble ncm_stats_dist1d_epdf_p_gk (NcmStatsDist1dEPDF *epdf1d, gdouble x);
+
+static gdouble 
+ncm_stats_dist1d_epdf_p_gk_func (gdouble x, gpointer epdf1d)
+{
+  const gdouble p = ncm_stats_dist1d_epdf_p_gk (epdf1d, x);
+  return p;
+}
+
 static void
 _ncm_stats_dist1d_epdf_compact_obs (NcmStatsDist1dEPDF *epdf1d)
 {
@@ -294,7 +315,7 @@ _ncm_stats_dist1d_epdf_compact_obs (NcmStatsDist1dEPDF *epdf1d)
 
   if (epdf1d->list_sorted)
     return;
-  
+
   g_array_sort (epdf1d->obs, _ncm_stats_dist1d_epdf_cmp_double);
   j = 0;
 
@@ -311,42 +332,15 @@ _ncm_stats_dist1d_epdf_compact_obs (NcmStatsDist1dEPDF *epdf1d)
       
       if (fabs (obs_j->x - obs_i->x) < min_dist)
       {
-#ifdef _NCM_STATS_DIST1D_EPDF_GROUPING_ALL  
-        gdouble wx = (obs_j->x * obs_j->w + obs_i->x * obs_i->w);
-        gdouble w  = obs_i->w + obs_j->w;
-        guint k;
-        obs_len--;
-        for (k = i + 1; k < epdf1d->obs->len; k++)
-        {
-          NcmStatsDist1dEPDFObs *obs_ik = &g_array_index (epdf1d->obs, NcmStatsDist1dEPDFObs, k);
-          if (fabs (obs_ik->x - obs_i->x) < min_dist)
-          {
-            wx += obs_ik->x * obs_ik->w;
-            w  += obs_ik->w;
-            obs_len--;
-            i++;
-            obs_i = obs_ik;
-          }
-          else
-            break;
-        }
-        obs_j->x = wx / w;
-        obs_j->w = w;
-#else
         obs_j->x = (obs_j->x * obs_j->w + obs_i->x * obs_i->w) / (obs_i->w + obs_j->w);
         obs_j->w = obs_i->w + obs_j->w;
 
-        /*obs_j->n = _NCM_STATS_DIST1D_EPDF_OBS_N (obs_j, epdf1d, sd);*/
-        
         obs_len--;
-#endif /* _NCM_STATS_DIST1D_EPDF_GROUPING_ALL */
       }
       else
       {
         j++;
         
-        /*obs_i->n = _NCM_STATS_DIST1D_EPDF_OBS_N (obs_i, epdf1d, sd);*/        
-
         if (i != j)
         {
           g_array_index (epdf1d->obs, NcmStatsDist1dEPDFObs, j) = *obs_i; 
@@ -463,7 +457,6 @@ _ncm_stats_dist1d_epdf_estimate_h (NcmVector *p_tilde2, NcmVector *Iv, const gui
 static void 
 _ncm_stats_dist1d_epdf_autobw (NcmStatsDist1dEPDF *epdf1d)
 {
-  const guint obs_len   = epdf1d->obs->len;
   const guint nbins     = exp2 (14.0 /*ceil (log2 (epdf1d->obs->len * 10))*/);
   const gdouble delta_l = (epdf1d->max - epdf1d->min) * 2.0;
   const gdouble deltax  = delta_l / nbins;
@@ -495,7 +488,7 @@ _ncm_stats_dist1d_epdf_autobw (NcmStatsDist1dEPDF *epdf1d)
     ncm_vector_clear (&epdf1d->pv);
     epdf1d->pv = ncm_vector_new_fftw (nbins / 2 + 1);
 
-    ncm_spline_set (epdf1d->p_spline, epdf1d->xv, epdf1d->pv, FALSE);
+    ncm_spline_set (epdf1d->ph_spline, epdf1d->xv, epdf1d->pv, FALSE);
 
     epdf1d->fftsize = nbins;
 
@@ -512,7 +505,7 @@ _ncm_stats_dist1d_epdf_autobw (NcmStatsDist1dEPDF *epdf1d)
       epdf1d->fft_tilde_to_est  = fftw_plan_r2r_1d (nbins, ncm_vector_data (epdf1d->p_tilde), ncm_vector_data (epdf1d->p_est),
                                                     FFTW_REDFT01, fftw_default_flags | FFTW_DESTROY_INPUT);
 
-      ncm_cfg_lock_plan_fftw ();
+      ncm_cfg_unlock_plan_fftw ();
 
       ncm_cfg_save_fftw_wisdom ("ncm_stats_dist1d_wisdown");
 
@@ -526,19 +519,21 @@ _ncm_stats_dist1d_epdf_autobw (NcmStatsDist1dEPDF *epdf1d)
   ncm_vector_set_zero (epdf1d->p_data);
 
   j = 0;
-  for (i = 0; i < obs_len; i++)
   {
-    NcmStatsDist1dEPDFObs *obs_i = &g_array_index (epdf1d->obs, NcmStatsDist1dEPDFObs, i);
-    /*printf ("x %20.15g xc % 20.15g j = %u\n", obs_i->x, xc, j);*/
-    while (obs_i->x > xc)
-    {
-      /*printf ("adding zero to x %20.15g xc % 20.15g j = %u\n", obs_i->x, xc, j);*/
-      j++;
-      xc += deltax;
-    }
-    ncm_vector_fast_addto (epdf1d->p_data, j, obs_i->w / epdf1d->n_obs);
-  }
+    const guint obs_len   = epdf1d->obs->len;
 
+    for (i = 0; i < obs_len; i++)
+    {
+      NcmStatsDist1dEPDFObs *obs_i = &g_array_index (epdf1d->obs, NcmStatsDist1dEPDFObs, i);
+      while (obs_i->x > xc)
+      {
+        j++;
+        xc += deltax;
+      }
+      ncm_vector_fast_addto (epdf1d->p_data, j, obs_i->w / epdf1d->n_obs);
+    }
+  }
+  
   fftw_execute (epdf1d->fft_data_to_tilde);
 
   for (i = 0; i < nbins; i++)
@@ -598,7 +593,7 @@ _ncm_stats_dist1d_epdf_autobw (NcmStatsDist1dEPDF *epdf1d)
       j++;
     }
 
-    ncm_spline_prepare (epdf1d->p_spline);
+    ncm_spline_prepare (epdf1d->ph_spline);
   }
 }
 
@@ -631,7 +626,6 @@ _ncm_stats_dist1d_epdf_set_bw (NcmStatsDist1dEPDF *epdf1d)
     }
     epdf1d->bw_set = TRUE;
   }
-
 }
 
 static gdouble 
@@ -639,7 +633,6 @@ ncm_stats_dist1d_epdf_p_gk (NcmStatsDist1dEPDF *epdf1d, gdouble x)
 {
   NcmStatsDist1d *sd1 = NCM_STATS_DIST1D (epdf1d);
   gdouble res = 0.0;
-  gint i;
 
   if (x < epdf1d->min || x > epdf1d->max)
     return 0.0;
@@ -650,14 +643,14 @@ ncm_stats_dist1d_epdf_p_gk (NcmStatsDist1dEPDF *epdf1d, gdouble x)
   if (FALSE)
   {
     const gdouble bias_corr = 0.5 * (erf ((x - epdf1d->min) / (M_SQRT2 * epdf1d->h)) + erf ((epdf1d->max - x) / (M_SQRT2 * epdf1d->h)));
-    const gdouble phat = exp (ncm_spline_eval (epdf1d->p_spline, x));
+    const gdouble phat = exp (ncm_spline_eval (epdf1d->ph_spline, x));
 
     return phat / bias_corr;
   }
-  
-#ifndef _NCM_STATS_DIST1D_EPDF_DIRECT 
+
   {
     gint s = _ncm_stats_dist1d_epdf_bsearch (epdf1d->obs, x, 0, epdf1d->obs->len - 1);
+    gint i;
 
     for (i = s; i < epdf1d->obs->len; i++)
     {
@@ -685,27 +678,11 @@ ncm_stats_dist1d_epdf_p_gk (NcmStatsDist1dEPDF *epdf1d, gdouble x)
         break;
     }
   }
-#else   
-  for (i = 0; i < epdf1d->obs->len; i++)
-  {
-    NcmStatsDist1dEPDFObs *obs = &g_array_index (epdf1d->obs, NcmStatsDist1dEPDFObs, i);
-    const gdouble x_i   = obs->x;
-    const gdouble de_i  = (x - x_i) / epdf1d->h;
-    const gdouble de2_i = de_i * de_i;
-    const gdouble exp_i = obs->w * exp (-de2_i * 0.5);
-
-    res += exp_i;
-    
-    /*res += exp_i / obs->n;*/
-  }
-#endif /* _NCM_STATS_DIST1D_EPDF_DIRECT */
   
   {
     const gdouble phat      = (res / (sqrt (2.0 * M_PI) * epdf1d->h) + 1.0 / (sd1->xf - sd1->xi)) / (epdf1d->n_obs + 1.0);
     const gdouble bias_corr = 0.5 * (erf ((x - epdf1d->min) / (M_SQRT2 * epdf1d->h)) + erf ((epdf1d->max - x) / (M_SQRT2 * epdf1d->h)));
 
-    /*printf ("% 20.15g % 20.15g % 20.15g % 20.15g % 20.15g % 20.15g % 20.15g\n", x, res, epdf1d->h, epdf1d->min, epdf1d->max, phat, bias_corr);*/
-
     return phat / bias_corr;
   }
 }
@@ -714,12 +691,15 @@ static gdouble
 ncm_stats_dist1d_epdf_p (NcmStatsDist1d *sd1, gdouble x)
 {
   NcmStatsDist1dEPDF *epdf1d = NCM_STATS_DIST1D_EPDF (sd1);
+  /*return fabs (ncm_spline_eval (epdf1d->p_spline, x));*/
   return ncm_stats_dist1d_epdf_p_gk (epdf1d, x);
 }
 
 static gdouble 
 ncm_stats_dist1d_epdf_m2lnp (NcmStatsDist1d *sd1, gdouble x)
 {
+  /*NcmStatsDist1dEPDF *epdf1d = NCM_STATS_DIST1D_EPDF (sd1);
+  return -2.0 * log (fabs (ncm_spline_eval (epdf1d->p_spline, x)));*/
   return -2.0 * log (ncm_stats_dist1d_epdf_p (sd1, x));
 }
 
@@ -748,6 +728,7 @@ ncm_stats_dist1d_epdf_prepare (NcmStatsDist1d *sd1)
 {
   NcmStatsDist1dEPDF *epdf1d = NCM_STATS_DIST1D_EPDF (sd1);
 
+  _ncm_stats_dist1d_epdf_compact_obs (epdf1d);
   _ncm_stats_dist1d_epdf_set_bw (epdf1d);
   
   if (FALSE)
@@ -758,6 +739,16 @@ ncm_stats_dist1d_epdf_prepare (NcmStatsDist1d *sd1)
   else
     ncm_stats_dist1d_epdf_update_limits (epdf1d);
 
+  if (FALSE)
+  {
+    gsl_function F;
+
+    F.function = ncm_stats_dist1d_epdf_p_gk_func;
+    F.params   = epdf1d;
+        
+    ncm_spline_set_func (epdf1d->p_spline, NCM_SPLINE_FUNCTION_SPLINE, &F, epdf1d->min, epdf1d->max, 0, 1.0e-7);
+  }
+  
   return;
 }
 
@@ -815,7 +806,7 @@ ncm_stats_dist1d_epdf_new (gdouble sd_min_scale)
 void
 ncm_stats_dist1d_epdf_add_obs (NcmStatsDist1dEPDF *epdf1d, gdouble x)
 {
-  const NcmStatsDist1dEPDFObs obs = {x, 1.0, 1.0};
+  NcmStatsDist1dEPDFObs obs = {x, 1.0, 1.0};
   const gdouble new_max = GSL_MAX (epdf1d->max, x);
   const gdouble new_min = GSL_MIN (epdf1d->min, x);
 
@@ -826,23 +817,23 @@ ncm_stats_dist1d_epdf_add_obs (NcmStatsDist1dEPDF *epdf1d, gdouble x)
   }
 
   epdf1d->bw_set = FALSE;
-    
+
   ncm_stats_vec_set (epdf1d->obs_stats, 0, x);
   ncm_stats_vec_update (epdf1d->obs_stats);
 
+  epdf1d->n_obs++;
+
   g_array_append_val (epdf1d->obs, obs);
   epdf1d->list_sorted = FALSE;
-
-  epdf1d->n_obs++;
   epdf1d->np_obs++;
 
   if (epdf1d->np_obs > epdf1d->max_obs)
   {    
     _ncm_stats_dist1d_epdf_compact_obs (epdf1d);
-    epdf1d->np_obs = 0;
-    /*printf ("# new size %u %u\n", epdf1d->obs->len, epdf1d->max_obs);*/
+    epdf1d->max_obs = GSL_MAX (10 * epdf1d->obs->len, epdf1d->max_obs);
+    epdf1d->np_obs  = 0;
   }
-  
+
   epdf1d->max = new_max;
   epdf1d->min = new_min;
 }
