@@ -53,6 +53,11 @@
 #  endif
 #endif
 
+#include <complex.h>
+#ifdef NUMCOSMO_HAVE_FFTW3
+#include <fftw3.h>
+#endif /* NUMCOSMO_HAVE_FFTW3 */
+
 enum
 {
   PROP_0,
@@ -106,6 +111,25 @@ ncm_vector_new_full (gdouble *d, gsize size, gsize stride, gpointer pdata, GDest
   return cv;
 }
 
+/**
+ * ncm_vector_new_fftw:
+ * @size: number of doubles allocated.
+ * 
+ * This function allocates memory for a new #NcmVector of double
+ * with @n components. It uses fftw_alloc_real in order to be used
+ * by fftw* functions.
+ *
+ * Returns: A new #NcmVector.
+ */
+NcmVector *
+ncm_vector_new_fftw (guint size)
+{
+  gdouble *d = fftw_alloc_real (size);
+  NcmVector *cv = ncm_vector_new_full (d, size, 1, d, (GDestroyNotify) fftw_free); 
+  cv->type = NCM_VECTOR_MALLOC;
+  return cv;
+}
+
 /**
  * ncm_vector_new_gsl: (skip)
  * @gv: vector from GNU Scientific Library (GSL) to be converted into a #NcmVector.
@@ -635,6 +659,14 @@ ncm_vector_log_vals_func (const NcmVector *v, const gchar *prestr, const gchar *
  * This function multiplies the components of the vector @cv by the constant factor @val.
  *
  */
+/**
+ * ncm_vector_add_constant:
+ * @cv: a #NcmVector.
+ * @val: a cosntant double.
+ *
+ * This function adds the constant @val to all components.
+ *
+ */
 /**
  * ncm_vector_div:
  * @cv1: a #NcmVector, numerator.
@@ -765,6 +797,57 @@ ncm_vector_log_vals_func (const NcmVector *v, const gchar *prestr, const gchar *
  * Returns: FIXME
  */
 
+
+/**
+ * ncm_vector_get_minmax: 
+ * @cv: a @NcmVector.
+ * @min: (out): minimum component value of @cv
+ * @max: (out): maximum component value of @cv
+ * 
+ * Gets the minimum/maximum value of the vector components.
+ * 
+ */
+void 
+ncm_vector_get_minmax (const NcmVector *cv, gdouble *min, gdouble *max)
+{
+  guint size = ncm_vector_len (cv);
+  guint i;
+
+  *min = HUGE_VAL;
+  *max = -HUGE_VAL;
+  for (i = 0; i < size; i++)
+  {
+    const gdouble v = ncm_vector_get (cv, i);
+    *min = GSL_MIN (*min, v);
+    *max = GSL_MAX (*max, v);
+  }
+}
+
+/**
+ * ncm_vector_get_absminmax: 
+ * @cv: a @NcmVector.
+ * @absmin: (out): minimum component absolute value of @cv
+ * @absmax: (out): maximum component absolute value of @cv
+ * 
+ * Gets the minimum/maximum absolute value of the vector components.
+ * 
+ */
+void 
+ncm_vector_get_absminmax (const NcmVector *cv, gdouble *absmin, gdouble *absmax)
+{
+  guint size = ncm_vector_len (cv);
+  guint i;
+
+  *absmin = HUGE_VAL;
+  *absmax = 0.0;
+  for (i = 0; i < size; i++)
+  {
+    const gdouble v = fabs (ncm_vector_get (cv, i));
+    *absmin = GSL_MIN (*absmin, v);
+    *absmax = GSL_MAX (*absmax, v);
+  }
+}
+
 /**
  * ncm_vector_set_from_variant: 
  * @cv: a @NcmVector.
