@@ -44,6 +44,12 @@ G_BEGIN_DECLS
 typedef struct _NcmVectorClass NcmVectorClass;
 typedef struct _NcmVector NcmVector;
 
+struct _NcmVectorClass
+{
+  /*< private >*/
+  GObjectClass parent_class;
+};
+
 /**
  * NcmVectorInternal:
  * @NCM_VECTOR_SLICE: FIXME
@@ -74,12 +80,6 @@ struct _NcmVector
   NcmVectorInternal type;
 };
 
-struct _NcmVectorClass
-{
-  /*< private >*/
-  GObjectClass parent_class;
-};
-
 typedef gdouble (*NcmVectorCompFunc) (gdouble v_i, guint i, gpointer user_data);
 
 GType ncm_vector_get_type (void) G_GNUC_CONST;
@@ -88,6 +88,7 @@ GType ncm_vector_get_type (void) G_GNUC_CONST;
 
 NcmVector *ncm_vector_new (gsize n);
 NcmVector *ncm_vector_new_full (gdouble *d, gsize size, gsize stride, gpointer pdata, GDestroyNotify pfree);
+NcmVector *ncm_vector_new_fftw (guint size);
 NcmVector *ncm_vector_new_gsl (gsl_vector *gv);
 NcmVector *ncm_vector_new_gsl_static (gsl_vector *gv);
 NcmVector *ncm_vector_new_array (GArray *a);
@@ -126,9 +127,12 @@ G_INLINE_FUNC void ncm_vector_addto (NcmVector *cv, const guint i, const gdouble
 G_INLINE_FUNC void ncm_vector_fast_addto (NcmVector *cv, const guint i, const gdouble val);
 G_INLINE_FUNC void ncm_vector_subfrom (NcmVector *cv, const guint i, const gdouble val);
 G_INLINE_FUNC void ncm_vector_fast_subfrom (NcmVector *cv, const guint i, const gdouble val);
+G_INLINE_FUNC void ncm_vector_mulby (NcmVector *cv, const guint i, const gdouble val);
+G_INLINE_FUNC void ncm_vector_fast_mulby (NcmVector *cv, const guint i, const gdouble val);
 G_INLINE_FUNC void ncm_vector_set_all (NcmVector *cv, const gdouble val);
 G_INLINE_FUNC void ncm_vector_set_array (NcmVector *cv, const gdouble *array);
 G_INLINE_FUNC void ncm_vector_scale (NcmVector *cv, const gdouble val);
+G_INLINE_FUNC void ncm_vector_add_constant (NcmVector *cv, const gdouble val);
 G_INLINE_FUNC void ncm_vector_div (NcmVector *cv1, const NcmVector *cv2);
 G_INLINE_FUNC void ncm_vector_add (NcmVector *cv1, const NcmVector *cv2);
 G_INLINE_FUNC void ncm_vector_sub (NcmVector *cv1, const NcmVector *cv2);
@@ -145,6 +149,9 @@ G_INLINE_FUNC const gsl_vector *ncm_vector_const_gsl (const NcmVector *cv);
 G_INLINE_FUNC guint ncm_vector_len (const NcmVector *cv);
 G_INLINE_FUNC guint ncm_vector_stride (const NcmVector *cv);
 
+void ncm_vector_get_minmax (const NcmVector *cv, gdouble *min, gdouble *max);
+void ncm_vector_get_absminmax (const NcmVector *cv, gdouble *absmin, gdouble *absmax);
+
 NcmVector *ncm_vector_dup (const NcmVector *cv);
 void ncm_vector_substitute (NcmVector **cv, NcmVector *nv, gboolean check_size);
 void ncm_vector_free (NcmVector *cv);
@@ -245,6 +252,18 @@ ncm_vector_fast_subfrom (NcmVector *cv, const guint i, const gdouble val)
   ncm_vector_gsl (cv)->data[i] = ncm_vector_gsl (cv)->data[i] - val;
 }
 
+G_INLINE_FUNC void
+ncm_vector_mulby (NcmVector *cv, const guint i, const gdouble val)
+{
+  gsl_vector_set (ncm_vector_gsl (cv), i, gsl_vector_get (ncm_vector_gsl (cv), i) * val);
+}
+
+G_INLINE_FUNC void
+ncm_vector_fast_mulby (NcmVector *cv, const guint i, const gdouble val)
+{
+  ncm_vector_gsl (cv)->data[i] *= val;
+}
+
 G_INLINE_FUNC void
 ncm_vector_set_all (NcmVector *cv, const gdouble val)
 {
@@ -266,6 +285,12 @@ ncm_vector_scale (NcmVector *cv, const gdouble val)
   gsl_vector_scale (ncm_vector_gsl (cv), val);
 }
 
+G_INLINE_FUNC void
+ncm_vector_add_constant (NcmVector *cv, const gdouble val)
+{
+  gsl_vector_add_constant (ncm_vector_gsl (cv), val);
+}
+
 G_INLINE_FUNC void
 ncm_vector_div (NcmVector *cv1, const NcmVector *cv2)
 {
@@ -293,6 +318,7 @@ ncm_vector_set_zero (NcmVector *cv)
 G_INLINE_FUNC void
 ncm_vector_memcpy (NcmVector *cv1, const NcmVector *cv2)
 {
+  g_assert_cmpuint (ncm_vector_len (cv1), ==, ncm_vector_len (cv2));
   gsl_vector_memcpy (ncm_vector_gsl (cv1), ncm_vector_const_gsl (cv2));
 }
 
