@@ -43,6 +43,9 @@
 #include "math/ncm_cfg.h"
 #include "math/ncm_mset_func_list.h"
 
+#include <gsl/gsl_errno.h>
+#include <gsl/gsl_math.h>
+
 G_DEFINE_ABSTRACT_TYPE (NcHICosmo, nc_hicosmo, NCM_TYPE_MODEL);
 
 static void
@@ -50,6 +53,8 @@ nc_hicosmo_init (NcHICosmo *cosmo)
 {
   cosmo->prim  = NULL;
   cosmo->reion = NULL;
+  cosmo->T     = gsl_root_fsolver_brent;
+  cosmo->s     = gsl_root_fsolver_alloc (cosmo->T);
 }
 
 static void
@@ -67,7 +72,9 @@ nc_hicosmo_dispose (GObject *object)
 static void
 nc_hicosmo_finalize (GObject *object)
 {
-
+  NcHICosmo *cosmo = NC_HICOSMO (object);
+  gsl_root_fsolver_free (cosmo->s);
+  
   /* Chain up : end */
   G_OBJECT_CLASS (nc_hicosmo_parent_class)->finalize (object);
 }
@@ -304,7 +311,7 @@ NCM_MODEL_SET_IMPL_FUNC(NC_HICOSMO,NcHICosmo,nc_hicosmo,NcHICosmoFunc0,xb)
  * @model_class: a #NcmModelClass
  * @f: FIXME
  *
- * FIXME
+ * Normalized Hubble function squared, $E^2(z)$.
  *
  */
 NCM_MODEL_SET_IMPL_FUNC(NC_HICOSMO,NcHICosmo,nc_hicosmo,NcHICosmoFunc1Z,E2)
@@ -314,7 +321,7 @@ NCM_MODEL_SET_IMPL_FUNC(NC_HICOSMO,NcHICosmo,nc_hicosmo,NcHICosmoFunc1Z,E2)
  * @model_class: a #NcmModelClass
  * @f: FIXME
  *
- * FIXME
+ * First derivative with respect to the redshift of the normalized Hubble function squared, $\frac{dE^2(z)}{dz}$. 
  *
  */
 NCM_MODEL_SET_IMPL_FUNC(NC_HICOSMO,NcHICosmo,nc_hicosmo,NcHICosmoFunc1Z,dE2_dz)
@@ -324,7 +331,7 @@ NCM_MODEL_SET_IMPL_FUNC(NC_HICOSMO,NcHICosmo,nc_hicosmo,NcHICosmoFunc1Z,dE2_dz)
  * @model_class: a #NcmModelClass
  * @f: FIXME
  *
- * FIXME
+ * Second derivative with respect to the redshift of the normalized Hubble function squared, $\frac{d^2E^2(z)}{dz^2}$.
  *
  */
 NCM_MODEL_SET_IMPL_FUNC(NC_HICOSMO,NcHICosmo,nc_hicosmo,NcHICosmoFunc1Z,d2E2_dz2)
@@ -445,6 +452,99 @@ nc_hicosmo_log_all_models (GType parent)
   _nc_hicosmo_log_all_models_go (parent, 0);
 }
 
+typedef struct _zt_params
+{
+  NcHICosmo *cosmo;
+}zt_params;
+
+static gdouble
+_nc_hicosmo_zt_func (gdouble z, void *params)
+{
+  zt_params *p = (zt_params *) params;
+  return nc_hicosmo_q (p->cosmo, z);
+}
+
+/**
+ * nc_hicosmo_zt:
+ * @cosmo: a #NcHICosmo
+ * @z_max: maximum redshift $z_\mathrm{max}$
+ *
+ * Computes the deceleration-acceleration transition redshift, $z_t$ (find 
+ * numerically the first root of $q(z)$ in the interval $[0,z_\mathrm{max}]$).
+ * If $z_t$ is not found, i.e., $q(z) \neq 0$ in the entire redshift interval, 
+ * the function returns NAN.
+ * 
+ * Redshift interval: $[0.0, @z_max]$.
+ *
+ * Returns: the transition redshift $z_t$ or NAN if not found.
+ */
+gdouble
+nc_hicosmo_zt (NcHICosmo *cosmo, gdouble z_max)
+{
+  gint status;
+  gint iter = 0, max_iter = 10000;
+  gdouble zt;
+  gdouble z_hi = 0.0;
+  gdouble z_lo = 0.0;
+  const gdouble step   = (1.0e-1 > z_max) ? (z_max / 10.0) : 1.0e-1;
+  const gdouble reltol = 1.0e-7;
+  const gdouble q0     = nc_hicosmo_q (cosmo, z_lo);
+  gsl_function F;
+  zt_params params;
+
+  params.cosmo = cosmo;
+  
+  F.function = &_nc_hicosmo_zt_func;
+  F.params   = &params;
+
+  do
+  {
+    z_hi += step;
+  } while (q0 * nc_hicosmo_q (cosmo, z_hi) >= 0.0 && (z_hi < z_max));
+
+  if (z_hi > z_max)
+    return GSL_NAN;
+  
+  gsl_root_fsolver_set (cosmo->s, &F, z_lo, z_hi);
+
+  /*
+  printf ("using %s method\n", 
+          gsl_root_fsolver_name (cosmo->s));
+
+  printf ("%5s [%9s, %9s] %9s %10s %9s\n",
+          "iter", "lower", "upper", "root", 
+          "err", "err(est)");
+
+  printf ("zmin = %.5g zmax = %.5g\n", z_lo, z_max);
+  */
+
+  do
+  {
+    iter++;
+    status = gsl_root_fsolver_iterate (cosmo->s);
+
+    zt     = gsl_root_fsolver_root (cosmo->s);
+    z_lo   = gsl_root_fsolver_x_lower (cosmo->s);
+    z_hi   = gsl_root_fsolver_x_upper (cosmo->s);
+    status = gsl_root_test_interval (z_lo, z_hi, 0.0, reltol);
+
+    /*
+     if (status == GSL_SUCCESS)
+     printf ("Converged:\n");
+
+     printf ("%5d [%.7f, %.7f] %.7f %.7f\n",
+     iter, z_lo, z_max,
+     zt, z_max - z_lo);
+     */
+  }
+  while (status == GSL_CONTINUE && iter < max_iter);
+
+  if (status != GSL_SUCCESS)
+    return GSL_NAN;
+  else
+    return zt;  
+}
+
 /*
  * Inlined functions
  */
@@ -826,6 +926,15 @@ nc_hicosmo_log_all_models (GType parent)
  *
  * Returns: FIXME
  */
+/**
+ * nc_hicosmo_nec:
+ * @cosmo: a #NcHICosmo
+ * @z: redshift $z$
+ *
+ * FIXME
+ *
+ * Returns: FIXME
+ */
 /**
  * nc_hicosmo_dec:
  * @cosmo: a #NcHICosmo
@@ -862,6 +971,15 @@ nc_hicosmo_log_all_models (GType parent)
  *
  * Returns: FIXME
  */
+/**
+ * nc_hicosmo_mqE2:
+ * @cosmo: a #NcHICosmo
+ * @z: redshift $z$
+ *
+ * Calculates $-q(z)E^2(z)$.
+ *
+ * Returns: $-q(z)E^2(z)$.
+ */
 
 /**
  * nc_hicosmo_abs_alpha:
@@ -921,8 +1039,8 @@ nc_hicosmo_sigma8 (NcHICosmo *cosmo, NcmPowspecFilter *psf)
 #define _NC_HICOSMO_FUNC0_TO_FLIST(fname) \
 static void _nc_hicosmo_flist_##fname (NcmMSetFuncList *flist, NcmMSet *mset, const gdouble *x, gdouble *res) \
 { \
- NcHICosmo *cosmo = NC_HICOSMO (ncm_mset_peek (mset, nc_hicosmo_id ())); \
- res[0] = nc_hicosmo_##fname (cosmo); \
+  NcHICosmo *cosmo = NC_HICOSMO (ncm_mset_peek (mset, nc_hicosmo_id ())); \
+  res[0] = nc_hicosmo_##fname (cosmo); \
 }
 
 _NC_HICOSMO_FUNC0_TO_FLIST (H0)
@@ -977,10 +1095,13 @@ _NC_HICOSMO_FUNC1_TO_FLIST (Em2)
 _NC_HICOSMO_FUNC1_TO_FLIST (dE2_dz)
 _NC_HICOSMO_FUNC1_TO_FLIST (d2E2_dz2)
 _NC_HICOSMO_FUNC1_TO_FLIST (q)
+_NC_HICOSMO_FUNC1_TO_FLIST (nec)
 _NC_HICOSMO_FUNC1_TO_FLIST (dec)
 _NC_HICOSMO_FUNC1_TO_FLIST (wec)
 _NC_HICOSMO_FUNC1_TO_FLIST (qp)
 _NC_HICOSMO_FUNC1_TO_FLIST (j)
+_NC_HICOSMO_FUNC1_TO_FLIST (mqE2)
+_NC_HICOSMO_FUNC1_TO_FLIST (zt)
 
 void
 _nc_hicosmo_register_functions (void)
@@ -1021,9 +1142,12 @@ _nc_hicosmo_register_functions (void)
   ncm_mset_func_list_register ("Em2",         "E^{-2}",                          "NcHICosmo", "One over Hubble function over H_0 squared", G_TYPE_NONE, _nc_hicosmo_flist_Em2,      1, 1);
   ncm_mset_func_list_register ("dE2_dz",      "\\mathrm{d}E^2/\\mathrm{d}z",     "NcHICosmo", "First derivative of E2",                    G_TYPE_NONE, _nc_hicosmo_flist_dE2_dz,   1, 1);
   ncm_mset_func_list_register ("d2E2_dz2",    "\\mathrm{d}^2E^2/\\mathrm{d}z^2", "NcHICosmo", "Second derivative of E2",                   G_TYPE_NONE, _nc_hicosmo_flist_d2E2_dz2, 1, 1);
-  ncm_mset_func_list_register ("q",           "q",                               "NcHICosmo", "Deceleration function",                     G_TYPE_NONE, _nc_hicosmo_flist_q,        1, 1);
-  ncm_mset_func_list_register ("dec",         "\\mathrm{dec}",                   "NcHICosmo", "DEC violation function",                    G_TYPE_NONE, _nc_hicosmo_flist_dec,      1, 1);
-  ncm_mset_func_list_register ("wec",         "\\mathrm{wec}",                   "NcHICosmo", "WEC violation function",                    G_TYPE_NONE, _nc_hicosmo_flist_wec,      1, 1);
+  ncm_mset_func_list_register ("q",           "q",                               "NcHICosmo", "Deceleration function (also SEC >0)",       G_TYPE_NONE, _nc_hicosmo_flist_q,        1, 1);
+  ncm_mset_func_list_register ("nec",         "\\mathrm{nec}",                   "NcHICosmo", "NEC violation function (>0)",               G_TYPE_NONE, _nc_hicosmo_flist_nec,      1, 1);
+  ncm_mset_func_list_register ("dec",         "\\mathrm{dec}",                   "NcHICosmo", "DEC violation function (>0)",               G_TYPE_NONE, _nc_hicosmo_flist_dec,      1, 1);
+  ncm_mset_func_list_register ("wec",         "\\mathrm{wec}",                   "NcHICosmo", "WEC violation function (>0)",               G_TYPE_NONE, _nc_hicosmo_flist_wec,      1, 1);
   ncm_mset_func_list_register ("qp",          "\\mathrm{d}q/\\mathrm{d}z",       "NcHICosmo", "Derivative of the deceleration function",   G_TYPE_NONE, _nc_hicosmo_flist_qp,       1, 1);
   ncm_mset_func_list_register ("j",           "j",                               "NcHICosmo", "Jerk function",                             G_TYPE_NONE, _nc_hicosmo_flist_j,        1, 1);
+  ncm_mset_func_list_register ("mqE2",        "-qE^2",                           "NcHICosmo", "Effective geometric OmegaL",                G_TYPE_NONE, _nc_hicosmo_flist_mqE2,     1, 1);
+  ncm_mset_func_list_register ("zt",          "z_t",                             "NcHICosmo", "Transition redshift",                       G_TYPE_NONE, _nc_hicosmo_flist_zt,       1, 1);
 }
