@@ -34,6 +34,8 @@
 #include <numcosmo/math/ncm_likelihood.h>
 #include <numcosmo/math/ncm_powspec_filter.h>
 
+#include <gsl/gsl_roots.h>
+
 G_BEGIN_DECLS
 
 #define NC_TYPE_HICOSMO             (nc_hicosmo_get_type ())
@@ -177,6 +179,8 @@ struct _NcHICosmo
   gboolean is_eternal;
   NcHIPrim *prim;
   NcHIReion *reion;
+  const gsl_root_fsolver_type *T;
+  gsl_root_fsolver *s;
 };
 
 GType nc_hicosmo_get_type (void) G_GNUC_CONST;
@@ -208,6 +212,7 @@ void nc_hicosmo_free (NcHICosmo *cosmo);
 void nc_hicosmo_clear (NcHICosmo **cosmo);
 
 void nc_hicosmo_log_all_models (GType parent);
+gdouble nc_hicosmo_zt (NcHICosmo *cosmo, gdouble z_max);
 
 /*
  * Cosmological model constant functions
@@ -258,11 +263,14 @@ G_INLINE_FUNC gdouble nc_hicosmo_bgp_cs2 (NcHICosmo *cosmo, gdouble z);
 G_INLINE_FUNC gdouble nc_hicosmo_Dc (NcHICosmo *cosmo, gdouble z);
 
 G_INLINE_FUNC gdouble nc_hicosmo_q (NcHICosmo *cosmo, gdouble z);
+G_INLINE_FUNC gdouble nc_hicosmo_nec (NcHICosmo *cosmo, gdouble z);
 G_INLINE_FUNC gdouble nc_hicosmo_dec (NcHICosmo *cosmo, gdouble z);
 G_INLINE_FUNC gdouble nc_hicosmo_wec (NcHICosmo *cosmo, gdouble z);
 G_INLINE_FUNC gdouble nc_hicosmo_qp (NcHICosmo *cosmo, gdouble z);
 G_INLINE_FUNC gdouble nc_hicosmo_j (NcHICosmo *cosmo, gdouble z);
 
+G_INLINE_FUNC gdouble nc_hicosmo_mqE2 (NcHICosmo *cosmo, gdouble z);
+
 G_INLINE_FUNC gdouble nc_hicosmo_abs_alpha (NcHICosmo *cosmo, gdouble x);
 G_INLINE_FUNC gdouble nc_hicosmo_x_alpha (NcHICosmo *cosmo, gdouble alpha);
 
@@ -467,6 +475,17 @@ nc_hicosmo_q (NcHICosmo *cosmo, gdouble z)
   return (dE2_dz * (1.0 + z) / (2.0 * E2) - 1.0);
 }
 
+G_INLINE_FUNC gdouble
+nc_hicosmo_nec (NcHICosmo *cosmo, gdouble z)
+{
+  const gdouble x  = 1.0 + z;
+  const gdouble q  = nc_hicosmo_q (cosmo, z);
+  const gdouble E2 = nc_hicosmo_E2 (cosmo, z);
+  const gdouble Ok = nc_hicosmo_Omega_k0 (cosmo);
+
+  return (1.0 + q) * E2 - Ok * x * x;
+}
+
 G_INLINE_FUNC gdouble
 nc_hicosmo_dec (NcHICosmo *cosmo, gdouble z)
 {
@@ -475,7 +494,7 @@ nc_hicosmo_dec (NcHICosmo *cosmo, gdouble z)
   const gdouble E2 = nc_hicosmo_E2 (cosmo, z);
   const gdouble Ok = nc_hicosmo_Omega_k0 (cosmo);
 
-  return (2.0 * E2 - q * E2 - 2.0 * Ok * x * x) / 3.0;
+  return ((2.0 - q) * E2 - 2.0 * Ok * x * x) / 3.0;
 }
 
 G_INLINE_FUNC gdouble
@@ -508,6 +527,16 @@ nc_hicosmo_j (NcHICosmo *cosmo, gdouble z)
   return gsl_pow_2 (1.0 + z) * (d2E2_dz2 - 2.0 * dE2_dz / (1.0 + z)) / (2.0 * E2) + 1.0;
 }
 
+G_INLINE_FUNC gdouble
+nc_hicosmo_mqE2 (NcHICosmo *cosmo, gdouble z)
+{
+  const gdouble q        = nc_hicosmo_q (cosmo, z);
+  const gdouble E2       = nc_hicosmo_E2 (cosmo, z);
+
+  return -q * E2;
+}
+
+
 G_INLINE_FUNC gdouble
 nc_hicosmo_x_alpha (NcHICosmo *cosmo, gdouble alpha)
 {
