@@ -768,21 +768,29 @@ nc_recomb_clear (NcRecomb **recomb)
 /**
  * nc_recomb_prepare:
  * @recomb: a #NcRecomb
- * @reion: a #NcHIReion
  * @cosmo: a #NcHICosmo
  *
  * Prepare the object using the model @cosmo.
  *
  */
 void
-nc_recomb_prepare (NcRecomb *recomb, NcHIReion *reion, NcHICosmo *cosmo)
+nc_recomb_prepare (NcRecomb *recomb, NcHICosmo *cosmo)
 {
-  NC_RECOMB_GET_CLASS (recomb)->prepare (recomb, reion, cosmo);
+  NC_RECOMB_GET_CLASS (recomb)->prepare (recomb, cosmo);
 
   ncm_model_ctrl_update (recomb->ctrl_cosmo, NCM_MODEL (cosmo));
-  ncm_model_ctrl_update (recomb->ctrl_reion, NCM_MODEL (reion));
 }
 
+/**
+ * nc_recomb_prepare_if_needed:
+ * @recomb: a #NcRecomb
+ * @cosmo: a #NcHICosmo
+ *
+ * Prepare the object using the model @cosmo if it was changed
+ * since last preparation.
+ *
+ */
+
 /**
  * nc_recomb_Xe:
  * @recomb: a #NcRecomb
