@@ -33,7 +33,6 @@
 #include "math/ncm_serialize.h"
 #include "math/ncm_cfg.h"
 #include "lss/nc_window_tophat.h"
-#include "lss/nc_matter_var.h"
 #include "xcor/nc_xcor_limber.h"
 
 G_DEFINE_ABSTRACT_TYPE (NcXcorLimber, nc_xcor_limber, NCM_TYPE_MODEL);
@@ -174,8 +173,7 @@ gdouble nc_xcor_limber_noise_spec (NcXcorLimber* xcl, guint l)
  *
  * FIXME
  *
- * Returns: FIXME
-*/
+ */
 void nc_xcor_limber_prepare (NcXcorLimber* xcl, NcHICosmo* cosmo)
 {
 	if (ncm_model_ctrl_update (xcl->cosmo_ctrl, NCM_MODEL (cosmo)))
@@ -250,6 +248,7 @@ static void nc_xcor_limber_class_init (NcXcorLimberClass* klass)
                               "line 297 of nc_cor_limber.c, to be modified "
                               "accordingly).",
                               NULL,
-                              TRUE);
+                              TRUE,
+                              NCM_MSET_MODEL_MAIN);
 	ncm_model_class_check_params_info (NCM_MODEL_CLASS (klass));
 }
