@@ -52,18 +52,18 @@ main (gint argc, gchar *argv[])
   ncm_cfg_init ();
   ncm_cfg_enable_gsl_err_handler ();
 
-  g_test_add_func ("/numcosmo/ncm_matrix/new", &test_ncm_matrix_new);
-  g_test_add_func ("/numcosmo/ncm_matrix/new_gsl", &test_ncm_matrix_new_gsl);
-  g_test_add_func ("/numcosmo/ncm_matrix/new_array", &test_ncm_matrix_new_array);
-  g_test_add_func ("/numcosmo/ncm_matrix/new_data_slice", &test_ncm_matrix_new_data_slice);
-  g_test_add_func ("/numcosmo/ncm_matrix/new_data_malloc", &test_ncm_matrix_new_data_malloc);
-  g_test_add_func ("/numcosmo/ncm_matrix/new_data_static", &test_ncm_matrix_new_data_static);
-  g_test_add_func ("/numcosmo/ncm_matrix/new_data_static_tda", &test_ncm_matrix_new_data_static_tda);
-  g_test_add_func ("/numcosmo/ncm_matrix/operations", &test_ncm_matrix_operations);
-  g_test_add_func ("/numcosmo/ncm_matrix/add_mul", &test_ncm_matrix_add_mul);
-  g_test_add_func ("/numcosmo/ncm_matrix/submatrix", &test_ncm_matrix_submatrix);
-  g_test_add_func ("/numcosmo/ncm_matrix/serialization", &test_ncm_matrix_serialization);
-  g_test_add_func ("/numcosmo/ncm_matrix/free", &test_ncm_matrix_free);
+  g_test_add_func ("/ncm/matrix/new", &test_ncm_matrix_new);
+  g_test_add_func ("/ncm/matrix/new_gsl", &test_ncm_matrix_new_gsl);
+  g_test_add_func ("/ncm/matrix/new_array", &test_ncm_matrix_new_array);
+  g_test_add_func ("/ncm/matrix/new_data_slice", &test_ncm_matrix_new_data_slice);
+  g_test_add_func ("/ncm/matrix/new_data_malloc", &test_ncm_matrix_new_data_malloc);
+  g_test_add_func ("/ncm/matrix/new_data_static", &test_ncm_matrix_new_data_static);
+  g_test_add_func ("/ncm/matrix/new_data_static_tda", &test_ncm_matrix_new_data_static_tda);
+  g_test_add_func ("/ncm/matrix/operations", &test_ncm_matrix_operations);
+  g_test_add_func ("/ncm/matrix/add_mul", &test_ncm_matrix_add_mul);
+  g_test_add_func ("/ncm/matrix/submatrix", &test_ncm_matrix_submatrix);
+  g_test_add_func ("/ncm/matrix/serialization", &test_ncm_matrix_serialization);
+  g_test_add_func ("/ncm/matrix/free", &test_ncm_matrix_free);
 
   g_test_run ();
 }
@@ -231,20 +231,7 @@ test_ncm_matrix_new_gsl (void)
   test_ncm_matrix_new_sanity (mm);
   g_assert (ncm_matrix_nrows (mm) == gm->size1 && ncm_matrix_ncols (mm) == gm->size2);
 
-  ncm_matrix_free (mm);
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-  {
-    ncm_matrix_free (mm);
-    exit (0);
-  }
-  g_test_trap_assert_failed ();
-
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-  {
-    g_assert (mm->pdata == NULL);
-    exit (0);
-  }
-  g_test_trap_assert_passed ();
+  NCM_TEST_FREE (ncm_matrix_free, mm);
 }
 
 void
@@ -262,20 +249,7 @@ test_ncm_matrix_new_array (void)
   g_assert (ga == ncm_matrix_get_array (mm));
   g_array_unref (ga);
 
-  ncm_matrix_free (mm);
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-  {
-    ncm_matrix_free (mm);
-    exit (0);
-  }
-  g_test_trap_assert_failed ();
-
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-  {
-    g_array_unref (mm->pdata);
-    exit (0);
-  }
-  g_test_trap_assert_failed ();
+  NCM_TEST_FREE (ncm_matrix_free, mm);
 }
 
 void
@@ -288,20 +262,7 @@ test_ncm_matrix_new_data_slice (void)
 
   g_assert ((ncm_matrix_nrows (mm) * ncm_matrix_ncols (mm)) == (_NCM_MATRIX_TEST_NROW * _NCM_MATRIX_TEST_NCOL));
 
-  ncm_matrix_free (mm);
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-  {
-    ncm_matrix_free (mm);
-    exit (0);
-  }
-  g_test_trap_assert_failed ();
-
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-  {
-    g_assert (ncm_matrix_data (mm) == NULL);
-    exit (0);
-  }
-  g_test_trap_assert_passed ();
+  NCM_TEST_FREE (ncm_matrix_free, mm);
 }
 
 void
@@ -314,20 +275,7 @@ test_ncm_matrix_new_data_malloc (void)
 
   g_assert_cmpuint ((ncm_matrix_nrows (mm) * ncm_matrix_ncols (mm)), ==, (_NCM_MATRIX_TEST_NROW * _NCM_MATRIX_TEST_NCOL));
 
-  ncm_matrix_free (mm);
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-  {
-    ncm_matrix_free (mm);
-    exit (0);
-  }
-  g_test_trap_assert_failed ();
-
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-  {
-    g_assert (ncm_matrix_data (mm) == NULL);
-    exit (0);
-  }
-  g_test_trap_assert_passed ();
+  NCM_TEST_FREE (ncm_matrix_free, mm);
 }
 
 void
@@ -339,13 +287,8 @@ test_ncm_matrix_new_data_static (void)
   test_ncm_matrix_new_sanity (mm);
 
   g_assert ((ncm_matrix_nrows (mm) * ncm_matrix_ncols (mm)) == (_NCM_MATRIX_TEST_NROW * _NCM_MATRIX_TEST_NCOL));
-
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-  {
-    ncm_matrix_free (mm);
-    exit (0);
-  }
-  g_test_trap_assert_passed ();
+  
+  ncm_matrix_free (mm);
 }
 
 void
@@ -387,12 +330,7 @@ test_ncm_matrix_new_data_static_tda (void)
     ncm_vector_free (v);
   }
 
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-  {
-    ncm_matrix_free (mm);
-    exit (0);
-  }
-  g_test_trap_assert_passed ();
+  ncm_matrix_free (mm);
 }
 
 void
@@ -417,13 +355,7 @@ test_ncm_matrix_submatrix (void)
   g_assert (G_IS_OBJECT (m));
   ncm_matrix_ref (m);
 
-  ncm_matrix_free (sm);
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-  {
-    ncm_matrix_free (sm);
-    exit (0);
-  }
-  g_test_trap_assert_failed ();
+  NCM_TEST_FREE (ncm_matrix_free, sm);
 }
 
 void
@@ -480,30 +412,11 @@ test_ncm_matrix_add_mul (void)
       }
     }
 
-    ncm_matrix_free (osm);
-    if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-    {
-      ncm_matrix_free (osm);
-      exit (0);
-    }
-    g_test_trap_assert_failed ();
-    
-    ncm_matrix_free (res);
-    if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-    {
-      ncm_matrix_free (res);
-      exit (0);
-    }
-    g_test_trap_assert_failed ();
+    NCM_TEST_FREE (ncm_matrix_free, osm);
+    NCM_TEST_FREE (ncm_matrix_free, res);    
   }
 
-  ncm_matrix_free (sm);
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-  {
-    ncm_matrix_free (sm);
-    exit (0);
-  }
-  g_test_trap_assert_failed ();
+  NCM_TEST_FREE (ncm_matrix_free, sm);
 }
 
 
@@ -525,23 +438,11 @@ test_ncm_matrix_serialization (void)
     }
   }
 
-  ncm_matrix_free (m_dup);
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-  {
-    ncm_matrix_free (m_dup);
-    exit (0);
-  }
-  g_test_trap_assert_failed ();
+  NCM_TEST_FREE (ncm_matrix_free, m_dup);
 }
 
 void
 test_ncm_matrix_free (void)
 {
-  ncm_matrix_free (m);
-  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
-  {
-    ncm_matrix_free (m);
-    exit (0);
-  }
-  g_test_trap_assert_failed ();
+  NCM_TEST_FREE (ncm_matrix_free, m);
 }
