@@ -73,164 +73,164 @@ main (gint argc, gchar *argv[])
 
   /* Default vector allocation */
 
-  g_test_add ("/numcosmo/ncm_vector/default/sanity", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/default/sanity", TestNcmVector, NULL, 
               &test_ncm_vector_new, 
               &test_ncm_vector_sanity, 
               &test_ncm_vector_free);
 
-  g_test_add ("/numcosmo/ncm_vector/default/operations", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/default/operations", TestNcmVector, NULL, 
               &test_ncm_vector_new, 
               &test_ncm_vector_operations, 
               &test_ncm_vector_free);
 
-  g_test_add ("/numcosmo/ncm_vector/default/subvector", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/default/subvector", TestNcmVector, NULL, 
               &test_ncm_vector_new, 
               &test_ncm_vector_subvector,
               &test_ncm_vector_free);
 
-  g_test_add ("/numcosmo/ncm_vector/default/variant", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/default/variant", TestNcmVector, NULL, 
               &test_ncm_vector_new, 
               &test_ncm_vector_variant,
               &test_ncm_vector_free);
 
-  g_test_add ("/numcosmo/ncm_vector/default/serialization", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/default/serialization", TestNcmVector, NULL, 
               &test_ncm_vector_new, 
               &test_ncm_vector_serialization,
               &test_ncm_vector_free);
 
   /* GSL vector allocation */
 
-  g_test_add ("/numcosmo/ncm_vector/gsl/sanity", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/gsl/sanity", TestNcmVector, NULL, 
               &test_ncm_vector_gsl_new, 
               &test_ncm_vector_sanity, 
               &test_ncm_vector_gsl_free);
   
-  g_test_add ("/numcosmo/ncm_vector/gsl/operations", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/gsl/operations", TestNcmVector, NULL, 
               &test_ncm_vector_gsl_new, 
               &test_ncm_vector_operations, 
               &test_ncm_vector_gsl_free);
 
-  g_test_add ("/numcosmo/ncm_vector/gsl/subvector", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/gsl/subvector", TestNcmVector, NULL, 
               &test_ncm_vector_gsl_new, 
               &test_ncm_vector_subvector,
               &test_ncm_vector_gsl_free);
 
-  g_test_add ("/numcosmo/ncm_vector/gsl/variant", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/gsl/variant", TestNcmVector, NULL, 
               &test_ncm_vector_gsl_new, 
               &test_ncm_vector_variant,
               &test_ncm_vector_gsl_free);
 
-  g_test_add ("/numcosmo/ncm_vector/gsl/serialization", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/gsl/serialization", TestNcmVector, NULL, 
               &test_ncm_vector_gsl_new, 
               &test_ncm_vector_serialization,
               &test_ncm_vector_gsl_free);
 
   /* Array vector allocation */
 
-  g_test_add ("/numcosmo/ncm_vector/array/sanity", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/array/sanity", TestNcmVector, NULL, 
               &test_ncm_vector_array_new, 
               &test_ncm_vector_sanity, 
               &test_ncm_vector_array_free);
   
-  g_test_add ("/numcosmo/ncm_vector/array/operations", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/array/operations", TestNcmVector, NULL, 
               &test_ncm_vector_array_new, 
               &test_ncm_vector_operations, 
               &test_ncm_vector_array_free);
 
-  g_test_add ("/numcosmo/ncm_vector/array/subvector", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/array/subvector", TestNcmVector, NULL, 
               &test_ncm_vector_array_new, 
               &test_ncm_vector_subvector,
               &test_ncm_vector_array_free);
 
-  g_test_add ("/numcosmo/ncm_vector/array/variant", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/array/variant", TestNcmVector, NULL, 
               &test_ncm_vector_array_new, 
               &test_ncm_vector_variant,
               &test_ncm_vector_array_free);
   
-  g_test_add ("/numcosmo/ncm_vector/array/serialization", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/array/serialization", TestNcmVector, NULL, 
               &test_ncm_vector_array_new, 
               &test_ncm_vector_serialization,
               &test_ncm_vector_array_free);
 
   /* Data slice vector allocation */
 
-  g_test_add ("/numcosmo/ncm_vector/data_slice/sanity", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/data_slice/sanity", TestNcmVector, NULL, 
               &test_ncm_vector_data_slice_new, 
               &test_ncm_vector_sanity, 
               &test_ncm_vector_data_slice_free);
   
-  g_test_add ("/numcosmo/ncm_vector/data_slice/operations", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/data_slice/operations", TestNcmVector, NULL, 
               &test_ncm_vector_data_slice_new, 
               &test_ncm_vector_operations, 
               &test_ncm_vector_data_slice_free);
 
-  g_test_add ("/numcosmo/ncm_vector/data_slice/subvector", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/data_slice/subvector", TestNcmVector, NULL, 
               &test_ncm_vector_data_slice_new, 
               &test_ncm_vector_subvector,
               &test_ncm_vector_data_slice_free);
 
-  g_test_add ("/numcosmo/ncm_vector/data_slice/variant", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/data_slice/variant", TestNcmVector, NULL, 
               &test_ncm_vector_data_slice_new, 
               &test_ncm_vector_variant,
               &test_ncm_vector_data_slice_free);
   
-  g_test_add ("/numcosmo/ncm_vector/data_slice/serialization", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/data_slice/serialization", TestNcmVector, NULL, 
               &test_ncm_vector_data_slice_new, 
               &test_ncm_vector_serialization,
               &test_ncm_vector_data_slice_free);
 
   /* Data malloc vector allocation */
 
-  g_test_add ("/numcosmo/ncm_vector/data_malloc/sanity", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/data_malloc/sanity", TestNcmVector, NULL, 
               &test_ncm_vector_data_malloc_new, 
               &test_ncm_vector_sanity, 
               &test_ncm_vector_data_malloc_free);
   
-  g_test_add ("/numcosmo/ncm_vector/data_malloc/operations", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/data_malloc/operations", TestNcmVector, NULL, 
               &test_ncm_vector_data_malloc_new, 
               &test_ncm_vector_operations, 
               &test_ncm_vector_data_malloc_free);
 
-  g_test_add ("/numcosmo/ncm_vector/data_malloc/subvector", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/data_malloc/subvector", TestNcmVector, NULL, 
               &test_ncm_vector_data_malloc_new, 
               &test_ncm_vector_subvector,
               &test_ncm_vector_data_malloc_free);
 
-  g_test_add ("/numcosmo/ncm_vector/data_malloc/variant", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/data_malloc/variant", TestNcmVector, NULL, 
               &test_ncm_vector_data_malloc_new, 
               &test_ncm_vector_variant,
               &test_ncm_vector_data_malloc_free);
 
   /* Data static vector allocation */
 
-  g_test_add ("/numcosmo/ncm_vector/data_static/sanity", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/data_static/sanity", TestNcmVector, NULL, 
               &test_ncm_vector_data_static_new, 
               &test_ncm_vector_sanity, 
               &test_ncm_vector_data_static_free);
 
-  g_test_add ("/numcosmo/ncm_vector/data_static/operations", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/data_static/operations", TestNcmVector, NULL, 
               &test_ncm_vector_data_static_new, 
               &test_ncm_vector_operations, 
               &test_ncm_vector_data_static_free);
 
-  g_test_add ("/numcosmo/ncm_vector/data_static/subvector", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/data_static/subvector", TestNcmVector, NULL, 
               &test_ncm_vector_data_static_new, 
               &test_ncm_vector_subvector,
               &test_ncm_vector_data_static_free);
 
-  g_test_add ("/numcosmo/ncm_vector/data_static/variant", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/data_static/variant", TestNcmVector, NULL, 
               &test_ncm_vector_data_static_new, 
               &test_ncm_vector_variant,
               &test_ncm_vector_data_static_free);
 
-  g_test_add ("/numcosmo/ncm_vector/data_static/serialization", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/data_static/serialization", TestNcmVector, NULL, 
               &test_ncm_vector_data_static_new, 
               &test_ncm_vector_serialization,
               &test_ncm_vector_data_static_free);
 
   /* Data static vector allocation */
 
-  g_test_add ("/numcosmo/ncm_vector/data_const/sanity", TestNcmVector, NULL, 
+  g_test_add ("/ncm/vector/data_const/sanity", TestNcmVector, NULL, 
               &test_ncm_vector_data_const_new, 
               &test_ncm_vector_data_const_sanity, 
               &test_ncm_vector_data_const_free);
@@ -258,8 +258,7 @@ void
 test_ncm_vector_free (TestNcmVector *test, gconstpointer pdata)
 {
   NcmVector *v = test->v;
-  ncm_vector_free (v);
-  NCM_TEST_FAIL (ncm_vector_free (v));
+  NCM_TEST_FREE (ncm_vector_free, v);
 }
 
 void
@@ -276,9 +275,7 @@ void
 test_ncm_vector_gsl_free (TestNcmVector *test, gconstpointer pdata)
 {
   NcmVector *v = test->v;
-  ncm_vector_free (v);
-  NCM_TEST_FAIL (ncm_vector_free (v));
-  NCM_TEST_PASS (g_assert (v->pdata == NULL));
+  NCM_TEST_FREE (ncm_vector_free, v);
 }
 
 void
@@ -287,6 +284,7 @@ test_ncm_vector_array_new (TestNcmVector *test, gconstpointer pdata)
   guint v_size = test->v_size = g_test_rand_int_range (_TEST_NCM_VECTOR_MIN_SIZE, _TEST_NCM_VECTOR_STATIC_SIZE);
   GArray *ga = g_array_sized_new (FALSE, FALSE, sizeof (gdouble), v_size);
   NcmVector *v;
+  
   g_array_set_size (ga, v_size);
   v = test->v = ncm_vector_new_array (ga);
   g_array_unref (ga);
@@ -302,9 +300,8 @@ void
 test_ncm_vector_array_free (TestNcmVector *test, gconstpointer pdata)
 {
   NcmVector *v = test->v;
-  ncm_vector_free (v);
-  NCM_TEST_FAIL (ncm_vector_free (v));
-  NCM_TEST_FAIL (g_array_unref (v->pdata));
+  
+  NCM_TEST_FREE (ncm_vector_free, v);
 }
 
 void
@@ -321,10 +318,9 @@ test_ncm_vector_data_slice_new (TestNcmVector *test, gconstpointer pdata)
 void
 test_ncm_vector_data_slice_free (TestNcmVector *test, gconstpointer pdata)
 {
-  NcmVector *v = test->v;  
-  ncm_vector_free (v);
-  NCM_TEST_FAIL (ncm_vector_free (v));
-  NCM_TEST_PASS (g_assert (ncm_vector_data (v) == NULL));
+  NcmVector *v = test->v;
+
+  NCM_TEST_FREE (ncm_vector_free, v);  
 }
 
 void
@@ -342,9 +338,7 @@ void
 test_ncm_vector_data_malloc_free (TestNcmVector *test, gconstpointer pdata)
 {
   NcmVector *v = test->v;  
-  ncm_vector_free (v);
-  NCM_TEST_FAIL (ncm_vector_free (v));
-  NCM_TEST_PASS (g_assert (ncm_vector_data (v) == NULL));
+  NCM_TEST_FREE (ncm_vector_free, v);
 }
 
 void
@@ -362,8 +356,7 @@ void
 test_ncm_vector_data_static_free (TestNcmVector *test, gconstpointer pdata)
 {
   NcmVector *v = test->v;
-
-  NCM_TEST_PASS (ncm_vector_free (v));
+  NCM_TEST_FREE (ncm_vector_free, v);
 }
 
 void
@@ -380,7 +373,7 @@ void
 test_ncm_vector_data_const_free (TestNcmVector *test, gconstpointer pdata)
 {
   const NcmVector *cv = test->cv;
-  NCM_TEST_PASS (ncm_vector_const_free (cv));
+  ncm_vector_const_free (cv);
 }
 
 void
@@ -570,8 +563,7 @@ test_ncm_vector_subvector (TestNcmVector *test, gconstpointer pdata)
   g_assert (G_IS_OBJECT (v));
   ncm_vector_ref (v);
 
-  ncm_vector_free (sv);
-  NCM_TEST_FAIL (ncm_vector_free (sv));
+  NCM_TEST_FREE (ncm_vector_free, sv);
 }
 
 void
@@ -579,7 +571,6 @@ test_ncm_vector_variant (TestNcmVector *test, gconstpointer pdata)
 {
   NcmVector *v = test->v;
   GVariant *var = ncm_vector_get_variant (v);
-
   g_assert (!g_variant_is_floating (var));
   g_assert (g_variant_is_container (var));
   g_assert_cmpuint (ncm_vector_len (v), ==, g_variant_n_children (var));
@@ -593,13 +584,11 @@ test_ncm_vector_variant (TestNcmVector *test, gconstpointer pdata)
     {
       ncm_assert_cmpdouble (ncm_vector_get (v, i), ==, ncm_vector_get (nv, i));
     }
-    
-    ncm_vector_free (nv);
-    NCM_TEST_FAIL (ncm_vector_free (nv));
+    NCM_TEST_FREE (ncm_vector_free, nv);
   }
-
+  
   g_variant_unref (var);
-  NCM_TEST_FAIL (g_variant_unref (var); fprintf (stderr,"fail (%s)", g_variant_get_type_string (var)));
+  NCM_TEST_FAIL (g_variant_unref (var); fprintf (stderr, "fail (%s)", g_variant_get_type_string (var)));
 }
 
 void
@@ -617,7 +606,5 @@ test_ncm_vector_serialization (TestNcmVector *test, gconstpointer pdata)
     ncm_assert_cmpdouble (ncm_vector_get (v, i), ==, ncm_vector_get (v_dup, i));
   }
 
-  ncm_vector_free (v_dup);
-  NCM_TEST_FAIL (ncm_vector_free (v_dup));
+  NCM_TEST_FREE (ncm_vector_free, v_dup);
 }
-
